@@ -44,51 +44,29 @@
 
 #define WRITE_TXT(fn, txt) ASSERT (write ((fn), (txt), 1 + strlen (txt)) != -1)
 
-#if defined (BUILD_LINUX) && defined (HAVE_EXECINFO_H)
+//! @brief Whether x matches c; case insensitive.
 
-#include <execinfo.h>
-
-void genie_sigsegv (NODE_T *p)
+BOOL_T match_string (char *x, char *c, char stop)
 {
-  (void) p;
-  raise (SIGSEGV);
-}
-
-//! @brief Provide a rudimentary backtrace.
-
-void stack_backtrace (void)
-{
-#define DEPTH 16
-  void *array[DEPTH];
-  WRITE_TXT (2, "\n++++ Top of call stack:");
-  int size = backtrace (array, DEPTH);
-  if (size > 0) {
-    WRITE_TXT (2, "\n");
-    backtrace_symbols_fd (array, size, 2);
+#define DONE(z) ((z) == NULL_CHAR || (z) == stop) 
+#define NOT_DONE(z) (! DONE (z))
+  BOOL_T match = A68G_TRUE;
+// Uppercase characters in c are mandatory.
+  while ((IS_UPPER (c[0]) || IS_DIGIT (c[0]) || (NOT_DONE (x[0]) && c[0] == '-')) && match) {
+    match = (BOOL_T) (match & (TO_LOWER (x[0]) == TO_LOWER ((c++)[0])));
+    if (NOT_DONE (x[0])) {
+      x++;
+    }
   }
-#undef DEPTH
+// Lowercase characters in c are optional.
+  while (NOT_DONE (x[0]) && NOT_DONE (c[0]) && match) {
+    match = (BOOL_T) (match & (TO_LOWER ((x++)[0]) == TO_LOWER ((c++)[0])));
+  }
+  return (BOOL_T) (match ? DONE (x[0]) : A68G_FALSE);
+#undef DONE
+#undef NOT_DONE
 }
 
-void genie_backtrace (NODE_T *p)
-{
-  (void) p;
-  stack_backtrace ();
-}
-
-#else
-
-void stack_backtrace (void)
-{
-  WRITE_TXT (2, "\n++++ Stack backtrace is not available on this platform");
-}
-
-void genie_backtrace (NODE_T *p)
-{
-  (void) p;
-  stack_backtrace ();
-}
-#endif
-
 //! @brief Open a file in ~/.a68g, if possible.
 
 FILE *a68g_fopen (char *fn, char *mode, char *new_fn)
@@ -99,7 +77,7 @@ FILE *a68g_fopen (char *fn, char *mode, char *new_fn)
 #else
   errno = 0;
   BUFFER dn;
-  ASSERT (a68g_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68_DIR) >= 0);
+  ASSERT (a68g_bufprt (dn, SNPRINTF_SIZE, "%s/%s", getenv ("HOME"), A68G_DIR) >= 0);
   int ret = mkdir (dn, (mode_t) (S_IRUSR | S_IWUSR | S_IXUSR));
   if (ret == 0 || (ret == -1 && errno == EEXIST)) {
     struct stat status;
@@ -167,7 +145,7 @@ void sigwinch_handler (int i)
 {
   (void) i;
   ABEND (signal (SIGWINCH, sigwinch_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  a68g_getty (&A68 (term_heigth), &A68 (term_width));
+  a68g_getty (&A68G (term_heigth), &A68G (term_width));
 }
 #endif
 
@@ -178,11 +156,12 @@ void sigsegv_handler (int i)
   (void) i;
 // write () is asynchronous-safe and may be called here.
   WRITE_TXT (2, "\nFatal");
-  if (FILE_INITIAL_NAME (&A68_JOB) != NO_TEXT) {
+  if (FILE_INITIAL_NAME (&A68G_JOB) != NO_TEXT) {
     WRITE_TXT (2, ": ");
-    WRITE_TXT (2, FILE_INITIAL_NAME (&A68_JOB));
+    WRITE_TXT (2, FILE_INITIAL_NAME (&A68G_JOB));
   }
   WRITE_TXT (2, ": memory access violation\n");
+  extern void stack_backtrace (void);
   stack_backtrace ();
   exit (EXIT_FAILURE);
 }
@@ -193,9 +172,9 @@ void sigint_handler (int i)
 {
   (void) i;
   ABEND (signal (SIGINT, sigint_handler) == SIG_ERR, ERROR_ACTION, __func__);
-  if (!(STATUS_TEST (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK) || A68 (in_monitor))) {
-    STATUS_SET (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK);
-    genie_break (TOP_NODE (&A68_JOB));
+  if (!(STATUS_TEST (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK) || A68G (in_monitor))) {
+    STATUS_SET (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK);
+    genie_break (TOP_NODE (&A68G_JOB));
   }
 }
 
@@ -206,7 +185,7 @@ void sigint_handler (int i)
 void sigttin_handler (int i)
 {
   (void) i;
-  ABEND (A68_TRUE, ERROR_ACTION, __func__);
+  ABEND (A68G_TRUE, ERROR_ACTION, __func__);
 }
 
 //! @brief Signal broken pipe.
@@ -214,7 +193,7 @@ void sigttin_handler (int i)
 void sigpipe_handler (int i)
 {
   (void) i;
-  ABEND (A68_TRUE, ERROR_ACTION, __func__);
+  ABEND (A68G_TRUE, ERROR_ACTION, __func__);
 }
 
 //! @brief Signal alarm - time limit check.
@@ -236,11 +215,11 @@ unsigned a68g_alarm (unsigned seconds)
 void sigalrm_handler (int i)
 {
   (void) i;
-  if (A68 (in_execution) && !A68 (in_monitor)) {
-    REAL_T _m_t = (REAL_T) OPTION_TIME_LIMIT (&A68_JOB);
-    if (_m_t > 0 && (seconds () - A68 (cputime_0)) > _m_t) {
-      diagnostic (A68_RUNTIME_ERROR, (NODE_T *) A68 (f_entry), ERROR_TIME_LIMIT_EXCEEDED);
-      exit_genie ((NODE_T *) A68 (f_entry), A68_RUNTIME_ERROR);
+  if (A68G (in_execution) && !A68G (in_monitor)) {
+    REAL_T _m_t = (REAL_T) OPTION_TIME_LIMIT (&A68G_JOB);
+    if (_m_t > 0 && (seconds () - A68G (cputime_0)) > _m_t) {
+      diagnostic (A68G_RUNTIME_ERROR, (NODE_T *) A68G (f_entry), ERROR_TIME_LIMIT_EXCEEDED);
+      exit_genie ((NODE_T *) A68G (f_entry), A68G_RUNTIME_ERROR);
     }
   }
   ABEND (signal (SIGALRM, sigalrm_handler) == SIG_ERR, ERROR_ACTION, __func__);
@@ -265,13 +244,28 @@ void install_signal_handlers (void)
 #endif
 }
 
-//! @brief Time versus arbitrary origin.
+//! @brief Wall clock versus arbitrary origin.
+
+REAL_T wall_seconds (void)
+{
+#if defined (BUILD_LINUX)
+  struct timespec ts;
+  clock_gettime (CLOCK_MONOTONIC, &ts);
+  return ts.tv_sec + ts.tv_nsec * 1e-9; 
+#else
+  return seconds();
+#endif
+} 
+
+//! @brief Process time versus arbitrary origin.
 
 REAL_T seconds (void)
 {
   return (REAL_T) clock () / (REAL_T) CLOCKS_PER_SEC;
 }
 
+
+
 //! @brief Delay for specified number of microseconds.
 
 int a68g_usleep (unsigned delay)
@@ -373,3 +367,49 @@ int a68g_bufprt (char *dst, size_t len, const char *format, ...)
     return rc;
   }
 }
+
+#if defined (BUILD_LINUX) && defined (HAVE_EXECINFO_H)
+
+#include <execinfo.h>
+
+void genie_sigsegv (NODE_T *p)
+{
+  (void) p;
+  raise (SIGSEGV);
+}
+
+//! @brief Provide a rudimentary backtrace.
+
+void stack_backtrace (void)
+{
+#define DEPTH 16
+  void *array[DEPTH];
+  WRITE_TXT (2, "\n++++ Top of call stack:");
+  int size = backtrace (array, DEPTH);
+  if (size > 0) {
+    WRITE_TXT (2, "\n");
+    backtrace_symbols_fd (array, size, 2);
+  }
+#undef DEPTH
+}
+
+void genie_backtrace (NODE_T *p)
+{
+  (void) p;
+  stack_backtrace ();
+}
+
+#else
+
+void stack_backtrace (void)
+{
+  WRITE_TXT (2, "\n++++ Stack backtrace is not available on this platform");
+}
+
+void genie_backtrace (NODE_T *p)
+{
+  (void) p;
+  stack_backtrace ();
+}
+#endif
+
