@@ -83,7 +83,7 @@ char *char_to_str (char ch)
 
 void pretty_diag (FILE_T f, char *p)
 {
-  int line_width = (f == A68_STDERR || f == A68_STDOUT ? A68 (term_width) : MAX_TERM_WIDTH);
+  int line_width = (f == A68G_STDERR || f == A68G_STDOUT ? A68G (term_width) : MAX_TERM_WIDTH);
   int pos = 1;
   while (p[0] != NULL_CHAR) {
     char *q;
@@ -117,19 +117,19 @@ void pretty_diag (FILE_T f, char *p)
 
 void abend (char *reason, char *info, char *file, int line)
 {
-  ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: exiting: %s: %d: %s", A68 (a68g_cmd_name), file, line, reason) >= 0);
+  ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: exiting: %s: %d: %s", A68G (a68g_cmd_name), file, line, reason) >= 0);
   if (info != NO_TEXT) {
-    a68g_bufcat (A68 (output_line), ", ", BUFFER_SIZE);
-    a68g_bufcat (A68 (output_line), info, BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), ", ", BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), info, BUFFER_SIZE);
   }
   if (errno != 0) {
-    a68g_bufcat (A68 (output_line), " (", BUFFER_SIZE);
-    a68g_bufcat (A68 (output_line), error_specification (), BUFFER_SIZE);
-    a68g_bufcat (A68 (output_line), ")", BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), " (", BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), error_specification (), BUFFER_SIZE);
+    a68g_bufcat (A68G (output_line), ")", BUFFER_SIZE);
   }
-  a68g_bufcat (A68 (output_line), "\n", BUFFER_SIZE);
+  a68g_bufcat (A68G (output_line), "\n", BUFFER_SIZE);
   io_close_tty_line ();
-  pretty_diag (A68_STDERR, A68 (output_line));
+  pretty_diag (A68G_STDERR, A68G (output_line));
   a68g_exit (EXIT_FAILURE);
 }
 
@@ -181,7 +181,7 @@ char *diag_pos (LINE_T * p, DIAGNOSTIC_T * d)
 
 void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
 {
-  int line_width = (f == A68_STDERR || f == A68_STDOUT ? A68 (term_width) : MAX_TERM_WIDTH);
+  int line_width = (f == A68G_STDERR || f == A68G_STDOUT ? A68G (term_width) : MAX_TERM_WIDTH);
 // Terminate properly.
   if ((STRING (p))[strlen (STRING (p)) - 1] == NEWLINE_CHAR) {
     (STRING (p))[strlen (STRING (p)) - 1] = NULL_CHAR;
@@ -190,38 +190,38 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
     }
   }
 // Print line number.
-  if (f == A68_STDERR || f == A68_STDOUT) {
+  if (f == A68G_STDERR || f == A68G_STDOUT) {
     io_close_tty_line ();
   } else {
     WRITE (f, NEWLINE_STRING);
   }
   if (NUMBER (p) == 0) {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "      ") >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "      ") >= 0);
   } else {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%-5d ", NUMBER (p) % 100000) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%-5d ", NUMBER (p) % 100000) >= 0);
   }
-  WRITE (f, A68 (output_line));
+  WRITE (f, A68G (output_line));
 // Pretty print line.
   char *c, *c0;
   c = c0 = STRING (p);
   int pos = 5, col = 1;
   int continuations = 0;
-  BOOL_T line_ended = A68_FALSE;
+  BOOL_T line_ended = A68G_FALSE;
   while (!line_ended) {
     int len = 0;
     char *new_pos = NO_TEXT;
     if (c[0] == NULL_CHAR) {
-      a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
-      line_ended = A68_TRUE;
+      a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
+      line_ended = A68G_TRUE;
     } else {
       if (IS_GRAPH (c[0])) {
         char *c1;
-        a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+        a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
         for (c1 = c; IS_GRAPH (c1[0]) && len <= line_width - 5; c1++, len++) {
-          a68g_bufcat (A68 (output_line), char_to_str (c1[0]), BUFFER_SIZE);
+          a68g_bufcat (A68G (output_line), char_to_str (c1[0]), BUFFER_SIZE);
         }
         if (len > line_width - 5) {
-          a68g_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
+          a68g_bufcpy (A68G (output_line), char_to_str (c[0]), BUFFER_SIZE);
           len = 1;
         }
         new_pos = &c[len];
@@ -230,18 +230,18 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
         int n = TABULATE (col);
         len = n;
         col += n;
-        a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+        a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
         while (n--) {
-          a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+          a68g_bufcat (A68G (output_line), " ", BUFFER_SIZE);
         }
         new_pos = &c[1];
       } else if (unprintable (c[0])) {
-        a68g_bufcpy (A68 (output_line), ctrl_char ((int) c[0]), BUFFER_SIZE);
-        len = (int) strlen (A68 (output_line));
+        a68g_bufcpy (A68G (output_line), ctrl_char ((int) c[0]), BUFFER_SIZE);
+        len = (int) strlen (A68G (output_line));
         new_pos = &c[1];
         col++;
       } else {
-        a68g_bufcpy (A68 (output_line), char_to_str (c[0]), BUFFER_SIZE);
+        a68g_bufcpy (A68G (output_line), char_to_str (c[0]), BUFFER_SIZE);
         len = 1;
         new_pos = &c[1];
         col++;
@@ -249,18 +249,18 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
     }
     if (!line_ended && (pos + len) <= line_width) {
 // Still room - print a character.
-      WRITE (f, A68 (output_line));
+      WRITE (f, A68G (output_line));
       pos += len;
       c = new_pos;
     } else {
 // First see if there are diagnostics to be printed.
-      BOOL_T y = A68_FALSE, z = A68_FALSE;
+      BOOL_T y = A68G_FALSE, z = A68G_FALSE;
       DIAGNOSTIC_T *d = DIAGNOSTICS (p);
       if (d != NO_DIAGNOSTIC || nwhere != NO_NODE) {
         char *c1;
         for (c1 = c0; c1 != c; c1++) {
-          y |= (BOOL_T) (nwhere != NO_NODE && p == LINE (INFO (nwhere)) ? c1 == where_pos (p, nwhere) : A68_FALSE);
-          if (mask != A68_NO_DIAGNOSTICS) {
+          y |= (BOOL_T) (nwhere != NO_NODE && p == LINE (INFO (nwhere)) ? c1 == where_pos (p, nwhere) : A68G_FALSE);
+          if (mask != A68G_NO_DIAGNOSTICS) {
             for (d = DIAGNOSTICS (p); d != NO_DIAGNOSTIC; FORWARD (d)) {
               z = (BOOL_T) (z | (c1 == diag_pos (p, d)));
             }
@@ -281,47 +281,47 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
               k = NUMBER (d2);
             }
           }
-          if (y == A68_TRUE && c1 == where_pos (p, nwhere)) {
-            a68g_bufcpy (A68 (output_line), "-", BUFFER_SIZE);
+          if (y == A68G_TRUE && c1 == where_pos (p, nwhere)) {
+            a68g_bufcpy (A68G (output_line), "-", BUFFER_SIZE);
           } else if (diags_at_this_pos != 0) {
-            if (mask == A68_NO_DIAGNOSTICS) {
-              a68g_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
+            if (mask == A68G_NO_DIAGNOSTICS) {
+              a68g_bufcpy (A68G (output_line), " ", BUFFER_SIZE);
             } else if (diags_at_this_pos == 1) {
-              ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%c", digchar (k)) >= 0);
+              ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%c", digchar (k)) >= 0);
             } else {
-              a68g_bufcpy (A68 (output_line), "*", BUFFER_SIZE);
+              a68g_bufcpy (A68G (output_line), "*", BUFFER_SIZE);
             }
           } else {
             if (unprintable (c1[0])) {
               int n = (int) strlen (ctrl_char (c1[0]));
               col_2 += 1;
-              a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+              a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
               while (n--) {
-                a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+                a68g_bufcat (A68G (output_line), " ", BUFFER_SIZE);
               }
             } else if (c1[0] == TAB_CHAR) {
               int n = TABULATE (col_2);
               col_2 += n;
-              a68g_bufcpy (A68 (output_line), "", BUFFER_SIZE);
+              a68g_bufcpy (A68G (output_line), "", BUFFER_SIZE);
               while (n--) {
-                a68g_bufcat (A68 (output_line), " ", BUFFER_SIZE);
+                a68g_bufcat (A68G (output_line), " ", BUFFER_SIZE);
               }
             } else {
-              a68g_bufcpy (A68 (output_line), " ", BUFFER_SIZE);
+              a68g_bufcpy (A68G (output_line), " ", BUFFER_SIZE);
               col_2++;
             }
           }
-          WRITE (f, A68 (output_line));
+          WRITE (f, A68G (output_line));
         }
       }
 // Resume pretty printing of line.
       if (!line_ended) {
         continuations++;
-        ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\n.%1d   ", continuations) >= 0);
-        WRITE (f, A68 (output_line));
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "\n.%1d   ", continuations) >= 0);
+        WRITE (f, A68G (output_line));
         if (continuations >= 9) {
           WRITE (f, "...");
-          line_ended = A68_TRUE;
+          line_ended = A68G_TRUE;
         } else {
           c0 = c;
           pos = 5;
@@ -335,8 +335,8 @@ void write_source_line (FILE_T f, LINE_T * p, NODE_T * nwhere, int mask)
     if (DIAGNOSTICS (p) != NO_DIAGNOSTIC) {
       DIAGNOSTIC_T *d;
       for (d = DIAGNOSTICS (p); d != NO_DIAGNOSTIC; FORWARD (d)) {
-        if (mask == A68_RUNTIME_ERROR) {
-          if (IS (d, A68_RUNTIME_ERROR) || IS (d, A68_MATH_ERROR) || (IS (d, A68_MATH_WARNING))) {
+        if (mask == A68G_RUNTIME_ERROR) {
+          if (IS (d, A68G_RUNTIME_ERROR) || IS (d, A68G_MATH_ERROR) || (IS (d, A68G_MATH_WARNING))) {
             WRITE (f, NEWLINE_STRING);
             pretty_diag (f, TEXT (d));
           }
@@ -355,16 +355,16 @@ void diagnostics_to_terminal (LINE_T * p, int sev)
 {
   for (; p != NO_LINE; FORWARD (p)) {
     if (DIAGNOSTICS (p) != NO_DIAGNOSTIC) {
-      BOOL_T z = A68_FALSE;
+      BOOL_T z = A68G_FALSE;
       for (DIAGNOSTIC_T *d = DIAGNOSTICS (p); d != NO_DIAGNOSTIC; FORWARD (d)) {
-        if (sev == A68_ALL_DIAGNOSTICS) {
-          z = (BOOL_T) (z | (IS (d, A68_WARNING) || IS (d, A68_ERROR) || IS (d, A68_SYNTAX_ERROR) || IS (d, A68_MATH_ERROR) || IS (d, A68_RUNTIME_ERROR) || IS (d, A68_SCANNER_ERROR)));
-        } else if (sev == A68_RUNTIME_ERROR) {
-          z = (BOOL_T) (z | (IS (d, A68_RUNTIME_ERROR) || (IS (d, A68_MATH_ERROR))));
+        if (sev == A68G_ALL_DIAGNOSTICS) {
+          z = (BOOL_T) (z | (IS (d, A68G_WARNING) || IS (d, A68G_ERROR) || IS (d, A68G_SYNTAX_ERROR) || IS (d, A68G_MATH_ERROR) || IS (d, A68G_RUNTIME_ERROR) || IS (d, A68G_SCANNER_ERROR)));
+        } else if (sev == A68G_RUNTIME_ERROR) {
+          z = (BOOL_T) (z | (IS (d, A68G_RUNTIME_ERROR) || (IS (d, A68G_MATH_ERROR))));
         }
       }
       if (z) {
-        write_source_line (A68_STDERR, p, NO_NODE, sev);
+        write_source_line (A68G_STDERR, p, NO_NODE, sev);
       }
     }
   }
@@ -375,11 +375,11 @@ void diagnostics_to_terminal (LINE_T * p, int sev)
 void scan_error (LINE_T * u, char *v, char *txt)
 {
   if (errno != 0) {
-    diagnostic (A68_SCANNER_ERROR, NO_NODE, txt, u, v, error_specification ());
+    diagnostic (A68G_SCANNER_ERROR, NO_NODE, txt, u, v, error_specification ());
   } else {
-    diagnostic (A68_SCANNER_ERROR, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
+    diagnostic (A68G_SCANNER_ERROR, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
   }
-  longjmp (RENDEZ_VOUS (&A68_JOB), 1);
+  longjmp (RENDEZ_VOUS (&A68G_JOB), 1);
 }
 
 void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
@@ -391,11 +391,11 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
     a68g_bufcpy (txti, txt, len);
     a68g_bufcat (txti, " Z", len);
     if (errno != 0) {
-      diagnostic (A68_SCANNER_ERROR, NO_NODE, txti, u, v, info, error_specification ());
+      diagnostic (A68G_SCANNER_ERROR, NO_NODE, txti, u, v, info, error_specification ());
     } else {
-      diagnostic (A68_SCANNER_ERROR, NO_NODE, txti, u, v, info, ERROR_UNSPECIFIED);
+      diagnostic (A68G_SCANNER_ERROR, NO_NODE, txti, u, v, info, ERROR_UNSPECIFIED);
     }
-    longjmp (RENDEZ_VOUS (&A68_JOB), 1);
+    longjmp (RENDEZ_VOUS (&A68G_JOB), 1);
   } else {
     scan_error(u, v, txt);
   }
@@ -406,9 +406,9 @@ void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
 void scan_warning (LINE_T * u, char *v, char *txt)
 {
   if (errno != 0) {
-    diagnostic (A68_SCANNER_WARNING, NO_NODE, txt, u, v, error_specification ());
+    diagnostic (A68G_SCANNER_WARNING, NO_NODE, txt, u, v, error_specification ());
   } else {
-    diagnostic (A68_SCANNER_WARNING, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
+    diagnostic (A68G_SCANNER_WARNING, NO_NODE, txt, u, v, ERROR_UNSPECIFIED);
   }
 }
 
@@ -417,28 +417,28 @@ void scan_warning (LINE_T * u, char *v, char *txt)
 char *get_severity (int sev)
 {
   switch (sev) {
-  case A68_ERROR: {
+  case A68G_ERROR: {
       return "error";
     }
-  case A68_SYNTAX_ERROR: {
+  case A68G_SYNTAX_ERROR: {
       return "syntax error";
     }
-  case A68_RUNTIME_ERROR: {
+  case A68G_RUNTIME_ERROR: {
       return "runtime error";
     }
-  case A68_MATH_ERROR: {
+  case A68G_MATH_ERROR: {
       return "math error";
     }
-  case A68_MATH_WARNING: {
+  case A68G_MATH_WARNING: {
       return "math warning";
     }
-  case A68_WARNING: {
+  case A68G_WARNING: {
       return "warning";
     }
-  case A68_SCANNER_ERROR: {
+  case A68G_SCANNER_ERROR: {
       return "scanner error";
     }
-  case A68_SCANNER_WARNING: {
+  case A68G_SCANNER_WARNING: {
       return "scanner warning";
     }
   default: {
@@ -454,13 +454,13 @@ void write_diagnostic (int sev, char *b)
   char txt[SMALL_BUFFER_SIZE];
   char *severity = get_severity (sev);
   if (severity == NO_TEXT) {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s.", A68 (a68g_cmd_name), b) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: %s.", A68G (a68g_cmd_name), b) >= 0);
   } else {
     a68g_bufcpy (txt, get_severity (sev), SMALL_BUFFER_SIZE);
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s: %s.", A68 (a68g_cmd_name), txt, b) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: %s: %s.", A68G (a68g_cmd_name), txt, b) >= 0);
   }
   io_close_tty_line ();
-  pretty_diag (A68_STDERR, A68 (output_line));
+  pretty_diag (A68G_STDERR, A68G (output_line));
 }
 
 //! @brief Add diagnostic to source line.
@@ -477,7 +477,7 @@ void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
   if (line == NO_LINE && p == NO_NODE) {
     return;
   }
-  if (A68 (in_monitor)) {
+  if (A68G (in_monitor)) {
     monitor_error (b, NO_TEXT);
     return;
   }
@@ -499,7 +499,7 @@ void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
   if (p != NO_NODE) {
     NODE_T *n = NEST (p);
     if (n != NO_NODE && NSYMBOL (n) != NO_TEXT) {
-      char *nt = non_terminal_string (A68 (edit_line), ATTRIBUTE (n));
+      char *nt = non_terminal_string (A68G (edit_line), ATTRIBUTE (n));
       if (nt != NO_TEXT) {
         if (LINE_NUMBER (n) == 0) {
           ASSERT (a68g_bufprt (nst, SNPRINTF_SIZE, ", in %s", nt) >= 0);
@@ -522,21 +522,21 @@ void add_diagnostic (LINE_T * line, char *pos, NODE_T * p, int sev, char *b)
     }
   }
   if (severity == NO_TEXT) {
-    if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68_JOB), FILENAME (line)) == 0) {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68g_cmd_name), (unt) k, b) >= 0);
+    if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68G_JOB), FILENAME (line)) == 0) {
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68G (a68g_cmd_name), (unt) k, b) >= 0);
     } else if (FILENAME (line) != NO_TEXT) {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), FILENAME (line), (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68G (a68g_cmd_name), FILENAME (line), (unt) k, b) >= 0);
     } else {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68 (a68g_cmd_name), (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %x: %s", A68G (a68g_cmd_name), (unt) k, b) >= 0);
     }
   } else {
     a68g_bufcpy (st, get_severity (sev), SMALL_BUFFER_SIZE);
-    if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68_JOB), FILENAME (line)) == 0) {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), st, (unt) k, b) >= 0);
+    if (FILENAME (line) != NO_TEXT && strcmp (FILE_SOURCE_NAME (&A68G_JOB), FILENAME (line)) == 0) {
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68G (a68g_cmd_name), st, (unt) k, b) >= 0);
     } else if (FILENAME (line) != NO_TEXT) {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %s: %x: %s", A68 (a68g_cmd_name), FILENAME (line), st, (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %s: %x: %s", A68G (a68g_cmd_name), FILENAME (line), st, (unt) k, b) >= 0);
     } else {
-      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68 (a68g_cmd_name), st, (unt) k, b) >= 0);
+      ASSERT (a68g_bufprt (a, SNPRINTF_SIZE, "%s: %s: %x: %s", A68G (a68g_cmd_name), st, (unt) k, b) >= 0);
     }
   }
 // cppcheck might complain here but this memory is not returned, for obvious reasons.
@@ -561,11 +561,11 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
   va_list args;
   MOID_T *moid = NO_MOID;
   char *t = loc_str, b[BUFFER_SIZE];
-  BOOL_T force, compose = A68_TRUE, issue = A68_TRUE;
+  BOOL_T force, compose = A68G_TRUE, issue = A68G_TRUE;
   va_start (args, loc_str);
   b[0] = NULL_CHAR;
-  force = (BOOL_T) ((sev & A68_FORCE_DIAGNOSTICS) != 0);
-  sev &= ~A68_FORCE_DIAGNOSTICS;
+  force = (BOOL_T) ((sev & A68G_FORCE_DIAGNOSTICS) != 0);
+  sev &= ~A68G_FORCE_DIAGNOSTICS;
 // Node or line?
   LINE_T *line = NO_LINE;
   char *pos = NO_TEXT;
@@ -574,45 +574,45 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
     pos = va_arg (args, char *);
   }
 // No warnings?
-  if (!force && sev == A68_WARNING && OPTION_NO_WARNINGS (&A68_JOB)) {
+  if (!force && sev == A68G_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
     va_end (args);
     return;
   }
-  if (!force && sev == A68_MATH_WARNING && OPTION_NO_WARNINGS (&A68_JOB)) {
+  if (!force && sev == A68G_MATH_WARNING && OPTION_NO_WARNINGS (&A68G_JOB)) {
     va_end (args);
     return;
   }
-  if (sev == A68_WARNING && OPTION_QUIET (&A68_JOB)) {
+  if (sev == A68G_WARNING && OPTION_QUIET (&A68G_JOB)) {
     va_end (args);
     return;
   }
-  if (sev == A68_MATH_WARNING && OPTION_QUIET (&A68_JOB)) {
+  if (sev == A68G_MATH_WARNING && OPTION_QUIET (&A68G_JOB)) {
     va_end (args);
     return;
   }
 // Suppressed?.
-  if (sev == A68_ERROR || sev == A68_SYNTAX_ERROR) {
-    if (ERROR_COUNT (&A68_JOB) == MAX_ERRORS) {
+  if (sev == A68G_ERROR || sev == A68G_SYNTAX_ERROR) {
+    if (ERROR_COUNT (&A68G_JOB) == MAX_ERRORS) {
       a68g_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
-      compose = A68_FALSE;
-      sev = A68_ERROR;
-    } else if (ERROR_COUNT (&A68_JOB) > MAX_ERRORS) {
-      ERROR_COUNT (&A68_JOB)++;
-      compose = issue = A68_FALSE;
+      compose = A68G_FALSE;
+      sev = A68G_ERROR;
+    } else if (ERROR_COUNT (&A68G_JOB) > MAX_ERRORS) {
+      ERROR_COUNT (&A68G_JOB)++;
+      compose = issue = A68G_FALSE;
     }
-  } else if (sev == A68_WARNING || sev == A68_MATH_WARNING) {
-    if (WARNING_COUNT (&A68_JOB) == MAX_ERRORS) {
+  } else if (sev == A68G_WARNING || sev == A68G_MATH_WARNING) {
+    if (WARNING_COUNT (&A68G_JOB) == MAX_ERRORS) {
       a68g_bufcpy (b, "further diagnostics suppressed", BUFFER_SIZE);
-      compose = A68_FALSE;
-    } else if (WARNING_COUNT (&A68_JOB) > MAX_ERRORS) {
-      WARNING_COUNT (&A68_JOB)++;
-      compose = issue = A68_FALSE;
+      compose = A68G_FALSE;
+    } else if (WARNING_COUNT (&A68G_JOB) > MAX_ERRORS) {
+      WARNING_COUNT (&A68G_JOB)++;
+      compose = issue = A68G_FALSE;
     }
   }
   if (compose) {
 // Synthesize diagnostic message.
-    if ((sev & A68_NO_SYNTHESIS) != NULL_MASK) {
-      sev &= ~A68_NO_SYNTHESIS;
+    if ((sev & A68G_NO_SYNTHESIS) != NULL_MASK) {
+      sev &= ~A68G_NO_SYNTHESIS;
       a68g_bufcat (b, t, BUFFER_SIZE);
     } else {
 // Legend for special symbols:
@@ -643,7 +643,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             if (p == NO_NODE) {
               a68g_bufcat (b, "construct", BUFFER_SIZE);
             } else {
-              char *nt = non_terminal_string (A68 (edit_line), ATTRIBUTE (p));
+              char *nt = non_terminal_string (A68G (edit_line), ATTRIBUTE (p));
               if (t != NO_TEXT) {
                 a68g_bufcat (b, nt, BUFFER_SIZE);
               } else {
@@ -652,7 +652,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             }
           } else if (t[0] == 'A') {
             int att = va_arg (args, int);
-            char *nt = non_terminal_string (A68 (edit_line), att);
+            char *nt = non_terminal_string (A68G (edit_line), att);
             if (nt != NO_TEXT) {
               a68g_bufcat (b, nt, BUFFER_SIZE);
             } else {
@@ -660,7 +660,7 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             }
           } else if (t[0] == 'B') {
             int att = va_arg (args, int);
-            KEYWORD_T *nt = find_keyword_from_attribute (A68 (top_keyword), att);
+            KEYWORD_T *nt = find_keyword_from_attribute (A68G (top_keyword), att);
             if (nt != NO_KEYWORD) {
               a68g_bufcat (b, "\"", BUFFER_SIZE);
               a68g_bufcat (b, TEXT (nt), BUFFER_SIZE);
@@ -817,10 +817,10 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
   }
 // Construct a diagnostic message.
   if (issue) {
-    if (sev == A68_WARNING) {
-      WARNING_COUNT (&A68_JOB)++;
+    if (sev == A68G_WARNING) {
+      WARNING_COUNT (&A68G_JOB)++;
     } else {
-      ERROR_COUNT (&A68_JOB)++;
+      ERROR_COUNT (&A68G_JOB)++;
     }
     if (p == NO_NODE) {
       if (line == NO_LINE) {
@@ -830,9 +830,9 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
       }
     } else {
       add_diagnostic (NO_LINE, NO_TEXT, p, sev, b);
-      if (sev == A68_MATH_WARNING && p != NO_NODE && LINE (INFO (p)) != NO_LINE) {
-        write_source_line (A68_STDERR, LINE (INFO (p)), p, A68_TRUE);
-        WRITE (A68_STDERR, NEWLINE_STRING);
+      if (sev == A68G_MATH_WARNING && p != NO_NODE && LINE (INFO (p)) != NO_LINE) {
+        write_source_line (A68G_STDERR, LINE (INFO (p)), p, A68G_TRUE);
+        WRITE (A68G_STDERR, NEWLINE_STRING);
       }
     }
   }
