@@ -30,30 +30,30 @@
 
 void init_heap (void)
 {
-  unt heap_a_size = A68_ALIGN (A68 (heap_size));
-  unt handle_a_size = A68_ALIGN (A68 (handle_pool_size));
-  unt frame_a_size = A68_ALIGN (A68 (frame_stack_size));
-  unt expr_a_size = A68_ALIGN (A68 (expr_stack_size));
-  REAL_T /* sic */ total_size = A68_ALIGN (heap_a_size + handle_a_size + frame_a_size + 2 * expr_a_size);
+  unt heap_a_size = A68G_ALIGN (A68G (heap_size));
+  unt handle_a_size = A68G_ALIGN (A68G (handle_pool_size));
+  unt frame_a_size = A68G_ALIGN (A68G (frame_stack_size));
+  unt expr_a_size = A68G_ALIGN (A68G (expr_stack_size));
+  REAL_T /* sic */ total_size = A68G_ALIGN (heap_a_size + handle_a_size + frame_a_size + 2 * expr_a_size);
   ABEND (OVER_2G (total_size), ERROR_OVER_2G, __func__);
   errno = 0;
-  BYTE_T *core = (BYTE_T *) (A68_ALIGN_T *) a68g_alloc ((size_t) total_size, __func__, __LINE__);
+  BYTE_T *core = (BYTE_T *) (A68G_ALIGN_T *) a68g_alloc ((size_t) total_size, __func__, __LINE__);
   ABEND (core == NO_BYTE, ERROR_OUT_OF_CORE, __func__);
-  A68_HEAP = NO_BYTE;
-  A68_HANDLES = NO_BYTE;
-  A68_STACK = NO_BYTE;
-  A68_SP = 0;
-  A68_FP = 0;
-  A68_HP = 0;
-  A68_GLOBALS = 0;
-  A68_HEAP = &(core[0]);
-  A68_HANDLES = &(A68_HEAP[heap_a_size]);
-  A68_STACK = &(A68_HANDLES[handle_a_size]);
-  A68 (fixed_heap_pointer) = A68_ALIGNMENT;
-  A68 (temp_heap_pointer) = total_size;
-  A68 (frame_start) = 0;
-  A68 (frame_end) = A68 (stack_start) = A68 (frame_start) + frame_a_size;
-  A68 (stack_end) = A68 (stack_start) + expr_a_size;
+  A68G_HEAP = NO_BYTE;
+  A68G_HANDLES = NO_BYTE;
+  A68G_STACK = NO_BYTE;
+  A68G_SP = 0;
+  A68G_FP = 0;
+  A68G_HP = 0;
+  A68G_GLOBALS = 0;
+  A68G_HEAP = &(core[0]);
+  A68G_HANDLES = &(A68G_HEAP[heap_a_size]);
+  A68G_STACK = &(A68G_HANDLES[handle_a_size]);
+  A68G (fixed_heap_pointer) = A68G_ALIGNMENT;
+  A68G (temp_heap_pointer) = total_size;
+  A68G (frame_start) = 0;
+  A68G (frame_end) = A68G (stack_start) = A68G (frame_start) + frame_a_size;
+  A68G (stack_end) = A68G (stack_start) + expr_a_size;
   ABEND (errno != 0, ERROR_ALLOCATION, __func__);
 }
 
@@ -68,7 +68,7 @@ void *a68g_alloc (size_t len, const char *f, int line)
   if (len > 0) {
     void *p = NULL;
     int save = errno;
-    size_t align = sizeof (A68_ALIGN_T);
+    size_t align = sizeof (A68G_ALIGN_T);
     errno = 0;
 #if defined (BUILD_WIN32)
     p = _aligned_malloc (len, align);
@@ -91,7 +91,7 @@ void *a68g_alloc (size_t len, const char *f, int line)
     if (p == (void *) NULL || errno != 0) {
       static BUFFER msg;
       a68g_bufprt (msg, SNPRINTF_SIZE, "cannot allocate %lu bytes; called from function %s, line %d", (long unt) len, f, line);
-      ABEND (A68_TRUE, ERROR_ALLOCATION, msg);
+      ABEND (A68G_TRUE, ERROR_ALLOCATION, msg);
     }
     errno = save;
     return p;
@@ -117,7 +117,7 @@ void a68g_free (void *z)
 BYTE_T *get_heap_space (size_t s)
 {
   ABEND (s == 0, ERROR_INVALID_SIZE, __func__);
-  BYTE_T *z = (BYTE_T *) (A68_ALIGN_T *) a68g_alloc (A68_ALIGN (s), __func__, __LINE__);
+  BYTE_T *z = (BYTE_T *) (A68G_ALIGN_T *) a68g_alloc (A68G_ALIGN (s), __func__, __LINE__);
   ABEND (z == NO_BYTE, ERROR_OUT_OF_CORE, __func__);
   return z;
 }
@@ -176,12 +176,12 @@ char *new_temp_string (char *t)
 
 BYTE_T *get_fixed_heap_space (size_t s)
 {
-  if (A68 (heap_is_fluid)) {
-    BYTE_T *z = HEAP_ADDRESS (A68 (fixed_heap_pointer));
-    A68 (fixed_heap_pointer) += A68_ALIGN ((int) s);
+  if (A68G (heap_is_fluid)) {
+    BYTE_T *z = HEAP_ADDRESS (A68G (fixed_heap_pointer));
+    A68G (fixed_heap_pointer) += A68G_ALIGN ((int) s);
 // Allow for extra storage for diagnostics etcetera 
-    ABEND (A68 (fixed_heap_pointer) >= (A68 (heap_size) - MIN_MEM_SIZE), ERROR_OUT_OF_CORE, __func__);
-    ABEND (((unt) A68 (temp_heap_pointer) - (unt) A68 (fixed_heap_pointer)) <= MIN_MEM_SIZE, ERROR_OUT_OF_CORE, __func__);
+    ABEND (A68G (fixed_heap_pointer) >= (A68G (heap_size) - MIN_MEM_SIZE), ERROR_OUT_OF_CORE, __func__);
+    ABEND (((unt) A68G (temp_heap_pointer) - (unt) A68G (fixed_heap_pointer)) <= MIN_MEM_SIZE, ERROR_OUT_OF_CORE, __func__);
     return z;
   } else {
     return get_heap_space (s);
@@ -192,11 +192,11 @@ BYTE_T *get_fixed_heap_space (size_t s)
 
 BYTE_T *get_temp_heap_space (size_t s)
 {
-  if (A68 (heap_is_fluid)) {
-    A68 (temp_heap_pointer) -= A68_ALIGN ((int) s);
+  if (A68G (heap_is_fluid)) {
+    A68G (temp_heap_pointer) -= A68G_ALIGN ((int) s);
 // Allow for extra storage for diagnostics etcetera.
-    ABEND (((unt) A68 (temp_heap_pointer) - (unt) A68 (fixed_heap_pointer)) <= MIN_MEM_SIZE, ERROR_OUT_OF_CORE, __func__);
-    return HEAP_ADDRESS (A68 (temp_heap_pointer));
+    ABEND (((unt) A68G (temp_heap_pointer) - (unt) A68G (fixed_heap_pointer)) <= MIN_MEM_SIZE, ERROR_OUT_OF_CORE, __func__);
+    return HEAP_ADDRESS (A68G (temp_heap_pointer));
   } else {
     return get_heap_space (s);
   }
@@ -207,23 +207,23 @@ BYTE_T *get_temp_heap_space (size_t s)
 void get_stack_size (void)
 {
 #if defined (BUILD_WIN32)
-  A68 (stack_size) = MEGABYTE;  // Guestimate
+  A68G (stack_size) = MEGABYTE;  // Guestimate
 #else
   errno = 0;
 // Some systems do not implement RLIMIT_STACK so if getrlimit fails, we do not abend.
   struct rlimit limits;
   if (!(getrlimit (RLIMIT_STACK, &limits) == 0 && errno == 0)) {
-    A68 (stack_size) = MEGABYTE;
+    A68G (stack_size) = MEGABYTE;
   }
-  A68 (stack_size) = (unt) (RLIM_CUR (&limits) < RLIM_MAX (&limits) ? RLIM_CUR (&limits) : RLIM_MAX (&limits));
+  A68G (stack_size) = (unt) (RLIM_CUR (&limits) < RLIM_MAX (&limits) ? RLIM_CUR (&limits) : RLIM_MAX (&limits));
 // A heuristic in case getrlimit yields extreme numbers: the frame stack is
 // assumed to fill at a rate comparable to the C stack, so the C stack needs
 // not be larger than the frame stack. This may not be true.
-  if (A68 (stack_size) < KILOBYTE || (A68 (stack_size) > 96 * MEGABYTE && A68 (stack_size) > A68 (frame_stack_size))) {
-    A68 (stack_size) = A68 (frame_stack_size);
+  if (A68G (stack_size) < KILOBYTE || (A68G (stack_size) > 96 * MEGABYTE && A68G (stack_size) > A68G (frame_stack_size))) {
+    A68G (stack_size) = A68G (frame_stack_size);
   }
 #endif
-  A68 (stack_limit) = (A68 (stack_size) > (4 * A68 (storage_overhead)) ? (A68 (stack_size) - A68 (storage_overhead)) : A68 (stack_size) / 2);
+  A68G (stack_limit) = (A68G (stack_size) > (4 * A68G (storage_overhead)) ? (A68G (stack_size) - A68G (storage_overhead)) : A68G (stack_size) / 2);
 }
 
 //! @brief Free heap allocated by genie.
