@@ -34,8 +34,8 @@
 
 #define MAX_INDENT 60
 
-#define ONE_LINER (A68_TRUE)
-#define KEYWORD (A68_TRUE)
+#define ONE_LINER (A68G_TRUE)
+#define KEYWORD (A68G_TRUE)
 #define BLANK {put_str (" ");}
 
 #define IS_OPEN_SYMBOL(p) (IS (p, OPEN_SYMBOL) || IS (p, SUB_SYMBOL) || IS (p, ACCO_SYMBOL))
@@ -51,10 +51,10 @@ void indent_format (NODE_T *);
 
 void put_nl (void)
 {
-  WRITE (A68_INDENT (fd), "\n");
-  for (A68_INDENT (col) = 1; A68_INDENT (col) < A68_INDENT (ind); A68_INDENT (col)++) {
-    if (A68_INDENT (col) <= MAX_INDENT) {
-      WRITE (A68_INDENT (fd), " ");
+  WRITE (A68G_INDENT (fd), "\n");
+  for (A68G_INDENT (col) = 1; A68G_INDENT (col) < A68G_INDENT (ind); A68G_INDENT (col)++) {
+    if (A68G_INDENT (col) <= MAX_INDENT) {
+      WRITE (A68G_INDENT (fd), " ");
     }
   }
 }
@@ -63,8 +63,8 @@ void put_nl (void)
 
 void put_str (char *txt)
 {
-  WRITE (A68_INDENT (fd), txt);
-  A68_INDENT (col) += (int) strlen (txt);
+  WRITE (A68G_INDENT (fd), txt);
+  A68G_INDENT (col) += (int) strlen (txt);
 }
 
 //! @brief Write a character.
@@ -104,13 +104,13 @@ void pretty_pragment (NODE_T * p, BOOL_T keyw)
       put_nl ();
     } else {
       if (!keyw && (int) strlen (NPRAGMENT (p)) < 20) {
-        if (A68_INDENT (col) > A68_INDENT (ind)) {
+        if (A68G_INDENT (col) > A68G_INDENT (ind)) {
           BLANK;
         }
         put_pragment (p);
         BLANK;
       } else {
-        if (A68_INDENT (col) > A68_INDENT (ind)) {
+        if (A68G_INDENT (col) > A68G_INDENT (ind)) {
           put_nl ();
         }
         put_pragment (p);
@@ -226,7 +226,7 @@ void indent_generic_list (NODE_T * p, NODE_T ** what, BOOL_T one_liner)
   for (; p != NULL; FORWARD (p)) {
     if (IS_OPEN_SYMBOL (p)) {
       put_sym (p, KEYWORD);
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
     } else if (IS_CLOSE_SYMBOL (p)) {
       put_sym (p, KEYWORD);
     } else if (IS (p, BEGIN_SYMBOL)) {
@@ -329,9 +329,9 @@ void indent_declarer (NODE_T * p)
     indent_declarer (NEXT (p));
   } else if (IS (p, BOUNDS) || IS (p, FORMAL_BOUNDS)) {
     NODE_T *what = NO_NODE;
-    int pop_ind = A68_INDENT (ind);
+    int pop_ind = A68G_INDENT (ind);
     indent_generic_list (SUB (p), &what, ONE_LINER);
-    A68_INDENT (ind) = pop_ind;
+    A68G_INDENT (ind) = pop_ind;
     BLANK;
     indent_declarer (NEXT (p));
   } else if (IS_STRUCT (p) || IS_UNION (p)) {
@@ -373,30 +373,30 @@ void indent_conditional (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, IF_PART) || IS (p, ELIF_IF_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, THEN_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, ELSE_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, ELIF_PART)) {
       indent_conditional (SUB (p));
@@ -433,30 +433,30 @@ void indent_case (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, CASE_PART) || IS (p, OUSE_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, CASE_IN_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_generic_list (NEXT_SUB (p), &what, ONE_LINER);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, OUT_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, CASE_OUSE_PART)) {
       indent_case (SUB (p));
@@ -499,30 +499,30 @@ void indent_conformity (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, CASE_PART) || IS (p, OUSE_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, CONFORMITY_IN_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_generic_list (NEXT_SUB (p), &what, ONE_LINER);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, OUT_PART)) {
       NODE_T *what = NO_NODE;
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
     } else if (IS (p, CONFORMITY_OUSE_PART)) {
       indent_conformity (SUB (p));
@@ -562,7 +562,7 @@ void indent_conformity (NODE_T * p)
 
 void indent_loop (NODE_T * p)
 {
-  int parts = 0, pop_ind = A68_INDENT (col);
+  int parts = 0, pop_ind = A68G_INDENT (col);
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, FOR_PART)) {
       put_sym (SUB (p), KEYWORD);
@@ -578,26 +578,26 @@ void indent_loop (NODE_T * p)
       parts++;
     } else if (IS (p, WHILE_PART)) {
       NODE_T *what = NO_NODE;
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       if (parts > 0) {
         put_nl ();
       }
       put_sym (SUB (p), KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       indent_serial (NEXT_SUB (p), !ONE_LINER, &what);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       parts++;
     } else if (is_one_of (p, DO_PART, ALT_DO_PART, STOP)) {
       NODE_T *q = SUB (p);
       NODE_T *what = NO_NODE;
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       if (parts > 0) {
         put_nl ();
       }
       put_sym (q, KEYWORD);     // DO
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
       FORWARD (q);
       parts = 0;
       if (IS (q, SERIAL_CLAUSE)) {
@@ -606,18 +606,18 @@ void indent_loop (NODE_T * p)
         parts++;
       }
       if (IS (q, UNTIL_PART)) {
-        int pop_ind2 = A68_INDENT (ind);
+        int pop_ind2 = A68G_INDENT (ind);
         if (parts > 0) {
           put_nl ();
         }
         put_sym (SUB (q), KEYWORD);
         BLANK;
-        A68_INDENT (ind) = A68_INDENT (col);
+        A68G_INDENT (ind) = A68G_INDENT (col);
         indent_serial (NEXT_SUB (q), !ONE_LINER, &what);
-        A68_INDENT (ind) = pop_ind2;
+        A68G_INDENT (ind) = pop_ind2;
         FORWARD (q);
       }
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
       put_nl ();
       put_sym (q, KEYWORD);     // OD
       parts++;
@@ -650,14 +650,14 @@ void indent_closed (NODE_T * p)
     put_sym (NEXT_NEXT (p), KEYWORD);
   } else {
     NODE_T *what = NO_NODE;
-    int pop_ind = A68_INDENT (col);
+    int pop_ind = A68G_INDENT (col);
     put_sym (p, KEYWORD);
     if (IS (p, BEGIN_SYMBOL)) {
       BLANK;
     }
-    A68_INDENT (ind) = A68_INDENT (col);
+    A68G_INDENT (ind) = A68G_INDENT (col);
     indent_serial (SUB_NEXT (p), !ONE_LINER, &what);
-    A68_INDENT (ind) = pop_ind;
+    A68G_INDENT (ind) = pop_ind;
     if (IS (NEXT_NEXT (p), END_SYMBOL)) {
       put_nl ();
     }
@@ -671,14 +671,14 @@ void indent_collateral (NODE_T * p)
 {
   int units = 0, seps = 0;
   NODE_T *what = NO_NODE;
-  int pop_ind = A68_INDENT (col);
+  int pop_ind = A68G_INDENT (col);
   count_stowed (p, &units, &seps);
   if (units <= 3) {
     indent_generic_list (p, &what, ONE_LINER);
   } else {
     indent_generic_list (p, &what, !ONE_LINER);
   }
-  A68_INDENT (ind) = pop_ind;
+  A68G_INDENT (ind) = pop_ind;
 }
 
 //! @brief Indent enclosed clause.
@@ -832,75 +832,75 @@ void indent_format (NODE_T * p)
 BOOL_T indent_folder (NODE_T * p)
 {
   if (MOID (p) == M_INT) {
-    A68_INT k;
-    A68_SP = 0;
+    A68G_INT k;
+    A68G_SP = 0;
     push_unit (p);
-    POP_OBJECT (p, &k, A68_INT);
-    if (ERROR_COUNT (&A68_JOB) == 0) {
-      ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, A68_LD, VALUE (&k)) >= 0);
-      put_str (A68 (output_line));
-      return A68_TRUE;
+    POP_OBJECT (p, &k, A68G_INT);
+    if (ERROR_COUNT (&A68G_JOB) == 0) {
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, A68G_LD, VALUE (&k)) >= 0);
+      put_str (A68G (output_line));
+      return A68G_TRUE;
     } else {
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   } else if (MOID (p) == M_REAL) {
-    A68_REAL x;
+    A68G_REAL x;
     REAL_T conv;
-    A68_SP = 0;
+    A68G_SP = 0;
     push_unit (p);
-    POP_OBJECT (p, &x, A68_REAL);
+    POP_OBJECT (p, &x, A68G_REAL);
 // Mind overflowing or underflowing values.
-    if (ERROR_COUNT (&A68_JOB) != 0) {
-      return A68_FALSE;
-    } else if (VALUE (&x) == A68_REAL_MAX) {
-      return A68_FALSE;
-    } else if (VALUE (&x) == -A68_REAL_MAX) {
-      return A68_FALSE;
+    if (ERROR_COUNT (&A68G_JOB) != 0) {
+      return A68G_FALSE;
+    } else if (VALUE (&x) == A68G_REAL_MAX) {
+      return A68G_FALSE;
+    } else if (VALUE (&x) == -A68G_REAL_MAX) {
+      return A68G_FALSE;
     } else {
-      ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%.*g", A68_REAL_WIDTH, VALUE (&x)) >= 0);
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%.*g", A68G_REAL_WIDTH, VALUE (&x)) >= 0);
       errno = 0;
-      conv = strtod (A68 (output_line), NO_REF);
+      conv = strtod (A68G (output_line), NO_REF);
       if (errno == ERANGE && conv == 0.0) {
         put_str ("0.0");
-        return A68_TRUE;
+        return A68G_TRUE;
       } else if (errno == ERANGE) {
-        return A68_FALSE;
+        return A68G_FALSE;
       } else {
-        if (strchr (A68 (output_line), '.') == NO_TEXT && strchr (A68 (output_line), 'e') == NO_TEXT && strchr (A68 (output_line), 'E') == NO_TEXT) {
-          a68g_bufcat (A68 (output_line), ".0", BUFFER_SIZE);
+        if (strchr (A68G (output_line), '.') == NO_TEXT && strchr (A68G (output_line), 'e') == NO_TEXT && strchr (A68G (output_line), 'E') == NO_TEXT) {
+          a68g_bufcat (A68G (output_line), ".0", BUFFER_SIZE);
         }
-        put_str (A68 (output_line));
-        return A68_TRUE;
+        put_str (A68G (output_line));
+        return A68G_TRUE;
       }
     }
   } else if (MOID (p) == M_BOOL) {
-    A68_BOOL b;
-    A68_SP = 0;
+    A68G_BOOL b;
+    A68G_SP = 0;
     push_unit (p);
-    POP_OBJECT (p, &b, A68_BOOL);
-    if (ERROR_COUNT (&A68_JOB) != 0) {
-      return A68_FALSE;
+    POP_OBJECT (p, &b, A68G_BOOL);
+    if (ERROR_COUNT (&A68G_JOB) != 0) {
+      return A68G_FALSE;
     } else {
-      ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s", (VALUE (&b) ? "TRUE" : "FALSE")) >= 0);
-      put_str (A68 (output_line));
-      return A68_TRUE;
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s", (VALUE (&b) ? "TRUE" : "FALSE")) >= 0);
+      put_str (A68G (output_line));
+      return A68G_TRUE;
     }
   } else if (MOID (p) == M_CHAR) {
-    A68_CHAR c;
-    A68_SP = 0;
+    A68G_CHAR c;
+    A68G_SP = 0;
     push_unit (p);
-    POP_OBJECT (p, &c, A68_CHAR);
-    if (ERROR_COUNT (&A68_JOB) == 0) {
-      return A68_FALSE;
+    POP_OBJECT (p, &c, A68G_CHAR);
+    if (ERROR_COUNT (&A68G_JOB) == 0) {
+      return A68G_FALSE;
     } else if (VALUE (&c) == '\"') {
       put_str ("\"\"\"\"");
-      return A68_TRUE;
+      return A68G_TRUE;
     } else {
-      ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\"%c\"", (int) VALUE (&c)) >= 0);
-      return A68_TRUE;
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "\"%c\"", (int) VALUE (&c)) >= 0);
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Indent statement.
@@ -918,7 +918,7 @@ void indent_statement (NODE_T * p)
       put_nl ();
     }
   }
-  if (A68_INDENT (use_folder) && folder_mode (MOID (p)) && constant_unit (p)) {
+  if (A68G_INDENT (use_folder) && folder_mode (MOID (p)) && constant_unit (p)) {
     if (indent_folder (p)) {
       return;
     };
@@ -945,19 +945,19 @@ void indent_statement (NODE_T * p)
     NODE_T *primary = SUB (p);
     NODE_T *arguments = NEXT (primary);
     NODE_T *what = NO_NODE;
-    int pop_ind = A68_INDENT (col);
+    int pop_ind = A68G_INDENT (col);
     indent_statement (primary);
     BLANK;
     indent_generic_list (arguments, &what, ONE_LINER);
-    A68_INDENT (ind) = pop_ind;
+    A68G_INDENT (ind) = pop_ind;
   } else if (IS (p, SLICE)) {
     NODE_T *primary = SUB (p);
     NODE_T *indexer = NEXT (primary);
     NODE_T *what = NO_NODE;
-    int pop_ind = A68_INDENT (col);
+    int pop_ind = A68G_INDENT (col);
     indent_statement (primary);
     indent_generic_list (indexer, &what, ONE_LINER);
-    A68_INDENT (ind) = pop_ind;
+    A68G_INDENT (ind) = pop_ind;
   } else if (IS (p, SELECTION)) {
     NODE_T *selector = SUB (p);
     NODE_T *secondary = NEXT (selector);
@@ -1095,7 +1095,7 @@ void indent_iddecl (NODE_T * p)
       BLANK;
     } else if (IS (p, DEFINING_IDENTIFIER)) {
       NODE_T *q = p;
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       put_sym (q, !KEYWORD);
       FORWARD (q);
       if (q != NO_NODE) {       // := unit
@@ -1105,7 +1105,7 @@ void indent_iddecl (NODE_T * p)
         FORWARD (q);
         indent_statement (q);
       }
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, COMMA_SYMBOL)) {
       put_sym (p, !KEYWORD);
       BLANK;
@@ -1123,10 +1123,10 @@ void indent_procdecl (NODE_T * p)
     } else if (IS (p, PROC_SYMBOL)) {
       put_sym (p, KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
     } else if (IS (p, DEFINING_IDENTIFIER)) {
       NODE_T *q = p;
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       put_sym (q, !KEYWORD);
       FORWARD (q);
       BLANK;
@@ -1134,7 +1134,7 @@ void indent_procdecl (NODE_T * p)
       BLANK;
       FORWARD (q);
       indent_statement (q);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, COMMA_SYMBOL)) {
       put_sym (p, !KEYWORD);
       put_nl ();
@@ -1152,14 +1152,14 @@ void indent_opdecl (NODE_T * p)
     } else if (IS (p, OP_SYMBOL)) {
       put_sym (p, KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
     } else if (IS (p, OPERATOR_PLAN)) {
       indent_declarer (SUB (p));
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
     } else if (IS (p, DEFINING_OPERATOR)) {
       NODE_T *q = p;
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       put_sym (q, !KEYWORD);
       FORWARD (q);
       BLANK;
@@ -1167,7 +1167,7 @@ void indent_opdecl (NODE_T * p)
       BLANK;
       FORWARD (q);
       indent_statement (q);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, COMMA_SYMBOL)) {
       put_sym (p, !KEYWORD);
       put_nl ();
@@ -1211,10 +1211,10 @@ void indent_modedecl (NODE_T * p)
     } else if (IS (p, MODE_SYMBOL)) {
       put_sym (p, KEYWORD);
       BLANK;
-      A68_INDENT (ind) = A68_INDENT (col);
+      A68G_INDENT (ind) = A68G_INDENT (col);
     } else if (IS (p, DEFINING_INDICANT)) {
       NODE_T *q = p;
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       put_sym (q, !KEYWORD);
       FORWARD (q);
       BLANK;
@@ -1222,7 +1222,7 @@ void indent_modedecl (NODE_T * p)
       BLANK;
       FORWARD (q);
       indent_declarer (q);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, COMMA_SYMBOL)) {
       put_sym (p, !KEYWORD);
       put_nl ();
@@ -1236,25 +1236,25 @@ void indent_declist (NODE_T * p, BOOL_T one_liner)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, IDENTITY_DECLARATION) || IS (p, VARIABLE_DECLARATION)) {
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       indent_iddecl (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, PROCEDURE_DECLARATION) || IS (p, PROCEDURE_VARIABLE_DECLARATION)) {
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       indent_procdecl (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, OPERATOR_DECLARATION) || IS (p, BRIEF_OPERATOR_DECLARATION)) {
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       indent_opdecl (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, PRIORITY_DECLARATION)) {
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       indent_priodecl (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, MODE_DECLARATION)) {
-      int pop_ind = A68_INDENT (ind);
+      int pop_ind = A68G_INDENT (ind);
       indent_modedecl (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, COMMA_SYMBOL)) {
       put_sym (p, !KEYWORD);
       if (one_liner) {
@@ -1274,10 +1274,10 @@ void indent_serial (NODE_T * p, BOOL_T one_liner, NODE_T ** what)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, UNIT) || IS (p, LABELED_UNIT)) {
-      int pop_ind = A68_INDENT (col);
+      int pop_ind = A68G_INDENT (col);
       (*what) = p;
       indent_statement (p);
-      A68_INDENT (ind) = pop_ind;
+      A68G_INDENT (ind) = pop_ind;
     } else if (IS (p, DECLARATION_LIST)) {
       (*what) = p;
       indent_declist (p, one_liner);
@@ -1326,15 +1326,15 @@ void skip_environ (NODE_T * p)
 
 void indenter (MODULE_T * q)
 {
-  A68_INDENT (ind) = 1;
-  A68_INDENT (col) = 1;
-  A68_INDENT (indentation) = OPTION_INDENT (q);
-  A68_INDENT (use_folder) = OPTION_FOLD (q);
-  FILE_PRETTY_FD (q) = open (FILE_PRETTY_NAME (q), O_WRONLY | O_CREAT | O_TRUNC, A68_PROTECTION);
+  A68G_INDENT (ind) = 1;
+  A68G_INDENT (col) = 1;
+  A68G_INDENT (indentation) = OPTION_INDENT (q);
+  A68G_INDENT (use_folder) = OPTION_FOLD (q);
+  FILE_PRETTY_FD (q) = open (FILE_PRETTY_NAME (q), O_WRONLY | O_CREAT | O_TRUNC, A68G_PROTECTION);
   ABEND (FILE_PRETTY_FD (q) == -1, ERROR_ACTION, __func__);
-  FILE_PRETTY_OPENED (q) = A68_TRUE;
-  A68_INDENT (fd) = FILE_PRETTY_FD (q);
+  FILE_PRETTY_OPENED (q) = A68G_TRUE;
+  A68G_INDENT (fd) = FILE_PRETTY_FD (q);
   skip_environ (TOP_NODE (q));
-  ASSERT (close (A68_INDENT (fd)) == 0);
-  FILE_PRETTY_OPENED (q) = A68_FALSE;
+  ASSERT (close (A68G_INDENT (fd)) == 0);
+  FILE_PRETTY_OPENED (q) = A68G_FALSE;
 }
