@@ -38,7 +38,7 @@ void genie_argument (NODE_T * p, NODE_T ** seq)
   for (; p != NO_NODE; FORWARD (p)) {
     if (IS (p, UNIT)) {
       GENIE_UNIT_NO_GC (p);
-      STACK_DNS (p, MOID (p), A68_FP);
+      STACK_DNS (p, MOID (p), A68G_FP);
       SEQUENCE (*seq) = p;
       (*seq) = p;
       return;
@@ -52,10 +52,10 @@ void genie_argument (NODE_T * p, NODE_T ** seq)
 
 //! @brief Evaluate partial call.
 
-void genie_partial_call (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * pmap, A68_PROCEDURE z, ADDR_T pop_sp, ADDR_T pop_fp)
+void genie_partial_call (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * pmap, A68G_PROCEDURE z, ADDR_T pop_sp, ADDR_T pop_fp)
 {
 // Get or make locale for the new procedure descriptor.
-  A68_REF ref; A68_HANDLE *locale;
+  A68G_REF ref; A68G_HANDLE *locale;
   if (LOCALE (&z) == NO_HANDLE) {
     int size = 0;
     for (PACK_T *s = PACK (p_mode); s != NO_PACK; FORWARD (s)) {
@@ -76,7 +76,7 @@ void genie_partial_call (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * p
   PACK_T *s = PACK (p_mode);
   for (PACK_T *t = PACK (pmap); t != NO_PACK && s != NO_PACK; FORWARD (t)) {
 // Skip already initialised arguments.
-    while (u != NULL && VALUE ((A68_BOOL *) & u[0])) {
+    while (u != NULL && VALUE ((A68G_BOOL *) & u[0])) {
       u = &(u[SIZE (M_BOOL) + SIZE (MOID (s))]);
       FORWARD (s);
     }
@@ -87,23 +87,23 @@ void genie_partial_call (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * p
       FORWARD (s);
     } else {
 // Move argument from stack to locale.
-      A68_BOOL w;
+      A68G_BOOL w;
       STATUS (&w) = INIT_MASK;
-      VALUE (&w) = A68_TRUE;
-      *(A68_BOOL *) & u[0] = w;
+      VALUE (&w) = A68G_TRUE;
+      *(A68G_BOOL *) & u[0] = w;
       COPY (&(u[SIZE (M_BOOL)]), v, SIZE (MOID (t)));
       u = &(u[SIZE (M_BOOL) + SIZE (MOID (s))]);
       v = &(v[SIZE (MOID (t))]);
       FORWARD (s);
     }
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   LOCALE (&z) = locale;
 // When closure is complete, push locale onto the stack and call procedure body.
   if (voids == 0) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     u = POINTER (locale);
-    v = STACK_ADDRESS (A68_SP);
+    v = STACK_ADDRESS (A68G_SP);
     for (s = PACK (p_mode); s != NO_PACK; FORWARD (s)) {
       int size = SIZE (MOID (s));
       COPY (v, &u[SIZE (M_BOOL)], size);
@@ -120,17 +120,17 @@ void genie_partial_call (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * p
 
 //! @brief Closure and deproceduring of routines with PARAMSETY.
 
-void genie_call_procedure (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * pmap, A68_PROCEDURE * z, ADDR_T pop_sp, ADDR_T pop_fp)
+void genie_call_procedure (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T * pmap, A68G_PROCEDURE * z, ADDR_T pop_sp, ADDR_T pop_fp)
 {
   if (pmap != M_VOID && p_mode != pmap) {
     genie_partial_call (p, p_mode, pproc, pmap, *z, pop_sp, pop_fp);
   } else if (STATUS (z) & STANDENV_PROC_MASK) {
-    NODE_T *save = A68 (f_entry);
-    A68 (f_entry) = p;
+    NODE_T *save = A68G (f_entry);
+    A68G (f_entry) = p;
     (void) ((*(PROCEDURE (&(BODY (z))))) (p));
-    A68 (f_entry) = save;
+    A68G (f_entry) = save;
   } else if (STATUS (z) & SKIP_PROCEDURE_MASK) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     genie_push_undefined (p, SUB ((MOID (z))));
   } else {
     NODE_T *body = NODE (&(BODY (z)));
@@ -140,13 +140,13 @@ void genie_call_procedure (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T *
 // Copy arguments from stack to frame.
       OPEN_PROC_FRAME (entry, ENVIRON (z));
       INIT_STATIC_FRAME (entry);
-      FRAME_DNS (A68_FP) = pop_fp;
+      FRAME_DNS (A68G_FP) = pop_fp;
       for (PACK_T *args = PACK (p_mode); args != NO_PACK; FORWARD (args)) {
         int size = SIZE (MOID (args));
         COPY ((FRAME_OBJECT (fp0)), STACK_ADDRESS (pop_sp + fp0), size);
         fp0 += size;
       }
-      A68_SP = pop_sp;
+      A68G_SP = pop_sp;
       ARGSIZE (GINFO (p)) = fp0;
 // Interpret routine text.
       if (DIM (p_mode) > 0) {
@@ -157,31 +157,31 @@ void genie_call_procedure (NODE_T * p, MOID_T * p_mode, MOID_T * pproc, MOID_T *
         entry = NEXT_NEXT (entry);
       }
       GENIE_UNIT_TRACE (entry);
-      if (A68_FP == A68_MON (finish_frame_pointer)) {
-        change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK, A68_TRUE);
+      if (A68G_FP == A68G_MON (finish_frame_pointer)) {
+        change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK, A68G_TRUE);
       }
       CLOSE_FRAME;
-      STACK_DNS (p, SUB (p_mode), A68_FP);
+      STACK_DNS (p, SUB (p_mode), A68G_FP);
     } else {
       OPEN_PROC_FRAME (body, ENVIRON (z));
       INIT_STATIC_FRAME (body);
-      FRAME_DNS (A68_FP) = pop_fp;
+      FRAME_DNS (A68G_FP) = pop_fp;
       GENIE_UNIT_TRACE (body);
-      if (A68_FP == A68_MON (finish_frame_pointer)) {
-        change_masks (TOP_NODE (&A68_JOB), BREAKPOINT_INTERRUPT_MASK, A68_TRUE);
+      if (A68G_FP == A68G_MON (finish_frame_pointer)) {
+        change_masks (TOP_NODE (&A68G_JOB), BREAKPOINT_INTERRUPT_MASK, A68G_TRUE);
       }
       CLOSE_FRAME;
-      STACK_DNS (p, SUB (p_mode), A68_FP);
+      STACK_DNS (p, SUB (p_mode), A68G_FP);
     }
   }
 }
 
 //! @brief Call event routine.
 
-void genie_call_event_routine (NODE_T * p, MOID_T * m, A68_PROCEDURE * proc, ADDR_T pop_sp, ADDR_T pop_fp)
+void genie_call_event_routine (NODE_T * p, MOID_T * m, A68G_PROCEDURE * proc, ADDR_T pop_sp, ADDR_T pop_fp)
 {
   if (NODE (&(BODY (proc))) != NO_NODE) {
-    A68_PROCEDURE save = *proc;
+    A68G_PROCEDURE save = *proc;
     set_default_event_procedure (proc);
     genie_call_procedure (p, MOID (&save), m, m, &save, pop_sp, pop_fp);
     (*proc) = save;
@@ -192,17 +192,17 @@ void genie_call_event_routine (NODE_T * p, MOID_T * m, A68_PROCEDURE * proc, ADD
 
 PROP_T genie_call_standenv_quick (NODE_T * p)
 {
-  NODE_T *save = A68 (f_entry);
-  A68 (f_entry) = p;
+  NODE_T *save = A68G (f_entry);
+  A68G (f_entry) = p;
   NODE_T *pr = SUB (p);
   TAG_T *proc = TAX (SOURCE (&GPROP (pr)));
 // Get arguments.
   for (NODE_T *q = SEQUENCE (p); q != NO_NODE; q = SEQUENCE (q)) {
     GENIE_UNIT_NO_GC (q);
-    STACK_DNS (p, MOID (q), A68_FP);
+    STACK_DNS (p, MOID (q), A68G_FP);
   }
   (void) ((*(PROCEDURE (proc))) (p));
-  A68 (f_entry) = save;
+  A68G (f_entry) = save;
   return GPROP (p);
 }
 
@@ -210,12 +210,12 @@ PROP_T genie_call_standenv_quick (NODE_T * p)
 
 PROP_T genie_call_quick (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP, pop_fp = A68_FP;
+  ADDR_T pop_sp = A68G_SP, pop_fp = A68G_FP;
 // Get procedure.
   NODE_T *proc = SUB (p);
   GENIE_UNIT_NO_GC (proc);
-  A68_PROCEDURE z;
-  POP_OBJECT (proc, &z, A68_PROCEDURE);
+  A68G_PROCEDURE z;
+  POP_OBJECT (proc, &z, A68G_PROCEDURE);
   genie_check_initialisation (p, (BYTE_T *) & z, MOID (proc));
 // Get arguments.
   if (SEQUENCE (p) == NO_NODE && !STATUS_TEST (p, SEQUENCE_MASK)) {
@@ -230,7 +230,7 @@ PROP_T genie_call_quick (NODE_T * p)
   } else {
     for (NODE_T *q = SEQUENCE (p); q != NO_NODE; q = SEQUENCE (q)) {
       GENIE_UNIT_NO_GC (q);
-      STACK_DNS (p, MOID (q), A68_FP);
+      STACK_DNS (p, MOID (q), A68G_FP);
     }
   }
   genie_call_procedure (p, MOID (&z), PARTIAL_PROC (GINFO (proc)), PARTIAL_LOCALE (GINFO (proc)), &z, pop_sp, pop_fp);
@@ -241,15 +241,15 @@ PROP_T genie_call_quick (NODE_T * p)
 
 PROP_T genie_call (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP, pop_fp = A68_FP;
+  ADDR_T pop_sp = A68G_SP, pop_fp = A68G_FP;
   PROP_T self;
   UNIT (&self) = genie_call_quick;
   SOURCE (&self) = p;
 // Get procedure.
   NODE_T *proc = SUB (p);
   GENIE_UNIT_NO_GC (proc);
-  A68_PROCEDURE z;
-  POP_OBJECT (proc, &z, A68_PROCEDURE);
+  A68G_PROCEDURE z;
+  POP_OBJECT (proc, &z, A68G_PROCEDURE);
   genie_check_initialisation (p, (BYTE_T *) & z, MOID (proc));
 // Get arguments.
   if (SEQUENCE (p) == NO_NODE && !STATUS_TEST (p, SEQUENCE_MASK)) {
