@@ -46,24 +46,24 @@ PROP_T genie_cast (NODE_T * p)
 
 PROP_T genie_uniting (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MOID_T *u = MOID (p), *v = MOID (SUB (p));
   if (ATTRIBUTE (v) != UNION_SYMBOL) {
     MOID_T *w = unites_to (v, u);
     PUSH_UNION (p, (void *) w);
     GENIE_UNIT (SUB (p));
-    STACK_DNS (p, SUB (v), A68_FP);
+    STACK_DNS (p, SUB (v), A68G_FP);
   } else {
-    A68_UNION *m = (A68_UNION *) STACK_TOP;
+    A68G_UNION *m = (A68G_UNION *) STACK_TOP;
     GENIE_UNIT (SUB (p));
-    STACK_DNS (p, SUB (v), A68_FP);
+    STACK_DNS (p, SUB (v), A68G_FP);
     VALUE (m) = (void *) unites_to ((MOID_T *) VALUE (m), u);
     if (!IS (u, ROWS_SYMBOL) && VALUE (m) == NO_MOID) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, v);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_VALUE_FROM, v);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
   }
-  A68_SP = pop_sp + SIZE (u);
+  A68G_SP = pop_sp + SIZE (u);
   PROP_T self;
   UNIT (&self) = genie_uniting;
   SOURCE (&self) = p;
@@ -87,10 +87,10 @@ void make_constant_widening (NODE_T * p, MOID_T * m, PROP_T * self)
 
 PROP_T genie_widen_int_to_real (NODE_T * p)
 {
-  A68_INT *i = (A68_INT *) STACK_TOP;
-  A68_REAL *z = (A68_REAL *) STACK_TOP;
+  A68G_INT *i = (A68G_INT *) STACK_TOP;
+  A68G_REAL *z = (A68G_REAL *) STACK_TOP;
   GENIE_UNIT (SUB (p));
-  INCREMENT_STACK_POINTER (p, SIZE_ALIGNED (A68_REAL) - SIZE (M_INT));
+  INCREMENT_STACK_POINTER (p, SIZE_ALIGNED (A68G_REAL) - SIZE (M_INT));
   VALUE (z) = (REAL_T) VALUE (i);
   STATUS (z) = INIT_MASK;
   return GPROP (p);
@@ -111,7 +111,7 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_INT, M_LONG_INT)) {
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_int_to_double_int (p);
 #else
     genie_lengthen_int_to_mp (p);
@@ -119,14 +119,14 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_LONG_INT, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_INT, M_LONG_LONG_INT)) {
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_double_int_to_mp (p);
 #else
     genie_lengthen_mp_to_long_mp (p);
 #endif
     make_constant_widening (p, M_LONG_LONG_INT, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_INT, M_LONG_REAL)) {
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     (void) genie_widen_double_int_to_double (p);
 #else
 // 1-1 mapping.
@@ -141,7 +141,7 @@ PROP_T genie_widen (NODE_T * p)
 // REAL widenings.
   else if (COERCE_FROM_TO (p, M_REAL, M_LONG_REAL)) {
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_real_to_double (p);
 #else
     genie_lengthen_real_to_mp (p);
@@ -149,7 +149,7 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_LONG_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_REAL, M_LONG_LONG_REAL)) {
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_double_to_mp (p);
 #else
     genie_lengthen_mp_to_long_mp (p);
@@ -157,14 +157,14 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_LONG_LONG_REAL, &self);
   } else if (COERCE_FROM_TO (p, M_REAL, M_COMPLEX)) {
     GENIE_UNIT (SUB (p));
-    PUSH_VALUE (p, 0.0, A68_REAL);
+    PUSH_VALUE (p, 0.0, A68G_REAL);
     make_constant_widening (p, M_COMPLEX, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_REAL, M_LONG_COMPLEX)) {
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     DOUBLE_NUM_T z;
     z.f = 0.0q;
     GENIE_UNIT (SUB (p));
-    PUSH_VALUE (p, z, A68_LONG_REAL);
+    PUSH_VALUE (p, z, A68G_LONG_REAL);
 #else
     GENIE_UNIT (SUB (p));
     (void) nil_mp (p, DIGITS (M_LONG_REAL));
@@ -177,7 +177,7 @@ PROP_T genie_widen (NODE_T * p)
   } else if (COERCE_FROM_TO (p, M_COMPLEX, M_LONG_COMPLEX)) {
 // COMPLEX widenings.
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_complex_to_double_compl (p);
 #else
     genie_lengthen_complex_to_mp_complex (p);
@@ -185,7 +185,7 @@ PROP_T genie_widen (NODE_T * p)
     make_constant_widening (p, M_LONG_COMPLEX, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_COMPLEX, M_LONG_LONG_COMPLEX)) {
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_double_compl_to_long_mp_complex (p);
 #else
     genie_lengthen_mp_complex_to_long_mp_complex (p);
@@ -194,15 +194,15 @@ PROP_T genie_widen (NODE_T * p)
   } else if (COERCE_FROM_TO (p, M_BITS, M_LONG_BITS)) {
 // BITS widenings.
     GENIE_UNIT (SUB (p));
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     genie_lengthen_bits_to_double_bits (p);
 #else
     genie_lengthen_int_to_mp (p);
 #endif
     make_constant_widening (p, M_LONG_BITS, &self);
   } else if (COERCE_FROM_TO (p, M_LONG_BITS, M_LONG_LONG_BITS)) {
-#if (A68_LEVEL >= 3)
-    ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+#if (A68G_LEVEL >= 3)
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
 #else
     GENIE_UNIT (SUB (p));
     genie_lengthen_mp_to_long_mp (p);
@@ -210,34 +210,34 @@ PROP_T genie_widen (NODE_T * p)
 #endif
   } else if (COERCE_FROM_TO (p, M_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_BITS, M_FLEX_ROW_BOOL)) {
     GENIE_UNIT (SUB (p));
-    A68_BITS x;
-    POP_OBJECT (p, &x, A68_BITS);
-    A68_REF z, row; A68_ARRAY arr; A68_TUPLE tup;
-    NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68_BITS_WIDTH);
-    BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68_BITS_WIDTH - 1);
+    A68G_BITS x;
+    POP_OBJECT (p, &x, A68G_BITS);
+    A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
+    NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68G_BITS_WIDTH);
+    BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68G_BITS_WIDTH - 1);
     UNSIGNED_T bit = 1;
-    for (int k = A68_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
-      STATUS ((A68_BOOL *) base) = INIT_MASK;
-      VALUE ((A68_BOOL *) base) = (BOOL_T) ((VALUE (&x) & bit) != 0 ? A68_TRUE : A68_FALSE);
+    for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
+      STATUS ((A68G_BOOL *) base) = INIT_MASK;
+      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((VALUE (&x) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
     }
     PUSH_REF (p, z);
   } else if (COERCE_FROM_TO (p, M_LONG_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_LONG_BITS, M_FLEX_ROW_BOOL)) {
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     GENIE_UNIT (SUB (p));
-    A68_LONG_BITS x;
-    POP_OBJECT (p, &x, A68_LONG_BITS);
-    A68_REF z, row; A68_ARRAY arr; A68_TUPLE tup;
-    NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68_LONG_BITS_WIDTH);
-    BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68_LONG_BITS_WIDTH - 1);
+    A68G_LONG_BITS x;
+    POP_OBJECT (p, &x, A68G_LONG_BITS);
+    A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
+    NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, A68G_LONG_BITS_WIDTH);
+    BYTE_T *base = ADDRESS (&row) + SIZE (M_BOOL) * (A68G_LONG_BITS_WIDTH - 1);
     UNSIGNED_T bit = 1;
-    for (int k = A68_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
-      STATUS ((A68_BOOL *) base) = INIT_MASK;
-      VALUE ((A68_BOOL *) base) = (BOOL_T) ((LW (VALUE (&x)) & bit) != 0 ? A68_TRUE : A68_FALSE);
+    for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
+      STATUS ((A68G_BOOL *) base) = INIT_MASK;
+      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((LW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
     }
     bit = 1;
-    for (int k = A68_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
-      STATUS ((A68_BOOL *) base) = INIT_MASK;
-      VALUE ((A68_BOOL *) base) = (BOOL_T) ((HW (VALUE (&x)) & bit) != 0 ? A68_TRUE : A68_FALSE);
+    for (int k = A68G_BITS_WIDTH - 1; k >= 0; k--, base -= SIZE (M_BOOL), bit <<= 1) {
+      STATUS ((A68G_BOOL *) base) = INIT_MASK;
+      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((HW (VALUE (&x)) & bit) != 0 ? A68G_TRUE : A68G_FALSE);
     }
     PUSH_REF (p, z);
 #else
@@ -245,23 +245,23 @@ PROP_T genie_widen (NODE_T * p)
     genie_lengthen_long_bits_to_row_bool (p);
 #endif
   } else if (COERCE_FROM_TO (p, M_LONG_LONG_BITS, M_ROW_BOOL) || COERCE_FROM_TO (p, M_LONG_LONG_BITS, M_FLEX_ROW_BOOL)) {
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
     GENIE_UNIT (SUB (p));
     genie_lengthen_long_bits_to_row_bool (p);
 #endif
   } else if (COERCE_FROM_TO (p, M_BYTES, M_ROW_CHAR) || COERCE_FROM_TO (p, M_BYTES, M_FLEX_ROW_CHAR)) {
     GENIE_UNIT (SUB (p));
-    A68_BYTES z;
-    POP_OBJECT (p, &z, A68_BYTES);
-    PUSH_REF (p, c_string_to_row_char (p, VALUE (&z), A68_BYTES_WIDTH));
+    A68G_BYTES z;
+    POP_OBJECT (p, &z, A68G_BYTES);
+    PUSH_REF (p, c_string_to_row_char (p, VALUE (&z), A68G_BYTES_WIDTH));
   } else if (COERCE_FROM_TO (p, M_LONG_BYTES, M_ROW_CHAR) || COERCE_FROM_TO (p, M_LONG_BYTES, M_FLEX_ROW_CHAR)) {
     GENIE_UNIT (SUB (p));
-    A68_LONG_BYTES z;
-    POP_OBJECT (p, &z, A68_LONG_BYTES);
-    PUSH_REF (p, c_string_to_row_char (p, VALUE (&z), A68_LONG_BYTES_WIDTH));
+    A68G_LONG_BYTES z;
+    POP_OBJECT (p, &z, A68G_LONG_BYTES);
+    PUSH_REF (p, c_string_to_row_char (p, VALUE (&z), A68G_LONG_BYTES_WIDTH));
   } else {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_CANNOT_WIDEN, MOID (SUB (p)), MOID (p));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_CANNOT_WIDEN, MOID (SUB (p)), MOID (p));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   return self;
 #undef COERCE_FROM_TO
@@ -274,7 +274,7 @@ void genie_proceduring (NODE_T * p)
   NODE_T *jump = SUB (p);
   NODE_T *q = SUB (jump);
   NODE_T *label = (IS (q, GOTO_SYMBOL) ? NEXT (q) : q);
-  A68_PROCEDURE z;
+  A68G_PROCEDURE z;
   STATUS (&z) = INIT_MASK;
   NODE (&(BODY (&z))) = jump;
   STATIC_LINK_FOR_FRAME (ENVIRON (&z), 1 + TAG_LEX_LEVEL (TAX (label)));
@@ -288,10 +288,10 @@ void genie_proceduring (NODE_T * p)
 PROP_T genie_dereferencing_quick (NODE_T * p)
 {
   BYTE_T *tos = STACK_TOP;
-  A68_REF *z = (A68_REF *) tos;
-  ADDR_T pop_sp = A68_SP;
+  A68G_REF *z = (A68G_REF *) tos;
+  ADDR_T pop_sp = A68G_SP;
   GENIE_UNIT (SUB (p));
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   CHECK_REF (p, *z, MOID (SUB (p)));
   PUSH (p, ADDRESS (z), SIZE (MOID (p)));
   genie_check_initialisation (p, tos, MOID (p));
@@ -304,8 +304,8 @@ PROP_T genie_dereference_frame_identifier (NODE_T * p)
 {
   MOID_T *deref = SUB_MOID (p);
   BYTE_T *tos = STACK_TOP;
-  A68_REF *z;
-  FRAME_GET (z, A68_REF, p);
+  A68G_REF *z;
+  FRAME_GET (z, A68G_REF, p);
   PUSH (p, ADDRESS (z), SIZE (deref));
   genie_check_initialisation (p, tos, deref);
   return GPROP (p);
@@ -317,8 +317,8 @@ PROP_T genie_dereference_generic_identifier (NODE_T * p)
 {
   MOID_T *deref = SUB_MOID (p);
   BYTE_T *tos = STACK_TOP;
-  A68_REF *z;
-  FRAME_GET (z, A68_REF, p);
+  A68G_REF *z;
+  FRAME_GET (z, A68G_REF, p);
   CHECK_REF (p, *z, MOID (SUB (p)));
   PUSH (p, ADDRESS (z), SIZE (deref));
   genie_check_initialisation (p, tos, deref);
@@ -330,28 +330,28 @@ PROP_T genie_dereference_generic_identifier (NODE_T * p)
 PROP_T genie_dereference_slice_name_quick (NODE_T * p)
 {
   MOID_T *ref_m = MOID (p); MOID_T *deref_m = SUB (ref_m);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
 // Get REF [] and [].
   BYTE_T *tos = STACK_TOP;
-  A68_REF *z = (A68_REF *) tos;
+  A68G_REF *z = (A68G_REF *) tos;
   GENIE_UNIT (SUB (p));
   CHECK_REF (p, *z, ref_m);
-  A68_ARRAY *arr; A68_TUPLE *tup;
-  GET_DESCRIPTOR (arr, tup, DEREF (A68_ROW, z));
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
+  GET_DESCRIPTOR (arr, tup, DEREF (A68G_ROW, z));
 // Compute index.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   int index = 0;
   for (NODE_T *q = SEQUENCE (p); q != NO_NODE; q = SEQUENCE (q)) {
-    A68_INT *j = (A68_INT *) STACK_TOP;
+    A68G_INT *j = (A68G_INT *) STACK_TOP;
     GENIE_UNIT (q);
     int k = VALUE (j);
     if (k < LWB (tup) || k > UPB (tup)) {
-      diagnostic (A68_RUNTIME_ERROR, q, ERROR_INDEX_OUT_OF_BOUNDS);
-      exit_genie (q, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, q, ERROR_INDEX_OUT_OF_BOUNDS);
+      exit_genie (q, A68G_RUNTIME_ERROR);
     }
     index += (SPAN (tup) * k - SHIFT (tup));
     tup++;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
   }
 // Push element.
   PUSH (p, &((ADDRESS (&(ARRAY (arr))))[ROW_ELEMENT (arr, index)]), SIZE (deref_m));
@@ -367,12 +367,12 @@ PROP_T genie_dereference_selection_name_quick (NODE_T * p)
   MOID_T *struct_m = MOID (NEXT (selector));
   MOID_T *result_m = SUB_MOID (selector);
   BYTE_T *tos = STACK_TOP;
-  A68_REF *z = (A68_REF *) tos;
-  ADDR_T pop_sp = A68_SP;
+  A68G_REF *z = (A68G_REF *) tos;
+  ADDR_T pop_sp = A68G_SP;
   GENIE_UNIT (NEXT (selector));
   CHECK_REF (selector, *z, struct_m);
   OFFSET (z) += OFFSET (NODE_PACK (SUB (selector)));
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   PUSH (p, ADDRESS (z), SIZE (result_m));
   genie_check_initialisation (p, tos, result_m);
   return GPROP (p);
@@ -383,8 +383,8 @@ PROP_T genie_dereference_selection_name_quick (NODE_T * p)
 PROP_T genie_dereferencing (NODE_T * p)
 {
   PROP_T self;
-  GENIE_UNIT_2 (SUB (p), self);
-  A68_REF z;
+  GENIE_UNIT_KEEP (SUB (p), self);
+  A68G_REF z;
   POP_REF (p, &z);
   CHECK_REF (p, z, MOID (SUB (p)));
   PUSH (p, ADDRESS (&z), SIZE (MOID (p)));
@@ -419,13 +419,13 @@ PROP_T genie_deproceduring (NODE_T * p)
   UNIT (&self) = genie_deproceduring;
   SOURCE (&self) = p;
 // Get procedure.
-  ADDR_T pop_sp = A68_SP, pop_fp = A68_FP;
-  A68_PROCEDURE *z = (A68_PROCEDURE *) STACK_TOP;
+  ADDR_T pop_sp = A68G_SP, pop_fp = A68G_FP;
+  A68G_PROCEDURE *z = (A68G_PROCEDURE *) STACK_TOP;
   GENIE_UNIT (proc);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   genie_check_initialisation (p, (BYTE_T *) z, proc_m);
   genie_call_procedure (p, proc_m, proc_m, M_VOID, z, pop_sp, pop_fp);
-  STACK_DNS (p, MOID (p), A68_FP);
+  STACK_DNS (p, MOID (p), A68G_FP);
   return self;
 }
 
@@ -434,10 +434,10 @@ PROP_T genie_deproceduring (NODE_T * p)
 PROP_T genie_voiding (NODE_T * p)
 {
   PROP_T self, source;
-  ADDR_T sp_for_voiding = A68_SP;
+  ADDR_T sp_for_voiding = A68G_SP;
   SOURCE (&self) = p;
-  GENIE_UNIT_2 (SUB (p), source);
-  A68_SP = sp_for_voiding;
+  GENIE_UNIT_KEEP (SUB (p), source);
+  A68G_SP = sp_for_voiding;
   if (UNIT (&source) == genie_assignation_quick) {
     UNIT (&self) = genie_voiding_assignation;
     SOURCE (&self) = SOURCE (&source);
