@@ -36,28 +36,28 @@ void genie_identity_dec (NODE_T * p)
     if (ISNT (p, DEFINING_IDENTIFIER)) {
       genie_identity_dec (SUB (p));
     } else {
-      A68_REF loc;
+      A68G_REF loc;
       NODE_T *src = NEXT_NEXT (p);
       MOID_T *src_mode = MOID (p);
       unt size = (unt) SIZE (src_mode);
       BYTE_T *tos = STACK_TOP;
-      ADDR_T pop_sp = A68_SP;
-      ADDR_T pop_dns = FRAME_DNS (A68_FP);
-      FRAME_DNS (A68_FP) = A68_FP;
+      ADDR_T pop_sp = A68G_SP;
+      ADDR_T pop_dns = FRAME_DNS (A68G_FP);
+      FRAME_DNS (A68G_FP) = A68G_FP;
       GENIE_UNIT_TRACE (src);
       genie_check_initialisation (src, tos, src_mode);
-      STACK_DNS (src, src_mode, A68_FP);
-      FRAME_DNS (A68_FP) = pop_dns;
+      STACK_DNS (src, src_mode, A68G_FP);
+      FRAME_DNS (A68G_FP) = pop_dns;
 // Make a temporary REF to the object in the frame.
       STATUS (&loc) = (STATUS_MASK_T) (INIT_MASK | IN_FRAME_MASK);
-      REF_HANDLE (&loc) = (A68_HANDLE *) & nil_handle;
-      OFFSET (&loc) = A68_FP + FRAME_INFO_SIZE + OFFSET (TAX (p));
-      REF_SCOPE (&loc) = A68_FP;
+      REF_HANDLE (&loc) = (A68G_HANDLE *) & nil_handle;
+      OFFSET (&loc) = A68G_FP + FRAME_INFO_SIZE + OFFSET (TAX (p));
+      REF_SCOPE (&loc) = A68G_FP;
       ABEND (ADDRESS (&loc) != FRAME_OBJECT (OFFSET (TAX (p))), ERROR_INTERNAL_CONSISTENCY, __func__);
 // Initialise the tag, value is in the stack.
       if (HAS_ROWS (src_mode)) {
-        A68_SP = pop_sp;
-        genie_clone_stack (p, src_mode, &loc, (A68_REF *) & nil_ref);
+        A68G_SP = pop_sp;
+        genie_clone_stack (p, src_mode, &loc, (A68G_REF *) & nil_ref);
       } else if (UNIT (&GPROP (src)) == genie_constant) {
         STATUS_SET (TAX (p), CONSTANT_MASK);
         POP_ALIGNED (p, ADDRESS (&loc), size);
@@ -86,20 +86,20 @@ void genie_variable_dec (NODE_T * p, NODE_T ** declarer, ADDR_T sp)
         MOID_T *ref_mode = MOID (p);
         TAG_T *tag = TAX (p);
         LEAP_T leap = (HEAP (tag) == LOC_SYMBOL ? LOC_SYMBOL : HEAP_SYMBOL);
-        A68_REF *z;
+        A68G_REF *z;
         MOID_T *src_mode = SUB_MOID (p);
-        z = (A68_REF *) (FRAME_OBJECT (OFFSET (TAX (p))));
+        z = (A68G_REF *) (FRAME_OBJECT (OFFSET (TAX (p))));
         genie_generator_internal (*declarer, ref_mode, BODY (tag), leap, sp);
         POP_REF (p, z);
         if (NEXT (p) != NO_NODE && IS (NEXT (p), ASSIGN_SYMBOL)) {
           NODE_T *src = NEXT_NEXT (p);
-          ADDR_T pop_sp = A68_SP;
-          ADDR_T pop_dns = FRAME_DNS (A68_FP);
-          FRAME_DNS (A68_FP) = A68_FP;
+          ADDR_T pop_sp = A68G_SP;
+          ADDR_T pop_dns = FRAME_DNS (A68G_FP);
+          FRAME_DNS (A68G_FP) = A68G_FP;
           GENIE_UNIT_TRACE (src);
-          STACK_DNS (src, src_mode, A68_FP);
-          FRAME_DNS (A68_FP) = pop_dns;
-          A68_SP = pop_sp;
+          STACK_DNS (src, src_mode, A68G_FP);
+          FRAME_DNS (A68G_FP) = pop_dns;
+          A68G_SP = pop_sp;
           if (HAS_ROWS (src_mode)) {
             genie_clone_stack (p, src_mode, z, z);
           } else {
@@ -118,25 +118,25 @@ void genie_proc_variable_dec (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     switch (ATTRIBUTE (p)) {
     case DEFINING_IDENTIFIER: {
-        ADDR_T sp_for_voiding = A68_SP;
+        ADDR_T sp_for_voiding = A68G_SP;
         MOID_T *ref_mode = MOID (p);
         TAG_T *tag = TAX (p);
         LEAP_T leap = (HEAP (tag) == LOC_SYMBOL ? LOC_SYMBOL : HEAP_SYMBOL);
-        A68_REF *z = (A68_REF *) (FRAME_OBJECT (OFFSET (TAX (p))));
-        genie_generator_internal (p, ref_mode, BODY (tag), leap, A68_SP);
+        A68G_REF *z = (A68G_REF *) (FRAME_OBJECT (OFFSET (TAX (p))));
+        genie_generator_internal (p, ref_mode, BODY (tag), leap, A68G_SP);
         POP_REF (p, z);
         if (NEXT (p) != NO_NODE && IS (NEXT (p), ASSIGN_SYMBOL)) {
           MOID_T *src_mode = SUB_MOID (p);
-          ADDR_T pop_sp = A68_SP;
-          ADDR_T pop_dns = FRAME_DNS (A68_FP);
-          FRAME_DNS (A68_FP) = A68_FP;
+          ADDR_T pop_sp = A68G_SP;
+          ADDR_T pop_dns = FRAME_DNS (A68G_FP);
+          FRAME_DNS (A68G_FP) = A68G_FP;
           GENIE_UNIT_TRACE (NEXT_NEXT (p));
-          STACK_DNS (p, SUB (ref_mode), A68_FP);
-          FRAME_DNS (A68_FP) = pop_dns;
-          A68_SP = pop_sp;
+          STACK_DNS (p, SUB (ref_mode), A68G_FP);
+          FRAME_DNS (A68G_FP) = pop_dns;
+          A68G_SP = pop_sp;
           MOVE (ADDRESS (z), STACK_TOP, (unt) SIZE (src_mode));
         }
-        A68_SP = sp_for_voiding;        // Voiding
+        A68G_SP = sp_for_voiding;        // Voiding
         return;
       }
     default: {
@@ -154,12 +154,12 @@ void genie_operator_dec (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     switch (ATTRIBUTE (p)) {
     case DEFINING_OPERATOR: {
-        A68_PROCEDURE *z = (A68_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (p))));
-        ADDR_T pop_dns = FRAME_DNS (A68_FP);
-        FRAME_DNS (A68_FP) = A68_FP;
+        A68G_PROCEDURE *z = (A68G_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (p))));
+        ADDR_T pop_dns = FRAME_DNS (A68G_FP);
+        FRAME_DNS (A68G_FP) = A68G_FP;
         GENIE_UNIT_TRACE (NEXT_NEXT (p));
-        STACK_DNS (p, MOID (p), A68_FP);
-        FRAME_DNS (A68_FP) = pop_dns;
+        STACK_DNS (p, MOID (p), A68G_FP);
+        FRAME_DNS (A68G_FP) = pop_dns;
         POP_PROCEDURE (p, z);
         return;
       }
@@ -194,16 +194,16 @@ void genie_declaration (NODE_T * p)
       }
     case VARIABLE_DECLARATION: {
         NODE_T *declarer = NO_NODE;
-        ADDR_T pop_sp = A68_SP;
-        genie_variable_dec (SUB (p), &declarer, A68_SP);
+        ADDR_T pop_sp = A68G_SP;
+        genie_variable_dec (SUB (p), &declarer, A68G_SP);
 // Voiding to remove garbage from declarers.
-        A68_SP = pop_sp;
+        A68G_SP = pop_sp;
         break;
       }
     case PROCEDURE_VARIABLE_DECLARATION: {
-        ADDR_T pop_sp = A68_SP;
+        ADDR_T pop_sp = A68G_SP;
         genie_proc_variable_dec (SUB (p));
-        A68_SP = pop_sp;
+        A68G_SP = pop_sp;
         break;
       }
     default: {
