@@ -35,7 +35,7 @@
 PROP_T genie_routine_text (NODE_T * p)
 {
   static PROP_T self;
-  A68_PROCEDURE z = *(A68_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (p))));
+  A68G_PROCEDURE z = *(A68G_PROCEDURE *) (FRAME_OBJECT (OFFSET (TAX (p))));
   PUSH_PROCEDURE (p, z);
   UNIT (&self) = genie_routine_text;
   SOURCE (&self) = p;
@@ -47,7 +47,7 @@ PROP_T genie_routine_text (NODE_T * p)
 PROP_T genie_format_text (NODE_T * p)
 {
   static PROP_T self;
-  A68_FORMAT z = *(A68_FORMAT *) (FRAME_OBJECT (OFFSET (TAX (p))));
+  A68G_FORMAT z = *(A68G_FORMAT *) (FRAME_OBJECT (OFFSET (TAX (p))));
   PUSH_FORMAT (p, z);
   UNIT (&self) = genie_format_text;
   SOURCE (&self) = p;
@@ -83,84 +83,84 @@ PROP_T genie_denotation (NODE_T * p)
   SOURCE (&self) = p;
   if (moid == M_INT) {
 // INT denotation.
-    A68_INT z;
+    A68G_INT z;
     NODE_T *s = IS (SUB (p), SHORTETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     UNIT (&self) = genie_constant;
     STATUS (&z) = INIT_MASK;
     CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE (M_INT));
     SIZE (GINFO (p)) = SIZE (M_INT);
     COPY (CONSTANT (GINFO (p)), &z, SIZE (M_INT));
-    PUSH_VALUE (p, VALUE ((A68_INT *) (CONSTANT (GINFO (p)))), A68_INT);
+    PUSH_VALUE (p, VALUE ((A68G_INT *) (CONSTANT (GINFO (p)))), A68G_INT);
     return self;
   }
   if (moid == M_REAL) {
 // REAL denotation.
-    A68_REAL z;
+    A68G_REAL z;
     NODE_T *s = IS (SUB (p), SHORTETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     STATUS (&z) = INIT_MASK;
     UNIT (&self) = genie_constant;
-    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68_REAL));
-    SIZE (GINFO (p)) = SIZE_ALIGNED (A68_REAL);
-    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68_REAL));
-    PUSH_VALUE (p, VALUE ((A68_REAL *) (CONSTANT (GINFO (p)))), A68_REAL);
+    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68G_REAL));
+    SIZE (GINFO (p)) = SIZE_ALIGNED (A68G_REAL);
+    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68G_REAL));
+    PUSH_VALUE (p, VALUE ((A68G_REAL *) (CONSTANT (GINFO (p)))), A68G_REAL);
     return self;
   }
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
   if (moid == M_LONG_INT) {
 // LONG INT denotation.
-    A68_LONG_INT z;
-    size_t len = (size_t) SIZE_ALIGNED (A68_LONG_INT);
+    A68G_LONG_INT z;
+    size_t len = (size_t) SIZE_ALIGNED (A68G_LONG_INT);
     NODE_T *s = IS (SUB (p), LONGETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     UNIT (&self) = genie_constant;
     STATUS (&z) = INIT_MASK;
     CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) len);
     SIZE (GINFO (p)) = len;
     COPY (CONSTANT (GINFO (p)), &z, len);
-    PUSH_VALUE (p, VALUE ((A68_LONG_INT *) (CONSTANT (GINFO (p)))), A68_LONG_INT);
+    PUSH_VALUE (p, VALUE ((A68G_LONG_INT *) (CONSTANT (GINFO (p)))), A68G_LONG_INT);
     return self;
   }
   if (moid == M_LONG_REAL) {
 // LONG REAL denotation.
-    A68_LONG_REAL z;
+    A68G_LONG_REAL z;
     NODE_T *s = IS (SUB (p), LONGETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     STATUS (&z) = INIT_MASK;
     UNIT (&self) = genie_constant;
-    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68_LONG_REAL));
-    SIZE (GINFO (p)) = SIZE_ALIGNED (A68_LONG_REAL);
-    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68_LONG_REAL));
-    PUSH_VALUE (p, VALUE ((A68_LONG_REAL *) (CONSTANT (GINFO (p)))), A68_LONG_REAL);
+    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68G_LONG_REAL));
+    SIZE (GINFO (p)) = SIZE_ALIGNED (A68G_LONG_REAL);
+    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68G_LONG_REAL));
+    PUSH_VALUE (p, VALUE ((A68G_LONG_REAL *) (CONSTANT (GINFO (p)))), A68G_LONG_REAL);
     return self;
   }
 // LONG BITS denotation.
   if (moid == M_LONG_BITS) {
-    A68_LONG_BITS z;
+    A68G_LONG_BITS z;
     NODE_T *s = IS (SUB (p), LONGETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     UNIT (&self) = genie_constant;
     STATUS (&z) = INIT_MASK;
-    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68_LONG_BITS));
-    SIZE (GINFO (p)) = SIZE_ALIGNED (A68_LONG_BITS);
-    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68_LONG_BITS));
-    PUSH_VALUE (p, VALUE ((A68_LONG_BITS *) (CONSTANT (GINFO (p)))), A68_LONG_BITS);
+    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68G_LONG_BITS));
+    SIZE (GINFO (p)) = SIZE_ALIGNED (A68G_LONG_BITS);
+    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68G_LONG_BITS));
+    PUSH_VALUE (p, VALUE ((A68G_LONG_BITS *) (CONSTANT (GINFO (p)))), A68G_LONG_BITS);
     return self;
   }
 #endif
@@ -175,9 +175,9 @@ PROP_T genie_denotation (NODE_T * p)
       number = SUB (p);
     }
     MP_T *z = nil_mp (p, digits);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     MP_STATUS (z) = (MP_T) INIT_MASK;
     UNIT (&self) = genie_constant;
@@ -197,9 +197,9 @@ PROP_T genie_denotation (NODE_T * p)
       number = SUB (p);
     }
     MP_T *z = nil_mp (p, digits);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     MP_STATUS (z) = (MP_T) INIT_MASK;
     UNIT (&self) = genie_constant;
@@ -210,18 +210,18 @@ PROP_T genie_denotation (NODE_T * p)
   }
   if (moid == M_BITS) {
 // BITS denotation.
-    A68_BITS z;
+    A68G_BITS z;
     NODE_T *s = IS (SUB (p), SHORTETY) ? NEXT_SUB (p) : SUB (p);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     UNIT (&self) = genie_constant;
     STATUS (&z) = INIT_MASK;
-    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68_BITS));
-    SIZE (GINFO (p)) = SIZE_ALIGNED (A68_BITS);
-    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68_BITS));
-    PUSH_VALUE (p, VALUE ((A68_BITS *) (CONSTANT (GINFO (p)))), A68_BITS);
+    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) SIZE_ALIGNED (A68G_BITS));
+    SIZE (GINFO (p)) = SIZE_ALIGNED (A68G_BITS);
+    COPY (CONSTANT (GINFO (p)), &z, SIZE_ALIGNED (A68G_BITS));
+    PUSH_VALUE (p, VALUE ((A68G_BITS *) (CONSTANT (GINFO (p)))), A68G_BITS);
   }
   if (moid == M_LONG_BITS || moid == M_LONG_LONG_BITS) {
 // [LONG] LONG BITS denotation.
@@ -234,9 +234,9 @@ PROP_T genie_denotation (NODE_T * p)
       number = SUB (p);
     }
     MP_T *z = nil_mp (p, digits);
-    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68_FALSE) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (genie_string_to_value_internal (p, moid, NSYMBOL (number), (BYTE_T *) z) == A68G_FALSE) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, moid);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     MP_STATUS (z) = (MP_T) INIT_MASK;
     UNIT (&self) = genie_constant;
@@ -247,28 +247,28 @@ PROP_T genie_denotation (NODE_T * p)
   }
   if (moid == M_BOOL) {
 // BOOL denotation.
-    A68_BOOL z;
-    ASSERT (genie_string_to_value_internal (p, M_BOOL, NSYMBOL (p), (BYTE_T *) & z) == A68_TRUE);
-    PUSH_VALUE (p, VALUE (&z), A68_BOOL);
+    A68G_BOOL z;
+    ASSERT (genie_string_to_value_internal (p, M_BOOL, NSYMBOL (p), (BYTE_T *) & z) == A68G_TRUE);
+    PUSH_VALUE (p, VALUE (&z), A68G_BOOL);
     return self;
   } else if (moid == M_CHAR) {
 // CHAR denotation.
-    PUSH_VALUE (p, TO_UCHAR (NSYMBOL (p)[0]), A68_CHAR);
+    PUSH_VALUE (p, TO_UCHAR (NSYMBOL (p)[0]), A68G_CHAR);
     return self;
   } else if (moid == M_ROW_CHAR) {
 // [] CHAR denotation - permanent string in the heap.
-    A68_REF z;
-    A68_ARRAY *arr;
-    A68_TUPLE *tup;
+    A68G_REF z;
+    A68G_ARRAY *arr;
+    A68G_TUPLE *tup;
     z = c_to_a_string (p, NSYMBOL (p), DEFAULT_WIDTH);
     GET_DESCRIPTOR (arr, tup, &z);
     BLOCK_GC_HANDLE (&z);
     BLOCK_GC_HANDLE (&(ARRAY (arr)));
     UNIT (&self) = genie_constant;
-    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) A68_REF_SIZE);
-    SIZE (GINFO (p)) = A68_REF_SIZE;
-    COPY (CONSTANT (GINFO (p)), &z, A68_REF_SIZE);
-    PUSH_REF (p, *(A68_REF *) (CONSTANT (GINFO (p))));
+    CONSTANT (GINFO (p)) = (void *) get_heap_space ((size_t) A68G_REF_SIZE);
+    SIZE (GINFO (p)) = A68G_REF_SIZE;
+    COPY (CONSTANT (GINFO (p)), &z, A68G_REF_SIZE);
+    PUSH_REF (p, *(A68G_REF *) (CONSTANT (GINFO (p))));
     (void) tup;
     return self;
   }
