@@ -41,7 +41,7 @@ PROP_T genie_frame_identifier (NODE_T * p)
 
 PROP_T genie_identifier_standenv_proc (NODE_T * p)
 {
-  A68_PROCEDURE z;
+  A68G_PROCEDURE z;
   TAG_T *q = TAX (p);
   STATUS (&z) = (STATUS_MASK_T) (INIT_MASK | STANDENV_PROC_MASK);
   PROCEDURE (&(BODY (&z))) = PROCEDURE (q);
@@ -67,7 +67,7 @@ PROP_T genie_identifier (NODE_T * p)
   static PROP_T self;
   TAG_T *q = TAX (p);
   SOURCE (&self) = p;
-  if (A68_STANDENV_PROC (q)) {
+  if (A68G_STANDENV_PROC (q)) {
     if (IS (MOID (q), PROC_SYMBOL)) {
       (void) genie_identifier_standenv_proc (p);
       UNIT (&self) = genie_identifier_standenv_proc;
