@@ -42,41 +42,41 @@ void genie_idle (NODE_T * p)
 
 void genie_unimplemented (NODE_T * p)
 {
-  diagnostic (A68_RUNTIME_ERROR, p, ERROR_UNIMPLEMENTED);
-  exit_genie (p, A68_RUNTIME_ERROR);
+  diagnostic (A68G_RUNTIME_ERROR, p, ERROR_UNIMPLEMENTED);
+  exit_genie (p, A68G_RUNTIME_ERROR);
 }
 
 //! @brief PROC sleep = (INT) INT
 
 void genie_sleep (NODE_T * p)
 {
-  A68_INT secs;
-  POP_OBJECT (p, &secs, A68_INT);
+  A68G_INT secs;
+  POP_OBJECT (p, &secs, A68G_INT);
   int wait = VALUE (&secs);
   PRELUDE_ERROR (wait < 0, p, ERROR_INVALID_ARGUMENT, M_INT);
   while (wait > 0) {
     wait = (int) sleep ((unt) wait);
   }
-  PUSH_VALUE (p, (INT_T) 0, A68_INT);
+  PUSH_VALUE (p, (INT_T) 0, A68G_INT);
 }
 
 //! @brief PROC system = (STRING) INT
 
 void genie_system (NODE_T * p)
 {
-  A68_REF cmd;
+  A68G_REF cmd;
   POP_REF (p, &cmd);
   CHECK_INIT (p, INITIALISED (&cmd), M_STRING);
   int size = 1 + a68g_string_size (p, cmd);
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + size);
-  PUSH_VALUE (p, system (a_to_c_string (p, DEREF (char, &ref_z), cmd)), A68_INT);
+  A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + size);
+  PUSH_VALUE (p, system (a_to_c_string (p, DEREF (char, &ref_z), cmd)), A68G_INT);
 }
 
 //! @brief PROC (PROC VOID) VOID on gc event
 
 void genie_on_gc_event (NODE_T * p)
 {
-  POP_PROCEDURE (p, &A68 (on_gc_event));
+  POP_PROCEDURE (p, &A68G (on_gc_event));
 }
 
 //! @brief Generic procedure for OP AND BECOMES (+:=, -:=, ...).
@@ -86,7 +86,7 @@ void genie_f_and_becomes (NODE_T * p, MOID_T * ref, GPROC * f)
   MOID_T *mode = SUB (ref);
   int size = SIZE (mode);
   BYTE_T *src = STACK_OFFSET (-size), *addr;
-  A68_REF *dst = (A68_REF *) STACK_OFFSET (-size - A68_REF_SIZE);
+  A68G_REF *dst = (A68G_REF *) STACK_OFFSET (-size - A68G_REF_SIZE);
   CHECK_REF (p, *dst, ref);
   addr = ADDRESS (dst);
   PUSH (p, addr, size);
@@ -101,7 +101,7 @@ void genie_f_and_becomes (NODE_T * p, MOID_T * ref, GPROC * f)
 
 void genie_system_heap_pointer (NODE_T * p)
 {
-  PUSH_VALUE (p, (int) (A68_HP), A68_INT);
+  PUSH_VALUE (p, (int) (A68G_HP), A68G_INT);
 }
 
 //! @brief INT system stack pointer
@@ -109,5 +109,5 @@ void genie_system_heap_pointer (NODE_T * p)
 void genie_system_stack_pointer (NODE_T * p)
 {
   BYTE_T stack_offset;
-  PUSH_VALUE (p, (int) (A68 (system_stack_offset) - &stack_offset), A68_INT);
+  PUSH_VALUE (p, (int) (A68G (system_stack_offset) - &stack_offset), A68G_INT);
 }
