@@ -39,28 +39,28 @@
 void genie_directory (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
-    PUSH_VALUE (p, A68_MAX_INT, A68_INT);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
+    PUSH_VALUE (p, A68G_MAX_INT, A68G_INT);
   } else {
     char *dir_name = a_to_c_string (p, buffer, name);
     DIR *dir = opendir (dir_name);
     if (dir == NULL) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     int n = 0;
     struct dirent *entry;
     do {
       entry = readdir (dir);
       if (errno != 0) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       if (entry != NULL) {
         n++;
@@ -68,23 +68,23 @@ void genie_directory (NODE_T * p)
     } while (entry != NULL);
     rewinddir (dir);
     if (errno != 0) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
-    A68_REF z, row; A68_ARRAY arr; A68_TUPLE tup;
+    A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
     NEW_ROW_1D (z, row, arr, tup, M_ROW_STRING, M_STRING, n);
-    A68_REF *base = DEREF (A68_REF, &row);
+    A68G_REF *base = DEREF (A68G_REF, &row);
     for (int k = 0; k < n; k++) {
       entry = readdir (dir);
       if (errno != 0) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       base[k] = c_to_a_string (p, D_NAME (entry), DEFAULT_WIDTH);
     }
     if (closedir (dir) != 0) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     PUSH_REF (p, z);
     a68g_free (buffer);
@@ -101,18 +101,18 @@ void genie_utctime (NODE_T * p)
   if (time (&dt) == (time_t) - 1) {
     (void) empty_row (p, M_ROW_INT);
   } else {
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     struct tm *tod = gmtime (&dt);
-    PUSH_VALUE (p, TM_YEAR (tod) + 1900, A68_INT);
-    PUSH_VALUE (p, TM_MON (tod) + 1, A68_INT);
-    PUSH_VALUE (p, TM_MDAY (tod), A68_INT);
-    PUSH_VALUE (p, TM_HOUR (tod), A68_INT);
-    PUSH_VALUE (p, TM_MIN (tod), A68_INT);
-    PUSH_VALUE (p, TM_SEC (tod), A68_INT);
-    PUSH_VALUE (p, TM_WDAY (tod) + 1, A68_INT);
-    PUSH_VALUE (p, TM_ISDST (tod), A68_INT);
-    A68_REF row = genie_make_row (p, M_INT, 8, pop_sp);
-    A68_SP = pop_sp;
+    PUSH_VALUE (p, TM_YEAR (tod) + 1900, A68G_INT);
+    PUSH_VALUE (p, TM_MON (tod) + 1, A68G_INT);
+    PUSH_VALUE (p, TM_MDAY (tod), A68G_INT);
+    PUSH_VALUE (p, TM_HOUR (tod), A68G_INT);
+    PUSH_VALUE (p, TM_MIN (tod), A68G_INT);
+    PUSH_VALUE (p, TM_SEC (tod), A68G_INT);
+    PUSH_VALUE (p, TM_WDAY (tod) + 1, A68G_INT);
+    PUSH_VALUE (p, TM_ISDST (tod), A68G_INT);
+    A68G_REF row = genie_make_row (p, M_INT, 8, pop_sp);
+    A68G_SP = pop_sp;
     PUSH_REF (p, row);
   }
 }
@@ -125,18 +125,18 @@ void genie_localtime (NODE_T * p)
   if (time (&dt) == (time_t) - 1) {
     (void) empty_row (p, M_ROW_INT);
   } else {
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     struct tm *tod = localtime (&dt);
-    PUSH_VALUE (p, TM_YEAR (tod) + 1900, A68_INT);
-    PUSH_VALUE (p, TM_MON (tod) + 1, A68_INT);
-    PUSH_VALUE (p, TM_MDAY (tod), A68_INT);
-    PUSH_VALUE (p, TM_HOUR (tod), A68_INT);
-    PUSH_VALUE (p, TM_MIN (tod), A68_INT);
-    PUSH_VALUE (p, TM_SEC (tod), A68_INT);
-    PUSH_VALUE (p, TM_WDAY (tod) + 1, A68_INT);
-    PUSH_VALUE (p, TM_ISDST (tod), A68_INT);
-    A68_REF row = genie_make_row (p, M_INT, 8, pop_sp);
-    A68_SP = pop_sp;
+    PUSH_VALUE (p, TM_YEAR (tod) + 1900, A68G_INT);
+    PUSH_VALUE (p, TM_MON (tod) + 1, A68G_INT);
+    PUSH_VALUE (p, TM_MDAY (tod), A68G_INT);
+    PUSH_VALUE (p, TM_HOUR (tod), A68G_INT);
+    PUSH_VALUE (p, TM_MIN (tod), A68G_INT);
+    PUSH_VALUE (p, TM_SEC (tod), A68G_INT);
+    PUSH_VALUE (p, TM_WDAY (tod) + 1, A68G_INT);
+    PUSH_VALUE (p, TM_ISDST (tod), A68G_INT);
+    A68G_REF row = genie_make_row (p, M_INT, 8, pop_sp);
+    A68G_SP = pop_sp;
     PUSH_REF (p, row);
   }
 }
@@ -146,7 +146,7 @@ void genie_localtime (NODE_T * p)
 void genie_rows (NODE_T * p)
 {
   errno = 0;
-  PUSH_VALUE (p, A68 (term_heigth), A68_INT);
+  PUSH_VALUE (p, A68G (term_heigth), A68G_INT);
 }
 
 //! @brief PROC INT columns
@@ -154,7 +154,7 @@ void genie_rows (NODE_T * p)
 void genie_columns (NODE_T * p)
 {
   errno = 0;
-  PUSH_VALUE (p, A68 (term_width), A68_INT);
+  PUSH_VALUE (p, A68G (term_width), A68G_INT);
 }
 
 //! @brief PROC INT argc
@@ -162,7 +162,7 @@ void genie_columns (NODE_T * p)
 void genie_argc (NODE_T * p)
 {
   errno = 0;
-  PUSH_VALUE (p, A68 (argc), A68_INT);
+  PUSH_VALUE (p, A68G (argc), A68G_INT);
 }
 
 //! @brief PROC (INT) STRING argv
@@ -170,10 +170,10 @@ void genie_argc (NODE_T * p)
 void genie_argv (NODE_T * p)
 {
   errno = 0;
-  A68_INT a68g_index;
-  POP_OBJECT (p, &a68g_index, A68_INT);
-  if (VALUE (&a68g_index) >= 1 && VALUE (&a68g_index) <= A68 (argc)) {
-    char *q = A68 (argv)[VALUE (&a68g_index) - 1];
+  A68G_INT a68g_index;
+  POP_OBJECT (p, &a68g_index, A68G_INT);
+  if (VALUE (&a68g_index) >= 1 && VALUE (&a68g_index) <= A68G (argc)) {
+    char *q = A68G (argv)[VALUE (&a68g_index) - 1];
     int n = (int) strlen (q);
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
     while (n > 0 && (IS_SPACE (q[n - 1]) || q[n - 1] == '#')) {
@@ -189,8 +189,8 @@ void genie_argv (NODE_T * p)
 
 int find_good_arg (void)
 {
-  for (int i = 0; i < A68 (argc); i++) {
-    char *q = A68 (argv)[i];
+  for (int i = 0; i < A68G (argc); i++) {
+    char *q = A68G (argv)[i];
     if (strncmp (q, "--script", 8) == 0) {
       return i + 1;
     }
@@ -212,7 +212,7 @@ int find_good_arg (void)
 void genie_a68g_argc (NODE_T * p)
 {
   errno = 0;
-  PUSH_VALUE (p, A68 (argc) - find_good_arg (), A68_INT);
+  PUSH_VALUE (p, A68G (argc) - find_good_arg (), A68G_INT);
 }
 
 //! @brief PROC (INT) STRING a68g_argv
@@ -220,14 +220,14 @@ void genie_a68g_argc (NODE_T * p)
 void genie_a68g_argv (NODE_T * p)
 {
   errno = 0;
-  A68_INT a68g_index;
-  POP_OBJECT (p, &a68g_index, A68_INT);
+  A68G_INT a68g_index;
+  POP_OBJECT (p, &a68g_index, A68G_INT);
   int k = VALUE (&a68g_index);
   if (k > 1) {
     k += find_good_arg ();
   }
-  if (k >= 1 && k <= A68 (argc)) {
-    char *q = A68 (argv)[k - 1];
+  if (k >= 1 && k <= A68G (argc)) {
+    char *q = A68G (argv)[k - 1];
     int n = (int) strlen (q);
 // Allow for spaces ending in # to have A68 comment syntax with '#!'.
     while (n > 0 && (IS_SPACE (q[n - 1]) || q[n - 1] == '#')) {
@@ -245,16 +245,16 @@ void genie_pwd (NODE_T * p)
 {
   errno = 0;
   char *buffer = NO_TEXT;
-  BOOL_T cont = A68_TRUE;
+  BOOL_T cont = A68G_TRUE;
   size_t size = BUFFER_SIZE;
   while (cont) {
     buffer = (char *) a68g_alloc (size, __func__, __LINE__);
     if (buffer == NO_TEXT) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     if (getcwd (buffer, size) == buffer) {
-      cont = A68_FALSE;
+      cont = A68G_FALSE;
     } else {
       a68g_free (buffer);
       cont = (BOOL_T) (errno == 0);
@@ -274,20 +274,20 @@ void genie_pwd (NODE_T * p)
 void genie_cd (NODE_T * p)
 {
   errno = 0;
-  A68_REF dir;
+  A68G_REF dir;
   POP_REF (p, &dir);
   CHECK_INIT (p, INITIALISED (&dir), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, dir)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     int ret = chdir (a_to_c_string (p, buffer, dir));
     if (ret == 0) {
-      PUSH_VALUE (p, 0, A68_INT);
+      PUSH_VALUE (p, 0, A68G_INT);
     } else {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ACCESS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     a68g_free (buffer);
   }
@@ -298,19 +298,19 @@ void genie_cd (NODE_T * p)
 void genie_file_mode (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (unt) (ST_MODE (&status)), A68_BITS);
+      PUSH_VALUE (p, (unt) (ST_MODE (&status)), A68G_BITS);
     } else {
-      PUSH_VALUE (p, 0x0, A68_BITS);
+      PUSH_VALUE (p, 0x0, A68G_BITS);
     }
     a68g_free (buffer);
   }
@@ -321,19 +321,19 @@ void genie_file_mode (NODE_T * p)
 void genie_file_is_block_device (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISBLK (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISBLK (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -344,19 +344,19 @@ void genie_file_is_block_device (NODE_T * p)
 void genie_file_is_char_device (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISCHR (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISCHR (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -367,19 +367,19 @@ void genie_file_is_char_device (NODE_T * p)
 void genie_file_is_directory (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISDIR (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISDIR (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -390,19 +390,19 @@ void genie_file_is_directory (NODE_T * p)
 void genie_file_is_regular (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISREG (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISREG (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -415,19 +415,19 @@ void genie_file_is_regular (NODE_T * p)
 void genie_file_is_fifo (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISFIFO (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISFIFO (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -442,19 +442,19 @@ void genie_file_is_fifo (NODE_T * p)
 void genie_file_is_link (NODE_T * p)
 {
   errno = 0;
-  A68_REF name;
+  A68G_REF name;
   POP_REF (p, &name);
   CHECK_INIT (p, INITIALISED (&name), M_STRING);
   char *buffer = (char *) a68g_alloc ((size_t) (1 + a68g_string_size (p, name)), __func__, __LINE__);
   if (buffer == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_CORE);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     struct stat status;
     if (stat (a_to_c_string (p, buffer, name), &status) == 0) {
-      PUSH_VALUE (p, (BOOL_T) (S_ISLNK (ST_MODE (&status)) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+      PUSH_VALUE (p, (BOOL_T) (S_ISLNK (ST_MODE (&status)) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
     } else {
-      PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+      PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
     }
     a68g_free (buffer);
   }
@@ -464,27 +464,27 @@ void genie_file_is_link (NODE_T * p)
 
 //! @brief Convert [] STRING row to char *vec[].
 
-void convert_string_vector (NODE_T * p, char *vec[], A68_REF row)
+void convert_string_vector (NODE_T * p, char *vec[], A68G_REF row)
 {
   BYTE_T *z = ADDRESS (&row);
-  A68_ARRAY *arr = (A68_ARRAY *) & z[0];
-  A68_TUPLE *tup = (A68_TUPLE *) & z[SIZE_ALIGNED (A68_ARRAY)];
+  A68G_ARRAY *arr = (A68G_ARRAY *) & z[0];
+  A68G_TUPLE *tup = (A68G_TUPLE *) & z[SIZE_ALIGNED (A68G_ARRAY)];
   int k = 0;
   if (get_row_size (tup, DIM (arr)) > 0) {
     BYTE_T *base_addr = DEREF (BYTE_T, &ARRAY (arr));
-    BOOL_T done = A68_FALSE;
+    BOOL_T done = A68G_FALSE;
     initialise_internal_index (tup, DIM (arr));
     while (!done) {
       ADDR_T a68g_index = calculate_internal_index (tup, DIM (arr));
       ADDR_T elem_addr = (a68g_index + SLICE_OFFSET (arr)) * ELEM_SIZE (arr) + FIELD_OFFSET (arr);
       BYTE_T *elem = &base_addr[elem_addr];
-      int size = a68g_string_size (p, *(A68_REF *) elem);
-      CHECK_INIT (p, INITIALISED ((A68_REF *) elem), M_STRING);
+      int size = a68g_string_size (p, *(A68G_REF *) elem);
+      CHECK_INIT (p, INITIALISED ((A68G_REF *) elem), M_STRING);
       vec[k] = (char *) get_heap_space ((size_t) (1 + size));
-      ASSERT (a_to_c_string (p, vec[k], *(A68_REF *) elem) != NO_TEXT);
+      ASSERT (a_to_c_string (p, vec[k], *(A68G_REF *) elem) != NO_TEXT);
       if (k == VECTOR_SIZE - 1) {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_TOO_MANY_ARGUMENTS);
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_TOO_MANY_ARGUMENTS);
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       if (strlen (vec[k]) > 0) {
         k++;
@@ -518,36 +518,36 @@ void genie_reset_errno (NODE_T * p)
 
 void genie_errno (NODE_T * p)
 {
-  PUSH_VALUE (p, errno, A68_INT);
+  PUSH_VALUE (p, errno, A68G_INT);
 }
 
 //! @brief PROC strerror = (INT) STRING
 
 void genie_strerror (NODE_T * p)
 {
-  A68_INT i;
-  POP_OBJECT (p, &i, A68_INT);
+  A68G_INT i;
+  POP_OBJECT (p, &i, A68G_INT);
   PUSH_REF (p, c_to_a_string (p, strerror (VALUE (&i)), DEFAULT_WIDTH));
 }
 
 //! @brief Set up file for usage in pipe.
 
-void set_up_file (NODE_T * p, A68_REF * z, int fd, A68_CHANNEL chan, BOOL_T r_mood, BOOL_T w_mood, int pid)
+void set_up_file (NODE_T * p, A68G_REF * z, int fd, A68G_CHANNEL chan, BOOL_T r_mood, BOOL_T w_mood, int pid)
 {
   *z = heap_generator (p, M_REF_FILE, SIZE (M_FILE));
-  A68_FILE *f = FILE_DEREF (z);
+  A68G_FILE *f = FILE_DEREF (z);
   STATUS (f) = (STATUS_MASK_T) ((pid < 0) ? 0 : INIT_MASK);
   IDENTIFICATION (f) = nil_ref;
   TERMINATOR (f) = nil_ref;
   CHANNEL (f) = chan;
   FD (f) = fd;
   STREAM (&DEVICE (f)) = NO_STREAM;
-  OPENED (f) = A68_TRUE;
-  OPEN_EXCLUSIVE (f) = A68_FALSE;
+  OPENED (f) = A68G_TRUE;
+  OPEN_EXCLUSIVE (f) = A68G_FALSE;
   READ_MOOD (f) = r_mood;
   WRITE_MOOD (f) = w_mood;
-  CHAR_MOOD (f) = A68_TRUE;
-  DRAW_MOOD (f) = A68_FALSE;
+  CHAR_MOOD (f) = A68G_TRUE;
+  DRAW_MOOD (f) = A68G_FALSE;
   FORMAT (f) = nil_format;
   TRANSPUT_BUFFER (f) = get_unblocked_transput_buffer (p);
   STRING (f) = nil_ref;
@@ -560,12 +560,12 @@ void set_up_file (NODE_T * p, A68_REF * z, int fd, A68_CHANNEL chan, BOOL_T r_mo
 void genie_mkpipe (NODE_T * p, int fd_r, int fd_w, int pid)
 {
   errno = 0;
-  A68_REF r, w;
-  set_up_file (p, &r, fd_r, A68 (stand_in_channel), A68_TRUE, A68_FALSE, pid);
-  set_up_file (p, &w, fd_w, A68 (stand_out_channel), A68_FALSE, A68_TRUE, pid);
+  A68G_REF r, w;
+  set_up_file (p, &r, fd_r, A68G (stand_in_channel), A68G_TRUE, A68G_FALSE, pid);
+  set_up_file (p, &w, fd_w, A68G (stand_out_channel), A68G_FALSE, A68G_TRUE, pid);
   PUSH_REF (p, r);
   PUSH_REF (p, w);
-  PUSH_VALUE (p, pid, A68_INT);
+  PUSH_VALUE (p, pid, A68G_INT);
 }
 
 //! @brief Push an environment string.
@@ -573,7 +573,7 @@ void genie_mkpipe (NODE_T * p, int fd_r, int fd_w, int pid)
 void genie_getenv (NODE_T * p)
 {
   errno = 0;
-  A68_REF a_env;
+  A68G_REF a_env;
   POP_REF (p, &a_env);
   CHECK_INIT (p, INITIALISED (&a_env), M_STRING);
   char *z_env = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_env)));
@@ -592,11 +592,11 @@ void genie_getenv (NODE_T * p)
 void genie_fork (NODE_T * p)
 {
 #if defined (BUILD_WIN32)
-  PUSH_VALUE (p, -1, A68_INT);
+  PUSH_VALUE (p, -1, A68G_INT);
 #else
   errno = 0;
   int pid = (int) fork ();
-  PUSH_VALUE (p, pid, A68_INT);
+  PUSH_VALUE (p, pid, A68G_INT);
 #endif
 }
 
@@ -606,7 +606,7 @@ void genie_exec (NODE_T * p)
 {
   errno = 0;
 // Pop parameters.
-  A68_REF a_prog, a_args, a_env;
+  A68G_REF a_prog, a_args, a_env;
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
@@ -617,15 +617,15 @@ void genie_exec (NODE_T * p)
   convert_string_vector (p, argv, a_args);
   convert_string_vector (p, envp, a_env);
   if (argv[0] == NO_TEXT) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   int ret = execve (prog, argv, envp);
 // execve only returns if it fails.
   free_vector (argv);
   free_vector (envp);
   a68g_free (prog);
-  PUSH_VALUE (p, ret, A68_INT);
+  PUSH_VALUE (p, ret, A68G_INT);
 }
 
 //! @brief PROC execve child = (STRING, [] STRING, [] STRING) INT
@@ -633,7 +633,7 @@ void genie_exec (NODE_T * p)
 void genie_exec_sub (NODE_T * p)
 {
   errno = 0;
-  A68_REF a_prog, a_args, a_env;
+  A68G_REF a_prog, a_args, a_env;
 // Pop parameters.
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
@@ -642,12 +642,12 @@ void genie_exec_sub (NODE_T * p)
 #if defined (BUILD_WIN32)
   int pid = -1;
   (void) pid;
-  PUSH_VALUE (p, -1, A68_INT);
+  PUSH_VALUE (p, -1, A68G_INT);
   return;
 #else
   int pid = (int) fork ();
   if (pid == -1) {
-    PUSH_VALUE (p, -1, A68_INT);
+    PUSH_VALUE (p, -1, A68G_INT);
   } else if (pid == 0) {
 // Child process.
     char *prog = (char *) get_heap_space ((size_t) (1 + a68g_string_size (p, a_prog)));
@@ -656,16 +656,16 @@ void genie_exec_sub (NODE_T * p)
     convert_string_vector (p, argv, a_args);
     convert_string_vector (p, envp, a_env);
     if (argv[0] == NO_TEXT) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
     a68g_exit (EXIT_FAILURE);
-    PUSH_VALUE (p, 0, A68_INT);
+    PUSH_VALUE (p, 0, A68G_INT);
   } else {
 // parent process.
-    PUSH_VALUE (p, pid, A68_INT);
+    PUSH_VALUE (p, pid, A68G_INT);
   }
 #endif
 }
@@ -683,7 +683,7 @@ void genie_exec_sub_pipeline (NODE_T * p)
 //        <-R...W<-
 //        pipe ctop
   errno = 0;
-  A68_REF a_prog, a_args, a_env;
+  A68G_REF a_prog, a_args, a_env;
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
   POP_REF (p, &a_prog);
@@ -716,13 +716,13 @@ void genie_exec_sub_pipeline (NODE_T * p)
 // Set up redirection.
     ASSERT (close (ctop_fd[FD_READ]) == 0);
     ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
-    ASSERT (close (A68_STDIN) == 0);
-    ASSERT (close (A68_STDOUT) == 0);
-    ASSERT (dup2 (ptoc_fd[FD_READ], A68_STDIN) != -1);
-    ASSERT (dup2 (ctop_fd[FD_WRITE], A68_STDOUT) != -1);
+    ASSERT (close (A68G_STDIN) == 0);
+    ASSERT (close (A68G_STDOUT) == 0);
+    ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
+    ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
     if (argv[0] == NO_TEXT) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
@@ -749,7 +749,7 @@ void genie_exec_sub_output (NODE_T * p)
 //        <-R...W<-
 //       pipe ctop
   errno = 0;
-  A68_REF a_prog, a_args, a_env, dest;
+  A68G_REF a_prog, a_args, a_env, dest;
   POP_REF (p, &dest);
   POP_REF (p, &a_env);
   POP_REF (p, &a_args);
@@ -757,19 +757,19 @@ void genie_exec_sub_output (NODE_T * p)
 #if !defined (BUILD_UNIX)
   int pid = -1;
   (void) pid;
-  PUSH_VALUE (p, -1, A68_INT);
+  PUSH_VALUE (p, -1, A68G_INT);
   return;
 #else
 // Create the pipes and fork.
   int ptoc_fd[2], ctop_fd[2];
   if ((pipe (ptoc_fd) == -1) || (pipe (ctop_fd) == -1)) {
-    PUSH_VALUE (p, -1, A68_INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   int pid = (int) fork ();
   if (pid == -1) {
 // Fork failure.
-    PUSH_VALUE (p, -1, A68_INT);
+    PUSH_VALUE (p, -1, A68G_INT);
     return;
   }
   if (pid == 0) {
@@ -781,18 +781,18 @@ void genie_exec_sub_output (NODE_T * p)
 // Set up redirection.
     ASSERT (close (ctop_fd[FD_READ]) == 0);
     ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
-    ASSERT (close (A68_STDIN) == 0);
-    ASSERT (close (A68_STDOUT) == 0);
-    ASSERT (dup2 (ptoc_fd[FD_READ], A68_STDIN) != -1);
-    ASSERT (dup2 (ctop_fd[FD_WRITE], A68_STDOUT) != -1);
+    ASSERT (close (A68G_STDIN) == 0);
+    ASSERT (close (A68G_STDOUT) == 0);
+    ASSERT (dup2 (ptoc_fd[FD_READ], A68G_STDIN) != -1);
+    ASSERT (dup2 (ctop_fd[FD_WRITE], A68G_STDOUT) != -1);
     if (argv[0] == NO_TEXT) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_EMPTY_ARGUMENT);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     (void) execve (prog, argv, envp);
 // execve only returns if it fails - end child process.
     a68g_exit (EXIT_FAILURE);
-    PUSH_VALUE (p, -1, A68_INT);
+    PUSH_VALUE (p, -1, A68G_INT);
   } else {
 // Parent process.
     char ch;
@@ -813,11 +813,11 @@ void genie_exec_sub_output (NODE_T * p)
       status = -1;
     }
     if (!IS_NIL (dest)) {
-      *DEREF (A68_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
+      *DEREF (A68G_REF, &dest) = c_to_a_string (p, get_transput_buffer (INPUT_BUFFER), get_transput_buffer_index (INPUT_BUFFER));
     }
     ASSERT (close (ptoc_fd[FD_WRITE]) == 0);
     ASSERT (close (ctop_fd[FD_READ]) == 0);
-    PUSH_VALUE (p, ret, A68_INT);
+    PUSH_VALUE (p, ret, A68G_INT);
   }
 #endif
 }
@@ -829,7 +829,7 @@ void genie_create_pipe (NODE_T * p)
   errno = 0;
   genie_stand_in (p);
   genie_stand_out (p);
-  PUSH_VALUE (p, -1, A68_INT);
+  PUSH_VALUE (p, -1, A68G_INT);
 }
 
 //! @brief PROC wait pid = (INT) VOID
@@ -837,8 +837,8 @@ void genie_create_pipe (NODE_T * p)
 void genie_waitpid (NODE_T * p)
 {
   errno = 0;
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
 #if defined (BUILD_UNIX)
   ASSERT (waitpid ((a68g_pid_t) VALUE (&k), NULL, 0) != -1);
 #endif
