@@ -84,7 +84,7 @@ void moid_to_string_2 (char *b, MOID_T * n, int *w, NODE_T * idf)
     return;
   }
 // Reference to self through REF or PROC.
-  if (is_postulated (A68 (postulates), n)) {
+  if (is_postulated (A68G (postulates), n)) {
     add_to_moid_text (b, "SELF", w);
     return;
   }
@@ -189,13 +189,13 @@ void moid_to_string_2 (char *b, MOID_T * n, int *w, NODE_T * idf)
   } else if (IS_STRUCT (n)) {
     int j = (int) strlen ("STRUCT ()") + (DIM (n) - 1) * (int) strlen (".., ") + (int) strlen ("..");
     if ((*w) >= j) {
-      POSTULATE_T *save = A68 (postulates);
-      make_postulate (&A68 (postulates), n, NO_MOID);
+      POSTULATE_T *save = A68G (postulates);
+      make_postulate (&A68G (postulates), n, NO_MOID);
       add_to_moid_text (b, "STRUCT (", w);
-      pack_to_string (b, PACK (n), w, A68_TRUE, idf);
+      pack_to_string (b, PACK (n), w, A68G_TRUE, idf);
       add_to_moid_text (b, ")", w);
-      free_postulate_list (A68 (postulates), save);
-      A68 (postulates) = save;
+      free_postulate_list (A68G (postulates), save);
+      A68G (postulates) = save;
     } else {
       int k = DIM (n);
       add_to_moid_text (b, "STRUCT (", w);
@@ -207,13 +207,13 @@ void moid_to_string_2 (char *b, MOID_T * n, int *w, NODE_T * idf)
   } else if (IS_UNION (n)) {
     int j = (int) strlen ("UNION ()") + (DIM (n) - 1) * (int) strlen (".., ") + (int) strlen ("..");
     if ((*w) >= j) {
-      POSTULATE_T *save = A68 (postulates);
-      make_postulate (&A68 (postulates), n, NO_MOID);
+      POSTULATE_T *save = A68G (postulates);
+      make_postulate (&A68G (postulates), n, NO_MOID);
       add_to_moid_text (b, "UNION (", w);
-      pack_to_string (b, PACK (n), w, A68_FALSE, idf);
+      pack_to_string (b, PACK (n), w, A68G_FALSE, idf);
       add_to_moid_text (b, ")", w);
-      free_postulate_list (A68 (postulates), save);
-      A68 (postulates) = save;
+      free_postulate_list (A68G (postulates), save);
+      A68G (postulates) = save;
     } else {
       int k = DIM (n);
       add_to_moid_text (b, "UNION (", w);
@@ -232,14 +232,14 @@ void moid_to_string_2 (char *b, MOID_T * n, int *w, NODE_T * idf)
   } else if (IS (n, PROC_SYMBOL) && DIM (n) > 0) {
     int j = (int) strlen ("PROC () ..") + (DIM (n) - 1) * (int) strlen (".., ") + (int) strlen ("..");
     if ((*w) >= j) {
-      POSTULATE_T *save = A68 (postulates);
-      make_postulate (&A68 (postulates), n, NO_MOID);
+      POSTULATE_T *save = A68G (postulates);
+      make_postulate (&A68G (postulates), n, NO_MOID);
       add_to_moid_text (b, "PROC (", w);
-      pack_to_string (b, PACK (n), w, A68_FALSE, idf);
+      pack_to_string (b, PACK (n), w, A68G_FALSE, idf);
       add_to_moid_text (b, ") ", w);
       moid_to_string_2 (b, SUB (n), w, idf);
-      free_postulate_list (A68 (postulates), save);
-      A68 (postulates) = save;
+      free_postulate_list (A68G (postulates), save);
+      A68G (postulates) = save;
     } else {
       int k = DIM (n);
       add_to_moid_text (b, "PROC (", w);
@@ -252,7 +252,7 @@ void moid_to_string_2 (char *b, MOID_T * n, int *w, NODE_T * idf)
     int j = (int) strlen ("()") + (DIM (n) - 1) * (int) strlen (".., ") + (int) strlen ("..");
     if ((*w) >= j) {
       add_to_moid_text (b, "(", w);
-      pack_to_string (b, PACK (n), w, A68_FALSE, idf);
+      pack_to_string (b, PACK (n), w, A68G_FALSE, idf);
       add_to_moid_text (b, ")", w);
     } else {
       int k = DIM (n);
@@ -288,7 +288,7 @@ char *moid_to_string (MOID_T * n, int w, NODE_T * idf)
   if (w >= BUFFER_SIZE) {
     w = BUFFER_SIZE - 1;
   }
-  A68 (postulates) = NO_POSTULATE;
+  A68G (postulates) = NO_POSTULATE;
   if (n != NO_MOID) {
     moid_to_string_2 (a, n, &w, idf);
   } else {
