@@ -25,7 +25,7 @@
 
 #include "a68g.h"
 
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
 
 #include "a68g-prelude.h"
 #include "a68g-mp.h"
@@ -56,7 +56,7 @@ int get_mp_bits_width (const MOID_T * m)
   if (m == M_LONG_BITS) {
     return MP_BITS_WIDTH (LONG_MP_DIGITS);
   } else if (m == M_LONG_LONG_BITS) {
-    return MP_BITS_WIDTH (A68_MP (varying_mp_digits));
+    return MP_BITS_WIDTH (A68G_MP (varying_mp_digits));
   }
   return 0;
 }
@@ -68,7 +68,7 @@ int get_mp_bits_words (const MOID_T * m)
   if (m == M_LONG_BITS) {
     return MP_BITS_WORDS (LONG_MP_DIGITS);
   } else if (m == M_LONG_LONG_BITS) {
-    return MP_BITS_WORDS (A68_MP (varying_mp_digits));
+    return MP_BITS_WORDS (A68G_MP (varying_mp_digits));
   }
   return 0;
 }
@@ -78,7 +78,7 @@ int get_mp_bits_words (const MOID_T * m)
 MP_BITS_T *stack_mp_bits (NODE_T * p, MP_T * z, MOID_T * m)
 {
   int digits = DIGITS (m), words = get_mp_bits_words (m);
-  MP_BITS_T *row = (MP_BITS_T *) STACK_ADDRESS (A68_SP);
+  MP_BITS_T *row = (MP_BITS_T *) STACK_ADDRESS (A68G_SP);
   INCREMENT_STACK_POINTER (p, words * SIZE_ALIGNED (MP_BITS_T));
   MP_T *u = nil_mp (p, digits);
   MP_T *v = nil_mp (p, digits);
@@ -87,8 +87,8 @@ MP_BITS_T *stack_mp_bits (NODE_T * p, MP_T * z, MOID_T * m)
 // Argument check.
   if (MP_DIGIT (u, 1) < 0.0) {
     errno = EDOM;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, m);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, m);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 // Convert radix MP_BITS_RADIX number.
   for (int k = words - 1; k >= 0; k--) {
@@ -107,8 +107,8 @@ MP_BITS_T *stack_mp_bits (NODE_T * p, MP_T * z, MOID_T * m)
   }
   if ((row[0] & ~mask) != 0x0 || MP_DIGIT (u, 1) != 0.0) {
     errno = ERANGE;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, m);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, m);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 // Exit.
   return row;
@@ -119,7 +119,7 @@ MP_BITS_T *stack_mp_bits (NODE_T * p, MP_T * z, MOID_T * m)
 MP_T *pack_mp_bits (NODE_T * p, MP_T * u, MP_BITS_T * row, MOID_T * m)
 {
   int digits = DIGITS (m), words = get_mp_bits_words (m);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
 // Discard excess bits.
   MP_BITS_T mask = 0x1, musk = 0x0;
   MP_T *v = nil_mp (p, digits);
@@ -130,7 +130,7 @@ MP_T *pack_mp_bits (NODE_T * p, MP_T * u, MP_BITS_T * row, MOID_T * m)
     mask |= 0x1;
   }
   row[0] &= mask;
-  for (int k = 1; k < (A68_BITS_WIDTH - MP_BITS_BITS); k++) {
+  for (int k = 1; k < (A68G_BITS_WIDTH - MP_BITS_BITS); k++) {
     musk <<= 1;
   }
   for (int k = 0; k < MP_BITS_BITS; k++) {
@@ -148,7 +148,7 @@ MP_T *pack_mp_bits (NODE_T * p, MP_T * u, MP_BITS_T * row, MOID_T * m)
     }
   }
   MP_STATUS (u) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return u;
 }
 
@@ -160,19 +160,19 @@ UNSIGNED_T mp_to_unt (NODE_T * p, MP_T * z, int digits)
 // could be wider than 2 ** 52.
   int expo = (int) MP_EXPONENT (z);
   if (expo >= digits) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, MOID (p));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, MOID (p));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   UNSIGNED_T sum = 0, weight = 1;
   for (int j = 1 + expo; j >= 1; j--) {
     if ((unt) MP_DIGIT (z, j) > UINT_MAX / weight) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     UNSIGNED_T term = (unt) MP_DIGIT (z, j) * weight;
     if (sum > UINT_MAX - term) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     sum += term;
     weight *= MP_RADIX;
@@ -185,9 +185,9 @@ UNSIGNED_T mp_to_unt (NODE_T * p, MP_T * z, int digits)
 void check_long_bits_value (NODE_T * p, MP_T * u, MOID_T * m)
 {
   if (MP_EXPONENT (u) >= (MP_T) (DIGITS (m) - 1)) {
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     (void) stack_mp_bits (p, u, m);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
   }
 }
 
@@ -200,7 +200,7 @@ void mp_strtou (NODE_T * p, MP_T * z, char *str, MOID_T * m)
   int base = (int) a68g_strtou (str, &radix, 10);
   if (radix != NO_TEXT && TO_UPPER (radix[0]) == TO_UPPER (RADIX_CHAR) && errno == 0) {
     int digits = DIGITS (m);
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     char *q = radix;
     MP_T *v = nil_mp (p, digits);
     MP_T *w = nil_mp (p, digits);
@@ -210,8 +210,8 @@ void mp_strtou (NODE_T * p, MP_T * z, char *str, MOID_T * m)
     SET_MP_ZERO (z, digits);
     SET_MP_ONE (w, digits);
     if (base < 2 || base > 16) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, base);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, base);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     while ((--q) != radix) {
       int digit = char_value (q[0]);
@@ -219,16 +219,16 @@ void mp_strtou (NODE_T * p, MP_T * z, char *str, MOID_T * m)
         (void) mul_mp_digit (p, v, w, (MP_T) digit, digits);
         (void) add_mp (p, z, z, v, digits);
       } else {
-        diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, m);
-        exit_genie (p, A68_RUNTIME_ERROR);
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, m);
+        exit_genie (p, A68G_RUNTIME_ERROR);
       }
       (void) mul_mp_digit (p, w, w, (MP_T) base, digits);
     }
     check_long_bits_value (p, z, m);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
   } else {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, m);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_IN_DENOTATION, m);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
 }
 
@@ -256,8 +256,8 @@ BOOL_T convert_radix_mp (NODE_T * p, MP_T * u, int radix, int width, MOID_T * m,
 
 void genie_lengthen_unt_to_mp (NODE_T * p)
 {
-  A68_BITS k;
-  POP_OBJECT (p, &k, A68_BITS);
+  A68G_BITS k;
+  POP_OBJECT (p, &k, A68G_BITS);
   int digits = DIGITS (M_LONG_INT);
   MP_T *z = nil_mp (p, digits);
   (void) unt_to_mp (p, z, (UNSIGNED_T) VALUE (&k), digits);
@@ -270,12 +270,12 @@ void genie_bin_mp (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
   int size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
 // We convert just for the operand check.
   (void) stack_mp_bits (p, u, mode);
   MP_STATUS (u) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief OP NOT = (LONG BITS) LONG BITS
@@ -284,7 +284,7 @@ void genie_not_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int words = get_mp_bits_words (mode);
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row = stack_mp_bits (p, u, mode);
@@ -292,7 +292,7 @@ void genie_not_mp (NODE_T * p)
     row[k] = ~row[k];
   }
   (void) pack_mp_bits (p, u, row, mode);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief OP SHORTEN = (LONG BITS) BITS
@@ -303,20 +303,20 @@ void genie_shorten_mp_to_bits (NODE_T * p)
   int digits = DIGITS (mode), size = SIZE (mode);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   DECREMENT_STACK_POINTER (p, size);
-  PUSH_VALUE (p, mp_to_unt (p, z, digits), A68_BITS);
+  PUSH_VALUE (p, mp_to_unt (p, z, digits), A68G_BITS);
 }
 
 //! @brief Get bit from LONG BITS.
 
 unt elem_long_bits (NODE_T * p, ADDR_T k, MP_T * z, MOID_T * m)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_BITS_T *words = stack_mp_bits (p, z, m), mask = 0x1;
   k += (MP_BITS_BITS - get_mp_bits_width (m) % MP_BITS_BITS - 1);
   for (int n = 0; n < MP_BITS_BITS - k % MP_BITS_BITS - 1; n++) {
     mask = mask << 1;
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return (words[k / MP_BITS_BITS]) & mask;
 }
 
@@ -326,11 +326,11 @@ void genie_elem_long_bits (NODE_T * p)
 {
   int bits = get_mp_bits_width (M_LONG_BITS), size = SIZE (M_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T w = elem_long_bits (p, VALUE (i), z, M_LONG_BITS);
   DECREMENT_STACK_POINTER (p, size + SIZE (M_INT));
-  PUSH_VALUE (p, (BOOL_T) (w != 0), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (w != 0), A68G_BOOL);
 }
 
 //! @brief OP ELEM = (INT, LONG LONG BITS) BOOL
@@ -339,11 +339,11 @@ void genie_elem_long_mp_bits (NODE_T * p)
 {
   int bits = get_mp_bits_width (M_LONG_LONG_BITS), size = SIZE (M_LONG_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T w = elem_long_bits (p, VALUE (i), z, M_LONG_LONG_BITS);
   DECREMENT_STACK_POINTER (p, size + SIZE (M_INT));
-  PUSH_VALUE (p, (BOOL_T) (w != 0), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (w != 0), A68G_BOOL);
 }
 
 //! @brief Set bit in LONG BITS.
@@ -367,14 +367,14 @@ MP_BITS_T *set_long_bits (NODE_T * p, int k, MP_T * z, MOID_T * m, MP_BITS_T bit
 
 void genie_set_long_bits (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int bits = get_mp_bits_width (M_LONG_BITS), size = SIZE (M_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T *w = set_long_bits (p, VALUE (i), z, M_LONG_BITS, 0x1);
   (void) pack_mp_bits (p, (MP_T *) STACK_ADDRESS (pop_sp - size - SIZE (M_INT)), w, M_LONG_BITS);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, SIZE (M_INT));
 }
 
@@ -382,14 +382,14 @@ void genie_set_long_bits (NODE_T * p)
 
 void genie_set_long_mp_bits (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int bits = get_mp_bits_width (M_LONG_LONG_BITS), size = SIZE (M_LONG_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T *w = set_long_bits (p, VALUE (i), z, M_LONG_LONG_BITS, 0x1);
   (void) pack_mp_bits (p, (MP_T *) STACK_ADDRESS (pop_sp - size - SIZE (M_INT)), w, M_LONG_LONG_BITS);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, SIZE (M_INT));
 }
 
@@ -397,14 +397,14 @@ void genie_set_long_mp_bits (NODE_T * p)
 
 void genie_clear_long_bits (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int bits = get_mp_bits_width (M_LONG_BITS), size = SIZE (M_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T *w = set_long_bits (p, VALUE (i), z, M_LONG_BITS, 0x0);
   (void) pack_mp_bits (p, (MP_T *) STACK_ADDRESS (pop_sp - size - SIZE (M_INT)), w, M_LONG_BITS);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, SIZE (M_INT));
 }
 
@@ -412,14 +412,14 @@ void genie_clear_long_bits (NODE_T * p)
 
 void genie_clear_long_mp_bits (NODE_T * p)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int bits = get_mp_bits_width (M_LONG_LONG_BITS), size = SIZE (M_LONG_LONG_BITS);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
-  A68_INT *i = (A68_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
+  A68G_INT *i = (A68G_INT *) STACK_OFFSET (-(size + SIZE (M_INT)));
   PRELUDE_ERROR (VALUE (i) < 1 || VALUE (i) > bits, p, ERROR_OUT_OF_BOUNDS, M_INT);
   MP_BITS_T *w = set_long_bits (p, VALUE (i), z, M_LONG_LONG_BITS, 0x0);
   (void) pack_mp_bits (p, (MP_T *) STACK_ADDRESS (pop_sp - size - SIZE (M_INT)), w, M_LONG_LONG_BITS);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, SIZE (M_INT));
 }
 
@@ -427,10 +427,10 @@ void genie_clear_long_mp_bits (NODE_T * p)
 
 void genie_long_bits_pack (NODE_T * p)
 {
-  A68_REF z;
+  A68G_REF z;
   POP_REF (p, &z);
   CHECK_REF (p, z, M_ROW_BOOL);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &z);
   int size = ROW_SIZE (tup);
   MOID_T *mode = MOID (p);
@@ -439,13 +439,13 @@ void genie_long_bits_pack (NODE_T * p)
   PRELUDE_ERROR (size < 0 || size > bits, p, ERROR_OUT_OF_BOUNDS, M_ROW_BOOL);
 // Convert so that LWB goes to MSB, so ELEM gives same order as [] BOOL.
   MP_T *sum = nil_mp (p, digits);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *fact = lit_mp (p, 1, 0, digits);
   if (ROW_SIZE (tup) > 0) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
     for (int k = UPB (tup); k >= LWB (tup); k--) {
       int addr = INDEX_1_DIM (arr, tup, k);
-      A68_BOOL *boo = (A68_BOOL *) & (base[addr]);
+      A68G_BOOL *boo = (A68G_BOOL *) & (base[addr]);
       CHECK_INIT (p, INITIALISED (boo), M_BOOL);
       if (VALUE (boo)) {
         (void) add_mp (p, sum, sum, fact, digits);
@@ -453,7 +453,7 @@ void genie_long_bits_pack (NODE_T * p)
       (void) mul_mp_digit (p, fact, fact, (MP_T) 2, digits);
     }
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_STATUS (sum) = (MP_T) INIT_MASK;
 }
 
@@ -461,16 +461,16 @@ void genie_long_bits_pack (NODE_T * p)
 
 void genie_shl_mp (NODE_T * p)
 {
-  A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
+  A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode);
   if (VALUE (&j) >= 0) {
     for (int i = 0; i < VALUE (&j); i++) {
-      BOOL_T carry = A68_FALSE;
+      BOOL_T carry = A68G_FALSE;
       for (int k = words - 1; k >= 0; k--) {
         row_u[k] <<= 1;
         if (carry) {
@@ -482,7 +482,7 @@ void genie_shl_mp (NODE_T * p)
     }
   } else {
     for (int i = 0; i < -VALUE (&j); i++) {
-      BOOL_T carry = A68_FALSE;
+      BOOL_T carry = A68G_FALSE;
       for (int k = 0; k < words; k++) {
         if (carry) {
           row_u[k] |= MP_BITS_RADIX;
@@ -493,15 +493,15 @@ void genie_shl_mp (NODE_T * p)
     }
   }
   (void) pack_mp_bits (p, u, row_u, mode);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief OP SHR = (LONG BITS, INT) LONG BITS
 
 void genie_shr_mp (NODE_T * p)
 {
-  A68_INT *j;
-  POP_OPERAND_ADDRESS (p, j, A68_INT);
+  A68G_INT *j;
+  POP_OPERAND_ADDRESS (p, j, A68G_INT);
   VALUE (j) = -VALUE (j);
   (void) genie_shl_mp (p);      // Conform RR
 }
@@ -512,16 +512,16 @@ void genie_le_long_bits (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
-  BOOL_T result = A68_TRUE;
+  BOOL_T result = A68G_TRUE;
   for (int k = 0; (k < words) && result; k++) {
     result = (BOOL_T) (result & ((row_u[k] | row_v[k]) == row_v[k]));
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
-  PUSH_VALUE (p, (BOOL_T) (result ? A68_TRUE : A68_FALSE), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (result ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
 }
 
 //! @brief OP >= = (LONG BITS, LONG BITS) BOOL
@@ -530,16 +530,16 @@ void genie_ge_long_bits (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
-  BOOL_T result = A68_TRUE;
+  BOOL_T result = A68G_TRUE;
   for (int k = 0; (k < words) && result; k++) {
     result = (BOOL_T) (result & ((row_u[k] | row_v[k]) == row_u[k]));
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, 2 * size);
-  PUSH_VALUE (p, (BOOL_T) (result ? A68_TRUE : A68_FALSE), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) (result ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
 }
 
 //! @brief OP AND = (LONG BITS, LONG BITS) LONG BITS
@@ -548,14 +548,14 @@ void genie_and_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
   for (int k = 0; k < words; k++) {
     row_u[k] &= row_v[k];
   }
   (void) pack_mp_bits (p, u, row_u, mode);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, size);
 }
 
@@ -565,14 +565,14 @@ void genie_or_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
   for (int k = 0; k < words; k++) {
     row_u[k] |= row_v[k];
   }
   (void) pack_mp_bits (p, u, row_u, mode);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, size);
 }
 
@@ -582,14 +582,14 @@ void genie_xor_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
   int size = SIZE (mode), words = get_mp_bits_words (mode);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
   for (int k = 0; k < words; k++) {
     row_u[k] ^= row_v[k];
   }
   (void) pack_mp_bits (p, u, row_u, mode);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   DECREMENT_STACK_POINTER (p, size);
 }
 
@@ -600,11 +600,11 @@ void genie_long_max_bits (NODE_T * p)
   int digits = DIGITS (M_LONG_BITS);
   int width = get_mp_bits_width (M_LONG_BITS);
   MP_T *z = nil_mp (p, digits);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) set_mp (z, (MP_T) 2, 0, digits);
   (void) pow_mp_int (p, z, z, width, digits);
   (void) minus_one_mp (p, z, z, digits);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief LONG LONG BITS long long max bits
@@ -613,11 +613,11 @@ void genie_long_mp_max_bits (NODE_T * p)
 {
   int digits = DIGITS (M_LONG_LONG_BITS), width = get_mp_bits_width (M_LONG_LONG_BITS);
   MP_T *z = nil_mp (p, digits);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) set_mp (z, (MP_T) 2, 0, digits);
   (void) pow_mp_int (p, z, z, width, digits);
   (void) minus_one_mp (p, z, z, digits);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
 }
 
 //! @brief Lengthen LONG BITS to [] BOOL.
@@ -626,12 +626,12 @@ void genie_lengthen_long_bits_to_row_bool (NODE_T * p)
 {
   MOID_T *m = MOID (SUB (p));
   int size = SIZE (m), width = get_mp_bits_width (m), words = get_mp_bits_words (m);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
 // Calculate and convert BITS value.
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *bits = stack_mp_bits (p, x, m);
 // Make [] BOOL.
-  A68_REF z, row; A68_ARRAY arr; A68_TUPLE tup;
+  A68G_REF z, row; A68G_ARRAY arr; A68G_TUPLE tup;
   NEW_ROW_1D (z, row, arr, tup, M_ROW_BOOL, M_BOOL, width);
   PUT_DESCRIPTOR (arr, tup, &z);
   BYTE_T *base = ADDRESS (&row) + (width - 1) * SIZE (M_BOOL);
@@ -639,15 +639,15 @@ void genie_lengthen_long_bits_to_row_bool (NODE_T * p)
   while (k > 0) {
     MP_BITS_T bit = 0x1;
     for (int j = 0; j < MP_BITS_BITS && k >= 0; j++) {
-      STATUS ((A68_BOOL *) base) = INIT_MASK;
-      VALUE ((A68_BOOL *) base) = (BOOL_T) ((bits[words - 1] & bit) ? A68_TRUE : A68_FALSE);
+      STATUS ((A68G_BOOL *) base) = INIT_MASK;
+      VALUE ((A68G_BOOL *) base) = (BOOL_T) ((bits[words - 1] & bit) ? A68G_TRUE : A68G_FALSE);
       base -= SIZE (M_BOOL);
       bit <<= 1;
       k--;
     }
     words--;
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   PUSH_REF (p, z);
 }
 
