@@ -37,9 +37,9 @@ MP_T *erf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     SET_MP_ZERO (z, digs);
     return z;
   } else {
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
 // Note we need double precision!
-    BOOL_T siga = A68_TRUE;
+    BOOL_T siga = A68G_TRUE;
     int sign = MP_SIGN (x);
     int gdigs = FUN_DIGITS (2 * digs);
     MP_T *y_g = nil_mp (p, gdigs);
@@ -80,7 +80,7 @@ MP_T *erf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     if (sign < 0) {
       (void) minus_mp (p, z, z, digs);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -98,14 +98,14 @@ MP_T *erfc_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs;
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
 // Precision adapts to the argument, but not too much.
 // If this is not precise enough, you need more digs
 // in your entire calculation, not just in this routine.
 // Calculate an initial Newton-Raphson estimate while at it.
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
   DOUBLE_T y = ABS (mp_to_double (p, x, digs));
   if (y < erf_double (5.0q)) {
     y = inverf_double (y);
@@ -136,7 +136,7 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) sub_mp (p, y_g, x_g, y_g, gdigs);
   if (MP_SIGN (y_g) >= 0) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
 // Newton-Raphson.
@@ -160,7 +160,7 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
       (void) sub_mp (p, z_g, z_g, f_g, gdigs);
       (void) sub_mp (p, y_g, z_g, y_g, gdigs);
       if (IS_ZERO_MP (y_g)) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
       } else {
         siga = ABS (MP_EXPONENT (y_g)) < digs;
       }
@@ -170,7 +170,7 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   if (sign < 0) {
     (void) minus_mp (p, z, z, digs);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -194,7 +194,7 @@ MP_T *inverfc_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 void mp_gamma_table (NODE_T *p, int digs)
 {
-  if (A68_MP (mp_gamma_size) <= 0) {
+  if (A68G_MP (mp_gamma_size) <= 0) {
     int b = 1;
     int gdigs = GAMMA_PRECISION (digs);
     REAL_T log_lim = -digs * LOG_MP_RADIX, log_error; 
@@ -204,11 +204,11 @@ void mp_gamma_table (NODE_T *p, int digs)
       log_error = -(log10 (b) / 2 + (b + 0.5) * log10 (2 *M_PI));
       b += 1;
     } while (log_error > log_lim);
-    A68_MP (mp_gamma_size) = b;
-    A68_MP (mp_gam_ck) = (MP_T **) get_heap_space ((size_t) ((b + 1) * sizeof (MP_T *)));
-    A68_MP (mp_gam_ck)[0] = (MP_T *) get_heap_space (SIZE_MP (gdigs));
-    (void) mp_pi (p, (A68_MP (mp_gam_ck)[0]), MP_SQRT_TWO_PI, gdigs);
-    ADDR_T pop_sp = A68_SP;
+    A68G_MP (mp_gamma_size) = b;
+    A68G_MP (mp_gam_ck) = (MP_T **) get_heap_space ((size_t) ((b + 1) * sizeof (MP_T *)));
+    A68G_MP (mp_gam_ck)[0] = (MP_T *) get_heap_space (SIZE_MP (gdigs));
+    (void) mp_pi (p, (A68G_MP (mp_gam_ck)[0]), MP_SQRT_TWO_PI, gdigs);
+    ADDR_T pop_sp = A68G_SP;
     MP_T *ak = nil_mp (p, gdigs);
     MP_T *db = lit_mp (p, b, 0, gdigs);
     MP_T *ck = nil_mp (p, gdigs);
@@ -225,30 +225,30 @@ void mp_gamma_table (NODE_T *p, int digs)
       (void) exp_mp (p, dz, ak, gdigs);
       (void) mul_mp (p, ck, ck, dz, gdigs);
       (void) div_mp (p, ck, ck, fac, gdigs);
-      A68_MP (mp_gam_ck)[k] = (MP_T *) get_heap_space (SIZE_MP (gdigs));
-      (void) move_mp ((A68_MP (mp_gam_ck)[k]), ck, gdigs);
+      A68G_MP (mp_gam_ck)[k] = (MP_T *) get_heap_space (SIZE_MP (gdigs));
+      (void) move_mp ((A68G_MP (mp_gam_ck)[k]), ck, gdigs);
       (void) mul_mp (p, fac, fac, dk, gdigs);
       (void) minus_mp (p, fac, fac, gdigs);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
   }
 }
 
 MP_T *mp_spouge_sum (NODE_T *p, MP_T *sum, MP_T *x_g, int gdigs)
 {
-  ADDR_T pop_sp = A68_SP;
-  int a = A68_MP (mp_gamma_size);
+  ADDR_T pop_sp = A68G_SP;
+  int a = A68G_MP (mp_gamma_size);
   MP_T *da = nil_mp (p, gdigs);
   MP_T *dz = nil_mp (p, gdigs);
-  (void) move_mp (sum, A68_MP (mp_gam_ck)[0], gdigs);
+  (void) move_mp (sum, A68G_MP (mp_gam_ck)[0], gdigs);
 // Sum small to large to preserve precision.
   for (int k = a - 1; k > 0; k--) {
     set_mp (da, k, 0, gdigs);
     (void) add_mp (p, dz, x_g, da, gdigs);
-    (void) div_mp (p, dz, A68_MP (mp_gam_ck)[k], dz, gdigs);
+    (void) div_mp (p, dz, A68G_MP (mp_gam_ck)[k], dz, gdigs);
     (void) add_mp (p, sum, sum, dz, gdigs);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return sum;
 }
 
@@ -259,7 +259,7 @@ MP_T *gamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   mp_gamma_table (p, digs);
   int gdigs = GAMMA_PRECISION (digs);
 // Set up coefficient table.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) < 0) {
 // G(1-x)G(x) = pi / sin (pi*x)
     MP_T *pi = nil_mp (p, digs);
@@ -271,10 +271,10 @@ MP_T *gamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     (void) sinpi_mp (p, sz, x, digs);
     (void) mul_mp (p, sz, sz, xm, digs);
     (void) div_mp (p, z, pi, sz, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
-  int a = A68_MP (mp_gamma_size);
+  int a = A68G_MP (mp_gamma_size);
 // Compute Spouge's Gamma
   MP_T *sum = nil_mp (p, gdigs);
   MP_T *x_g = len_mp (p, x, digs, gdigs);
@@ -296,7 +296,7 @@ MP_T *gamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) mul_mp (p, fac, fac, dz, gdigs);
   (void) mul_mp (p, fac, sum, fac, gdigs);
   (void) shorten_mp (p, z, digs, fac, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -307,7 +307,7 @@ MP_T *lngamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   mp_gamma_table (p, digs);
   int gdigs = GAMMA_PRECISION (digs);
 // Set up coefficient table.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) < 0) {
 // G(1-x)G(x) = pi / sin (pi*x)
     MP_T *sz = nil_mp (p, digs);
@@ -320,10 +320,10 @@ MP_T *lngamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     (void) one_minus_mp (p, xm, x, digs);
     (void) lngamma_mp (p, xm, xm, digs);
     (void) sub_mp (p, z, dz, xm, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
-  int a = A68_MP (mp_gamma_size);
+  int a = A68G_MP (mp_gamma_size);
 // Compute Spouge's ln Gamma
   MP_T *sum = nil_mp (p, gdigs);
   MP_T *x_g = len_mp (p, x, digs, gdigs);
@@ -345,7 +345,7 @@ MP_T *lngamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) ln_mp (p, dz, sum, gdigs);
   (void) add_mp (p, fac, fac, dz, gdigs);
   (void) shorten_mp (p, z, digs, fac, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -353,7 +353,7 @@ MP_T *lngamma_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *lnbeta_mp (NODE_T * p, MP_T * z, MP_T * a, MP_T *b, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *aa = nil_mp (p, digs);
   MP_T *bb = nil_mp (p, digs);
   MP_T *ab = nil_mp (p, digs);
@@ -363,7 +363,7 @@ MP_T *lnbeta_mp (NODE_T * p, MP_T * z, MP_T * a, MP_T *b, int digs)
   (void) lngamma_mp (p, ab, ab, digs);
   (void) add_mp (p, z, aa, bb, digs);
   (void) sub_mp (p, z, z, ab, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -371,11 +371,11 @@ MP_T *lnbeta_mp (NODE_T * p, MP_T * z, MP_T * a, MP_T *b, int digs)
 
 MP_T *beta_mp (NODE_T * p, MP_T * z, MP_T * a, MP_T *b, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *u = nil_mp (p, digs);
   lnbeta_mp (p, u, a, b, digs);
   exp_mp (p, z, u, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -385,18 +385,18 @@ MP_T *beta_inc_mp (NODE_T * p, MP_T * z, MP_T * s, MP_T *t, MP_T *x, int digs)
 {
 // Incomplete beta function I{x}(s, t).
 // Continued fraction, see dlmf.nist.gov/8.17; Lentz's algorithm.
-  ADDR_T pop_sp = A68_SP;
-  A68_BOOL gt;
+  ADDR_T pop_sp = A68G_SP;
+  A68G_BOOL gt;
   MP_T *one = lit_mp (p, 1, 0, digs);
   gt_mp (p, &gt, x, one, digs);
   if (MP_DIGIT (x, 1) < 0 || VALUE (&gt)) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   if (same_mp (p, x, one, digs)) {
     SET_MP_ONE (z, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 // Rapid convergence when x <= (s+1)/((s+1)+(t+1)) or else recursion.
@@ -412,15 +412,15 @@ MP_T *beta_inc_mp (NODE_T * p, MP_T * z, MP_T * s, MP_T *t, MP_T *x, int digs)
       (void) one_minus_mp (p, x, x, digs);
       PRELUDE_ERROR (beta_inc_mp (p, z, s, t, x, digs) == NaN_MP, p, ERROR_INVALID_ARGUMENT, MOID (p));
       (void) one_minus_mp (p, z, z, digs);
-      A68_SP = pop_sp;
+      A68G_SP = pop_sp;
       return z;
     }
   }
 // Lentz's algorithm for continued fraction.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   int gdigs = FUN_DIGITS (digs);
   const INT_T lim = gdigs * LOG_MP_RADIX;
-  BOOL_T cont = A68_TRUE;
+  BOOL_T cont = A68G_TRUE;
   MP_T *F = lit_mp (p, 1, 0, gdigs);
   MP_T *T = lit_mp (p, 1, 0, gdigs);
   MP_T *W = lit_mp (p, 1, 0, gdigs);
@@ -477,7 +477,7 @@ MP_T *beta_inc_mp (NODE_T * p, MP_T * z, MP_T * s, MP_T *t, MP_T *x, int digs)
     (void) mul_mp (p, F, F, c, gdigs);
     (void) mul_mp (p, F, F, d, gdigs);
     if (same_mp (p, F, W, gdigs)) {
-      cont = A68_FALSE;
+      cont = A68G_FALSE;
     } else {
       (void) move_mp (W, F, gdigs);
     }
@@ -493,6 +493,6 @@ MP_T *beta_inc_mp (NODE_T * p, MP_T * z, MP_T * s, MP_T *t, MP_T *x, int digs)
   (void) div_mp (p, m, m, w, gdigs);
   (void) mul_mp (p, m, m, F, gdigs);
   (void) shorten_mp (p, z, digs, m, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
