@@ -34,11 +34,11 @@
 static inline BOOL_T eps_mp (MP_T * z, int digs)
 {
   if (MP_DIGIT (z, 1) == 0) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (MP_EXPONENT (z) > -1) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (MP_EXPONENT (z) < -1) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else {
 // More or less optimised for LONG and default LONG LONG precisions.
     return (BOOL_T) (digs <= 10 ? ABS (MP_DIGIT (z, 1)) > 0.01 * MP_RADIX : ABS (MP_DIGIT (z, 1)) > 0.001 * MP_RADIX);
@@ -49,23 +49,23 @@ static inline BOOL_T eps_mp (MP_T * z, int digs)
 
 MP_T *sqrt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) == 0) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     SET_MP_ZERO (z, digs);
     return z;
   }
   if (MP_DIGIT (x, 1) < 0) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     errno = EDOM;
     return NaN_MP;
   }
   int gdigs = FUN_DIGITS (digs), hdigs;
-  BOOL_T reciprocal = A68_FALSE;
+  BOOL_T reciprocal = A68G_FALSE;
   MP_T *z_g = nil_mp (p, gdigs), *x_g = len_mp (p, x, digs, gdigs);
   MP_T *tmp = nil_mp (p, gdigs);
 // Scaling for small x; sqrt (x) = 1 / sqrt (1 / x).
-  if ((reciprocal = (BOOL_T) (MP_EXPONENT (x_g) < 0)) == A68_TRUE) {
+  if ((reciprocal = (BOOL_T) (MP_EXPONENT (x_g) < 0)) == A68G_TRUE) {
     (void) rec_mp (p, x_g, x_g, gdigs);
   }
   if (ABS (MP_EXPONENT (x_g)) >= 2) {
@@ -76,7 +76,7 @@ MP_T *sqrt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     MP_EXPONENT (z_g) += (MP_T) (expo / 2);
   } else {
 // Argument is in range. Estimate the root as double.
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     DOUBLE_T x_d = mp_to_double (p, x_g, gdigs);
     (void) double_to_mp (p, z_g, sqrt_double (x_d), gdigs);
 #else
@@ -98,7 +98,7 @@ MP_T *sqrt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) shorten_mp (p, z, digs, z_g, gdigs);
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -106,23 +106,23 @@ MP_T *sqrt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *curt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) == 0) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     SET_MP_ZERO (z, digs);
     return z;
   }
-  BOOL_T change_sign = A68_FALSE;
+  BOOL_T change_sign = A68G_FALSE;
   if (MP_DIGIT (x, 1) < 0) {
-    change_sign = A68_TRUE;
+    change_sign = A68G_TRUE;
     MP_DIGIT (x, 1) = -MP_DIGIT (x, 1);
   }
   int gdigs = FUN_DIGITS (digs), hdigs;
-  BOOL_T reciprocal = A68_FALSE;
+  BOOL_T reciprocal = A68G_FALSE;
   MP_T *z_g = nil_mp (p, gdigs), *x_g = len_mp (p, x, digs, gdigs);
   MP_T *tmp = nil_mp (p, gdigs);
 // Scaling for small x; curt (x) = 1 / curt (1 / x).
-  if ((reciprocal = (BOOL_T) (MP_EXPONENT (x_g) < 0)) == A68_TRUE) {
+  if ((reciprocal = (BOOL_T) (MP_EXPONENT (x_g) < 0)) == A68G_TRUE) {
     (void) rec_mp (p, x_g, x_g, gdigs);
   }
   if (ABS (MP_EXPONENT (x_g)) >= 3) {
@@ -133,7 +133,7 @@ MP_T *curt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     MP_EXPONENT (z_g) += (MP_T) (expo / 3);
   } else {
 // Argument is in range. Estimate the root as double.
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     DOUBLE_T x_d = mp_to_double (p, x_g, gdigs);
     (void) double_to_mp (p, z_g, cbrt_double (x_d), gdigs);
 #else
@@ -157,7 +157,7 @@ MP_T *curt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) shorten_mp (p, z, digs, z_g, gdigs);
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   if (change_sign) {
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
@@ -169,7 +169,7 @@ MP_T *curt_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *hypot_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 {
 // sqrt (x^2 + y^2).
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *t = nil_mp (p, digs), *u = nil_mp (p, digs), *v = nil_mp (p, digs);
   (void) move_mp (u, x, digs);
   (void) move_mp (v, y, digs);
@@ -196,7 +196,7 @@ MP_T *hypot_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
       (void) mul_mp (p, z, v, z, digs);
     }
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -206,7 +206,7 @@ MP_T *exp_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Argument is reduced by using exp (z / (2 ** n)) ** (2 ** n) = exp(z).
   int gdigs = FUN_DIGITS (digs);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) == 0) {
     SET_MP_ONE (z, digs);
     return z;
@@ -254,7 +254,7 @@ MP_T *exp_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   while (iter) {
     (void) div_mp (p, tmp, pwr, fac, gdigs);
     if (MP_EXPONENT (tmp) <= (MP_EXPONENT (sum) - gdigs)) {
-      iter = A68_FALSE;
+      iter = A68G_FALSE;
     } else {
       (void) add_mp (p, sum, sum, tmp, gdigs);
       (void) mul_mp (p, pwr, pwr, x_g, gdigs);
@@ -268,7 +268,7 @@ MP_T *exp_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) shorten_mp (p, z, digs, sum, gdigs);
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -278,7 +278,7 @@ MP_T *exp_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *expm1_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
   int gdigs = FUN_DIGITS (digs);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) == 0) {
     SET_MP_ONE (z, digs);
     return z;
@@ -319,7 +319,7 @@ MP_T *expm1_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   while (iter) {
     (void) div_mp (p, tmp, pwr, fac, gdigs);
     if (MP_EXPONENT (tmp) <= (MP_EXPONENT (sum) - gdigs)) {
-      iter = A68_FALSE;
+      iter = A68G_FALSE;
     } else {
       (void) add_mp (p, sum, sum, tmp, gdigs);
       (void) mul_mp (p, pwr, pwr, x_g, gdigs);
@@ -329,7 +329,7 @@ MP_T *expm1_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) shorten_mp (p, z, digs, sum, gdigs);
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -337,22 +337,22 @@ MP_T *expm1_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *mp_ln_scale (NODE_T * p, MP_T * z, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *z_g = nil_mp (p, gdigs);
 // First see if we can restore a previous calculation.
-  if (gdigs <= A68_MP (mp_ln_scale_size)) {
-    (void) move_mp (z_g, A68_MP (mp_ln_scale), gdigs);
+  if (gdigs <= A68G_MP (mp_ln_scale_size)) {
+    (void) move_mp (z_g, A68G_MP (mp_ln_scale), gdigs);
   } else {
 // No luck with the kept value, we generate a longer one.
     (void) set_mp (z_g, (MP_T) 1, 1, gdigs);
     (void) ln_mp (p, z_g, z_g, gdigs);
-    A68_MP (mp_ln_scale) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
-    (void) move_mp (A68_MP (mp_ln_scale), z_g, gdigs);
-    A68_MP (mp_ln_scale_size) = gdigs;
+    A68G_MP (mp_ln_scale) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
+    (void) move_mp (A68G_MP (mp_ln_scale), z_g, gdigs);
+    A68G_MP (mp_ln_scale_size) = gdigs;
   }
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -360,22 +360,22 @@ MP_T *mp_ln_scale (NODE_T * p, MP_T * z, int digs)
 
 MP_T *mp_ln_10 (NODE_T * p, MP_T * z, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *z_g = nil_mp (p, gdigs);
 // First see if we can restore a previous calculation.
-  if (gdigs <= A68_MP (mp_ln_10_size)) {
-    (void) move_mp (z_g, A68_MP (mp_ln_10), gdigs);
+  if (gdigs <= A68G_MP (mp_ln_10_size)) {
+    (void) move_mp (z_g, A68G_MP (mp_ln_10), gdigs);
   } else {
 // No luck with the kept value, we generate a longer one.
     (void) set_mp (z_g, (MP_T) 10, 0, gdigs);
     (void) ln_mp (p, z_g, z_g, gdigs);
-    A68_MP (mp_ln_10) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
-    (void) move_mp (A68_MP (mp_ln_10), z_g, gdigs);
-    A68_MP (mp_ln_10_size) = gdigs;
+    A68G_MP (mp_ln_10) = (MP_T *) get_heap_space ((unt) SIZE_MP (gdigs));
+    (void) move_mp (A68G_MP (mp_ln_10), z_g, gdigs);
+    A68G_MP (mp_ln_10_size) = gdigs;
   }
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -384,7 +384,7 @@ MP_T *mp_ln_10 (NODE_T * p, MP_T * z, int digs)
 MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Depending on the argument we choose either Taylor or Newton.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   BOOL_T neg, scale;
   MP_T expo = 0;
@@ -418,7 +418,7 @@ MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     while (iter) {
       (void) div_mp_digit (p, tmp, pwr, (MP_T) n, gdigs);
       if (MP_EXPONENT (tmp) <= (MP_EXPONENT (z_g) - gdigs)) {
-        iter = A68_FALSE;
+        iter = A68G_FALSE;
       } else {
         MP_DIGIT (tmp, 1) = (EVEN (n) ? -MP_DIGIT (tmp, 1) : MP_DIGIT (tmp, 1));
         (void) add_mp (p, z_g, z_g, tmp, gdigs);
@@ -430,7 +430,7 @@ MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // Newton's method: x<n+1> = x<n> - 1 + a / exp (x<n>).
     MP_T *tmp = nil_mp (p, gdigs);
 // Construct an estimate.
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     (void) double_to_mp (p, z_g, log_double (mp_to_double (p, x_g, gdigs)), gdigs);
 #else
     (void) real_to_mp (p, z_g, log (mp_to_real (p, x_g, gdigs)), gdigs);
@@ -458,7 +458,7 @@ MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) shorten_mp (p, z, digs, z_g, gdigs);
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -466,7 +466,7 @@ MP_T *ln_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *log_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *ln_10 = nil_mp (p, digs);
   if (ln_mp (p, z, x, digs) == NaN_MP) {
     errno = EDOM;
@@ -474,7 +474,7 @@ MP_T *log_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   }
   (void) mp_ln_10 (p, ln_10, digs);
   (void) div_mp (p, z, z, ln_10, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -482,7 +482,7 @@ MP_T *log_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *hyp_mp (NODE_T * p, MP_T * sh, MP_T * ch, MP_T * z, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x_g = nil_mp (p, digs), *y_g = nil_mp (p, digs), *z_g = nil_mp (p, digs);
   (void) move_mp (z_g, z, digs);
   (void) exp_mp (p, x_g, z_g, digs);
@@ -497,7 +497,7 @@ MP_T *hyp_mp (NODE_T * p, MP_T * sh, MP_T * ch, MP_T * z, int digs)
   (void) sub_mp (p, sh, x_g, y_g, digs);
   (void) half_mp (p, sh, sh, digs);
   (void) half_mp (p, ch, ch, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -505,12 +505,12 @@ MP_T *hyp_mp (NODE_T * p, MP_T * sh, MP_T * ch, MP_T * z, int digs)
 
 MP_T *sinh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *y_g = nil_mp (p, gdigs), *z_g = nil_mp (p, gdigs);
   (void) hyp_mp (p, z_g, y_g, x_g, gdigs);
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -522,7 +522,7 @@ MP_T *asinh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     SET_MP_ZERO (z, digs);
     return z;
   } else {
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     int gdigs;
     if (MP_EXPONENT (x) >= -1) {
       gdigs = FUN_DIGITS (digs);
@@ -542,7 +542,7 @@ MP_T *asinh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     } else {
       (void) shorten_mp (p, z, digs, z_g, gdigs);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -551,12 +551,12 @@ MP_T *asinh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *cosh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *y_g = nil_mp (p, gdigs), *z_g = nil_mp (p, gdigs);
   (void) hyp_mp (p, y_g, z_g, x_g, gdigs);
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -564,7 +564,7 @@ MP_T *cosh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *acosh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs;
   if (MP_DIGIT (x, 1) == 1 && MP_DIGIT (x, 2) == 0) {
 // Extra precision when x^2-1 gets close to 0.
@@ -580,7 +580,7 @@ MP_T *acosh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) add_mp (p, y_g, y_g, x_g, gdigs);
   (void) ln_mp (p, z_g, y_g, gdigs);
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -588,13 +588,13 @@ MP_T *acosh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *tanh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *y_g = nil_mp (p, gdigs), *z_g = nil_mp (p, gdigs);
   (void) hyp_mp (p, y_g, z_g, x_g, gdigs);
   (void) div_mp (p, z_g, y_g, z_g, gdigs);
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -602,7 +602,7 @@ MP_T *tanh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *atanh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *y_g = nil_mp (p, gdigs), *z_g = nil_mp (p, gdigs);
   SET_MP_ONE (y_g, gdigs);
@@ -612,7 +612,7 @@ MP_T *atanh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) ln_mp (p, z_g, y_g, gdigs);
   (void) half_mp (p, z_g, z_g, gdigs);
   (void) shorten_mp (p, z, digs, z_g, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -621,7 +621,7 @@ MP_T *atanh_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *sin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Use triple-angle relation to reduce argument.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
 // We will use "pi".
   MP_T *pi = nil_mp (p, gdigs), *tpi = nil_mp (p, gdigs), *hpi = nil_mp (p, gdigs);
@@ -672,18 +672,18 @@ MP_T *sin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) mul_mp (p, pwr, pwr, sqr, gdigs);
   (void) set_mp (fac, (MP_T) 362880, 0, gdigs);
   int n = 9;
-  BOOL_T even = A68_TRUE, iter = (BOOL_T) (MP_DIGIT (pwr, 1) != 0);
+  BOOL_T even = A68G_TRUE, iter = (BOOL_T) (MP_DIGIT (pwr, 1) != 0);
   while (iter) {
     (void) div_mp (p, tmp, pwr, fac, gdigs);
     if (MP_EXPONENT (tmp) <= (MP_EXPONENT (z_g) - gdigs)) {
-      iter = A68_FALSE;
+      iter = A68G_FALSE;
     } else {
       if (even) {
         (void) add_mp (p, z_g, z_g, tmp, gdigs);
-        even = A68_FALSE;
+        even = A68G_FALSE;
       } else {
         (void) sub_mp (p, z_g, z_g, tmp, gdigs);
-        even = A68_TRUE;
+        even = A68G_TRUE;
       }
       (void) mul_mp (p, pwr, pwr, sqr, gdigs);
       (void) mul_mp_digit (p, fac, fac, (MP_T) (++n), gdigs);
@@ -704,7 +704,7 @@ MP_T *sin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -713,12 +713,12 @@ MP_T *sin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *cas_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Hartley kernel, which Hartley named cas (cosine and sine).
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *sinx = nil_mp (p, digs), *cosx = nil_mp (p, digs);
   cos_mp (p, cosx, x, digs);
   sin_mp (p, sinx, x, digs);
   (void) add_mp (p, z, cosx, sinx, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -728,7 +728,7 @@ MP_T *cos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Use cos (x) = sin (pi / 2 - x).
 // Compute x mod 2 pi before subtracting to avoid cancellation.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *hpi = nil_mp (p, gdigs), *tpi = nil_mp (p, gdigs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *y = nil_mp (p, digs);
@@ -738,7 +738,7 @@ MP_T *cos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) sub_mp (p, x_g, hpi, x_g, gdigs);
   (void) shorten_mp (p, y, digs, x_g, gdigs);
   (void) sin_mp (p, z, y, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -747,7 +747,7 @@ MP_T *cos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *tan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Use tan (x) = sin (x) / sqrt (1 - sin ^ 2 (x)).
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *pi = nil_mp (p, gdigs), *hpi = nil_mp (p, gdigs);
   (void) mp_pi (p, pi, MP_PI, gdigs);
@@ -772,10 +772,10 @@ MP_T *tan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) sqrt_mp (p, cns, cns, digs);
   if (div_mp (p, z, sns, cns, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   if (neg) {
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
@@ -786,7 +786,7 @@ MP_T *tan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *asin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, gdigs), *z_g = nil_mp (p, gdigs);
   MP_T *y = nil_mp (p, digs);
@@ -794,23 +794,23 @@ MP_T *asin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) one_minus_mp (p, z_g, z_g, gdigs);
   if (sqrt_mp (p, z_g, z_g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   if (MP_DIGIT (z_g, 1) == 0) {
     (void) mp_pi (p, z, MP_HALF_PI, digs);
     MP_DIGIT (z, 1) = (MP_DIGIT (x_g, 1) >= 0 ? MP_DIGIT (z, 1) : -MP_DIGIT (z, 1));
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   if (div_mp (p, x_g, x_g, z_g, gdigs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   (void) shorten_mp (p, y, digs, x_g, gdigs);
   (void) atan_mp (p, z, y, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -818,12 +818,12 @@ MP_T *asin_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *acos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   BOOL_T neg = (BOOL_T) (MP_DIGIT (x, 1) < 0);
   if (MP_DIGIT (x, 1) == 0) {
     (void) mp_pi (p, z, MP_HALF_PI, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   MP_T *x_g = len_mp (p, x, digs, gdigs), *z_g = nil_mp (p, gdigs);
@@ -832,12 +832,12 @@ MP_T *acos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) one_minus_mp (p, z_g, z_g, gdigs);
   if (sqrt_mp (p, z_g, z_g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   if (div_mp (p, x_g, z_g, x_g, gdigs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   (void) shorten_mp (p, y, digs, x_g, gdigs);
@@ -846,7 +846,7 @@ MP_T *acos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     (void) mp_pi (p, y, MP_PI, digs);
     (void) add_mp (p, z, z, y, digs);
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -855,9 +855,9 @@ MP_T *acos_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Depending on the argument we choose either Taylor or Newton.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (x, 1) == 0) {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     SET_MP_ZERO (z, digs);
     return z;
   }
@@ -881,18 +881,18 @@ MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     (void) mul_mp (p, pwr, sqr, x_g, gdigs);
     (void) move_mp (z_g, x_g, gdigs);
     int n = 3;
-    BOOL_T even = A68_FALSE, iter = (BOOL_T) (MP_DIGIT (pwr, 1) != 0);
+    BOOL_T even = A68G_FALSE, iter = (BOOL_T) (MP_DIGIT (pwr, 1) != 0);
     while (iter) {
       (void) div_mp_digit (p, tmp, pwr, (MP_T) n, gdigs);
       if (MP_EXPONENT (tmp) <= (MP_EXPONENT (z_g) - gdigs)) {
-        iter = A68_FALSE;
+        iter = A68G_FALSE;
       } else {
         if (even) {
           (void) add_mp (p, z_g, z_g, tmp, gdigs);
-          even = A68_FALSE;
+          even = A68G_FALSE;
         } else {
           (void) sub_mp (p, z_g, z_g, tmp, gdigs);
-          even = A68_TRUE;
+          even = A68G_TRUE;
         }
         (void) mul_mp (p, pwr, pwr, sqr, gdigs);
         n += 2;
@@ -902,7 +902,7 @@ MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // Newton's method: x<n+1> = x<n> - cos (x<n>) * (sin (x<n>) - a cos (x<n>)).
     MP_T *sns = nil_mp (p, gdigs), *cns = nil_mp (p, gdigs), *tmp = nil_mp (p, gdigs);
 // Construct an estimate.
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     (void) double_to_mp (p, z_g, atan_double (mp_to_double (p, x_g, gdigs)), gdigs);
 #else
     (void) real_to_mp (p, z_g, atan (mp_to_real (p, x_g, gdigs)), gdigs);
@@ -928,7 +928,7 @@ MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) shorten_mp (p, z, digs, z_g, gdigs);
   MP_DIGIT (z, 1) = (neg ? -MP_DIGIT (z, 1) : MP_DIGIT (z, 1));
 // Exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -936,11 +936,11 @@ MP_T *atan_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *atan2_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *t = nil_mp (p, digs);
   if (MP_DIGIT (x, 1) == 0 && MP_DIGIT (y, 1) == 0) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
     BOOL_T flip = (BOOL_T) (MP_DIGIT (y, 1) < 0);
@@ -961,7 +961,7 @@ MP_T *atan2_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
       MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
     }
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1054,7 +1054,7 @@ MP_T *asecdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 MP_T *cot_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
 // Use tan (x) = sin (x) / sqrt (1 - sin ^ 2 (x)).
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *pi = nil_mp (p, gdigs), *hpi = nil_mp (p, gdigs);
   (void) mp_pi (p, pi, MP_PI, gdigs);
@@ -1079,10 +1079,10 @@ MP_T *cot_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) sqrt_mp (p, cns, cns, digs);
   if (div_mp (p, z, cns, sns, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   if (neg) {
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
@@ -1093,15 +1093,15 @@ MP_T *cot_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *acot_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs);
   if (rec_mp (p, f, x, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
     (void) atan_mp (p, z, f, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1110,12 +1110,12 @@ MP_T *acot_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *sindg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) mp_pi (p, f, MP_PI_OVER_180, digs);
   (void) mul_mp (p, g, x, f, digs);
   (void) sin_mp (p, z, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1123,12 +1123,12 @@ MP_T *sindg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *cosdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) mp_pi (p, f, MP_PI_OVER_180, digs);
   (void) mul_mp (p, g, x, f, digs);
   (void) cos_mp (p, z, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1136,16 +1136,16 @@ MP_T *cosdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *tandg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) mp_pi (p, f, MP_PI_OVER_180, digs);
   (void) mul_mp (p, g, x, f, digs);
   if (tan_mp (p, z, g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1154,16 +1154,16 @@ MP_T *tandg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *cotdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) mp_pi (p, f, MP_PI_OVER_180, digs);
   (void) mul_mp (p, g, x, f, digs);
   if (cot_mp (p, z, g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1172,12 +1172,12 @@ MP_T *cotdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *asindg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) asin_mp (p, f, x, digs);
   (void) mp_pi (p, g, MP_180_OVER_PI, digs);
   (void) mul_mp (p, z, f, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1185,12 +1185,12 @@ MP_T *asindg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *acosdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) acos_mp (p, f, x, digs);
   (void) mp_pi (p, g, MP_180_OVER_PI, digs);
   (void) mul_mp (p, z, f, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1198,12 +1198,12 @@ MP_T *acosdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *atandg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   (void) atan_mp (p, f, x, digs);
   (void) mp_pi (p, g, MP_180_OVER_PI, digs);
   (void) mul_mp (p, z, f, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1211,16 +1211,16 @@ MP_T *atandg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *acotdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   if (acot_mp (p, f, x, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
     (void) mp_pi (p, g, MP_180_OVER_PI, digs);
     (void) mul_mp (p, z, f, g, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1229,16 +1229,16 @@ MP_T *acotdg_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *atan2dg_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = nil_mp (p, digs);
   if (atan2_mp (p, f, x, y, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
     (void) mp_pi (p, g, MP_180_OVER_PI, digs);
     (void) mul_mp (p, z, f, g, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1247,18 +1247,18 @@ MP_T *atan2dg_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 
 MP_T *sinpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = lit_mp (p, 1, 0, digs);
   (void) mod_mp (p, f, x, g, digs);
   if (IS_ZERO_MP (f)) {
     SET_MP_ZERO (z, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   (void) mp_pi (p, f, MP_PI, digs);
   (void) mul_mp (p, g, x, f, digs);
   (void) sin_mp (p, z, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1266,7 +1266,7 @@ MP_T *sinpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *cospi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = lit_mp (p, 1, 0, digs);
   (void) mod_mp (p, f, x, g, digs);
   abs_mp (p, f, f, digs);
@@ -1274,13 +1274,13 @@ MP_T *cospi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   (void) sub_mp (p, g, f, g, digs);
   if (IS_ZERO_MP (g)) {
     SET_MP_ZERO (z, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   (void) mp_pi (p, f, MP_PI, digs);
   (void) mul_mp (p, g, x, f, digs);
   (void) cos_mp (p, z, g, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1288,14 +1288,14 @@ MP_T *cospi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *tanpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = lit_mp (p, 1, 0, digs);
   MP_T *h = nil_mp (p, digs), *half = nil_mp (p, digs);
   SET_MP_ONE (g, digs);
   (void) mod_mp (p, f, x, g, digs);
   if (IS_ZERO_MP (f)) {
     SET_MP_ZERO (z, digs);
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   SET_MP_MINUS_HALF (half, digs);
@@ -1319,17 +1319,17 @@ MP_T *tanpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     } else {
       SET_MP_ONE (z, digs);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   (void) mp_pi (p, f, MP_PI, digs);
   (void) mul_mp (p, g, x, f, digs);
   if (tan_mp (p, z, g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -1338,13 +1338,13 @@ MP_T *tanpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *cotpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *f = nil_mp (p, digs), *g = lit_mp (p, 1, 0, digs);
   MP_T *h = nil_mp (p, digs), *half = nil_mp (p, digs);
   (void) mod_mp (p, f, x, g, digs);
   if (IS_ZERO_MP (f)) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   }
   SET_MP_MINUS_HALF (half, digs);
@@ -1368,17 +1368,17 @@ MP_T *cotpi_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     } else {
       SET_MP_ONE (z, digs);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
   (void) mp_pi (p, f, MP_PI, digs);
   (void) mul_mp (p, g, x, f, digs);
   if (cot_mp (p, z, g, digs) == NaN_MP) {
     errno = EDOM;
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return NaN_MP;
   } else {
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
