@@ -111,7 +111,7 @@
 
 void set_long_mp_digits (int n)
 {
-  A68_MP (varying_mp_digits) = n;
+  A68G_MP (varying_mp_digits) = n;
 }
 
 //! @brief Convert precision to digits for long long number.
@@ -129,14 +129,14 @@ void raw_write_mp (char *str, MP_T * z, int digs)
 {
   fprintf (stdout, "\n(%d digits)%s", digs, str);
   for (int i = 1; i <= digs; i++) {
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
     fprintf (stdout, " %09lld", (MP_INT_T) MP_DIGIT (z, i));
 #else
     fprintf (stdout, " %07d", (MP_INT_T) MP_DIGIT (z, i));
 #endif
   }
-  fprintf (stdout, " E" A68_LD, (MP_INT_T) MP_EXPONENT (z));
-  fprintf (stdout, " S" A68_LD, (MP_INT_T) MP_STATUS (z));
+  fprintf (stdout, " E" A68G_LD, (MP_INT_T) MP_EXPONENT (z));
+  fprintf (stdout, " S" A68G_LD, (MP_INT_T) MP_STATUS (z));
   fprintf (stdout, "\n");
   ASSERT (fflush (stdout) == 0);
 }
@@ -150,9 +150,9 @@ BOOL_T check_mp_int (MP_T * z, const MOID_T * m)
   if (m == M_LONG_INT || m == M_LONG_BITS) {
     return (BOOL_T) ((MP_EXPONENT (z) >= (MP_T) 0) && (MP_EXPONENT (z) < (MP_T) LONG_MP_DIGITS));
   } else if (m == M_LONG_LONG_INT || m == M_LONG_LONG_BITS) {
-    return (BOOL_T) ((MP_EXPONENT (z) >= (MP_T) 0) && (MP_EXPONENT (z) < (MP_T) A68_MP (varying_mp_digits)));
+    return (BOOL_T) ((MP_EXPONENT (z) >= (MP_T) 0) && (MP_EXPONENT (z) < (MP_T) A68G_MP (varying_mp_digits)));
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief |x|
@@ -185,9 +185,9 @@ MP_T *minus_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *one_minus_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) sub_mp (p, z, mp_one (digs), x, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -195,9 +195,9 @@ MP_T *one_minus_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *minus_one_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) sub_mp (p, z, x, mp_one (digs), digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -205,9 +205,9 @@ MP_T *minus_one_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *plus_one_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) add_mp (p, z, x, mp_one (digs), digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -219,12 +219,12 @@ BOOL_T same_mp (NODE_T * p, MP_T * x, MP_T * y, int digs)
   if ((MP_STATUS (x) == MP_STATUS (y)) && (MP_EXPONENT (x) == MP_EXPONENT (y))) {
     for (int k = digs; k >= 1; k--) {
       if (MP_DIGIT (x, k) != MP_DIGIT (y, k)) {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -257,7 +257,7 @@ MP_T *align_mp (MP_T * z, INT_T * expo, int digs)
 
 MP_T *strtomp (NODE_T * p, MP_T * z, char *s, int digs)
 {
-  BOOL_T ok = A68_TRUE;
+  BOOL_T ok = A68G_TRUE;
   errno = 0;
   SET_MP_ZERO (z, digs);
   while (IS_SPACE (s[0])) {
@@ -377,22 +377,22 @@ INT_T mp_to_int (NODE_T * p, MP_T * z, int digs)
 // This routines looks a lot like "strtol". 
   INT_T expo = (int) MP_EXPONENT (z), sum = 0, weight = 1;
   if (expo >= digs) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, MOID (p));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, MOID (p));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   BOOL_T negative = (BOOL_T) (MP_DIGIT (z, 1) < 0);
   if (negative) {
     MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
   }
   for (int j = 1 + expo; j >= 1; j--) {
-    if ((MP_INT_T) MP_DIGIT (z, j) > A68_MAX_INT / weight) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_INT);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if ((MP_INT_T) MP_DIGIT (z, j) > A68G_MAX_INT / weight) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_INT);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     INT_T term = (MP_INT_T) MP_DIGIT (z, j) * weight;
-    if (sum > A68_MAX_INT - term) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_INT);
-      exit_genie (p, A68_RUNTIME_ERROR);
+    if (sum > A68G_MAX_INT - term) {
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_INT);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
     sum += term;
     weight *= MP_RADIX;
@@ -425,7 +425,7 @@ MP_T *real_to_mp (NODE_T * p, MP_T * z, REAL_T x, int digs)
 // Transport digs of x to the mantissa of z.
   INT_T sum = 0, weight = (MP_RADIX / 10);
   int j = 1;
-  for (int k = 0; a != 0.0 && j <= digs && k < A68_REAL_DIG; k++) {
+  for (int k = 0; a != 0.0 && j <= digs && k < A68G_REAL_DIG; k++) {
     REAL_T u = a * 10;
     REAL_T v = floor (u);
     a = u - v;
@@ -454,7 +454,7 @@ REAL_T mp_to_real (NODE_T * p, MP_T * z, int digs)
 {
 // This routine looks a lot like "strtod".
   (void) p;
-  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX <= (MP_T) A68_REAL_MIN_EXP) {
+  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX <= (MP_T) A68G_REAL_MIN_EXP) {
     return 0;
   } else {
     REAL_T terms[1 + MP_MAX_DIGITS];
@@ -542,8 +542,8 @@ MP_T *trunc_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     SET_MP_ZERO (z, digs);
   } else if (MP_EXPONENT (x) >= (MP_T) digs) {
     errno = EDOM;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, (IS (MOID (p), PROC_SYMBOL) ? SUB_MOID (p) : MOID (p)));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, (IS (MOID (p), PROC_SYMBOL) ? SUB_MOID (p) : MOID (p)));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     (void) move_mp (z, x, digs);
     for (int k = (int) (MP_EXPONENT (x) + 2); k <= digs; k++) {
@@ -561,8 +561,8 @@ MP_T *floor_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     SET_MP_ZERO (z, digs);
   } else if (MP_EXPONENT (x) >= (MP_T) digs) {
     errno = EDOM;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, (IS (MOID (p), PROC_SYMBOL) ? SUB_MOID (p) : MOID (p)));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, (IS (MOID (p), PROC_SYMBOL) ? SUB_MOID (p) : MOID (p)));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else {
     (void) move_mp (z, x, digs);
     for (int k = (int) (MP_EXPONENT (x) + 2); k <= digs; k++) {
@@ -585,7 +585,7 @@ MP_T *shorten_mp (NODE_T * p, MP_T * z, int digs, MP_T * x, int digs_x)
     return move_mp (z, x, digs);
   } else {
 // Reserve extra digs for proper rounding.
-    ADDR_T pop_sp = A68_SP;
+    ADDR_T pop_sp = A68G_SP;
     int digs_h = digs + 2;
     BOOL_T negative = (BOOL_T) (MP_DIGIT (x, 1) < 0);
     MP_T *w = nil_mp (p, digs_h);
@@ -600,7 +600,7 @@ MP_T *shorten_mp (NODE_T * p, MP_T * z, int digs, MP_T * x, int digs_x)
     if (negative) {
       MP_DIGIT (z, 1) = -MP_DIGIT (z, 1);
     }
-    A68_SP = pop_sp;
+    A68G_SP = pop_sp;
     return z;
   }
 }
@@ -640,7 +640,7 @@ MP_T *add_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return z;
   }
 // We want positive arguments.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T x_1 = MP_DIGIT (x, 1), y_1 = MP_DIGIT (y, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
   MP_DIGIT (y, 1) = ABS (y_1);
@@ -685,7 +685,7 @@ MP_T *add_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     check_mp_exp (p, z);
   }
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (y, 1) = y_1;
@@ -708,7 +708,7 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return z;
   }
 // We want positive arguments.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T x_1 = MP_DIGIT (x, 1), y_1 = MP_DIGIT (y, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
   MP_DIGIT (y, 1) = ABS (y_1);
@@ -721,7 +721,7 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     (void) sub_mp (p, z, y, x, digs);
   } else {
 // Subtract.
-    BOOL_T negative = A68_FALSE;
+    BOOL_T negative = A68G_FALSE;
     int fnz, digs_h = 2 + digs;
     MP_T *w = nil_mp (p, digs_h);
     if (MP_EXPONENT (x) == MP_EXPONENT (y)) {
@@ -788,7 +788,7 @@ MP_T *sub_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     check_mp_exp (p, z);
   }
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (y, 1) = y_1;
@@ -805,7 +805,7 @@ MP_T *mul_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return z;
   }
 // Grammar school algorithm with intermittent normalisation.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int digs_h = 2 + digs;
   MP_T x_1 = MP_DIGIT (x, 1), y_1 = MP_DIGIT (y, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
@@ -830,7 +830,7 @@ MP_T *mul_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
   norm_mp (w, 2, digs_h);
   round_internal_mp (z, w, digs);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (y, 1) = y_1;
@@ -858,7 +858,7 @@ MP_T *div_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return NaN_MP;
   }
 // Determine normalisation interval assuming that q < 2b in each step.
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
   int oflow = (int) FLOOR_MP ((MP_REAL_T) MAX_REPR_INT / (3 * MP_REAL_RADIX * MP_REAL_RADIX)) - 1;
 #else
   int oflow = (int) FLOOR_MP ((MP_REAL_T) MAX_REPR_INT / (2 * MP_REAL_RADIX * MP_REAL_RADIX)) - 1;
@@ -882,7 +882,7 @@ MP_T *div_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return z;
   }
 // Working nominator in which the quotient develops.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int wdigs = 4 + digs;
   MP_T *w = lit_mp (p, 0, MP_EXPONENT (x) - MP_EXPONENT (y), wdigs);
   (void) move_mp_part (&MP_DIGIT (w, 2), &MP_DIGIT (x, 1), digs);
@@ -915,7 +915,7 @@ MP_T *div_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
   norm_mp (w, 2, digs);
   round_internal_mp (z, w, digs);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (y, 1) = y_1;
@@ -932,14 +932,14 @@ MP_T *over_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     errno = ERANGE;
     return NaN_MP;
   }
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int digs_g = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, digs_g), *y_g = len_mp (p, y, digs, digs_g), *z_g = nil_mp (p, digs_g);
   (void) div_mp (p, z_g, x_g, y_g, digs_g);
   trunc_mp (p, z_g, z_g, digs_g);
   (void) shorten_mp (p, z, digs, z_g, digs_g);
   MP_STATUS (z) = (MP_T) INIT_MASK;
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -952,7 +952,7 @@ MP_T *mod_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
     return NaN_MP;
   }
   int digs_g = FUN_DIGITS (digs);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x_g = len_mp (p, x, digs, digs_g);
   MP_T *y_g = len_mp (p, y, digs, digs_g);
   MP_T *z_g = nil_mp (p, digs_g);
@@ -962,7 +962,7 @@ MP_T *mod_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
   (void) sub_mp (p, z_g, x_g, z_g, digs_g);
   (void) shorten_mp (p, z, digs, z_g, digs_g);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -973,7 +973,7 @@ MP_T *mul_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
 // This is an O(N) routine for multiplication by a short value.
   MP_T x_1 = MP_DIGIT (x, 1);
   int digs_h = 2 + digs;
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_DIGIT (x, 1) = ABS (x_1);
   MP_STATUS (z) = (MP_T) INIT_MASK;
   MP_T y_1 = y;
@@ -991,7 +991,7 @@ MP_T *mul_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
     round_internal_mp (z, w, digs);
   }
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (z, 1) = ((x_1 * y_1) >= 0 ? z_1 : -z_1);
@@ -1003,7 +1003,7 @@ MP_T *mul_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
 
 MP_T *half_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int digs_h = 2 + digs;
   MP_T x_1 = MP_DIGIT (x, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
@@ -1018,7 +1018,7 @@ MP_T *half_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   norm_mp (w, 2, digs_h);
   round_internal_mp (z, w, digs);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (z, 1) = (x_1 >= 0 ? z_1 : -z_1);
@@ -1030,7 +1030,7 @@ MP_T *half_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 
 MP_T *tenth_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int digs_h = 2 + digs;
   MP_T x_1 = MP_DIGIT (x, 1);
   MP_DIGIT (x, 1) = ABS (x_1);
@@ -1045,7 +1045,7 @@ MP_T *tenth_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
   norm_mp (w, 2, digs_h);
   round_internal_mp (z, w, digs);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (z, 1) = (x_1 >= 0 ? z_1 : -z_1);
@@ -1062,13 +1062,13 @@ MP_T *div_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
     return NaN_MP;
   }
 // Determine normalisation interval assuming that q < 2b in each step.
-#if (A68_LEVEL <= 2)
+#if (A68G_LEVEL <= 2)
   int oflow = (int) FLOOR_MP ((MP_REAL_T) MAX_REPR_INT / (3 * MP_REAL_RADIX * MP_REAL_RADIX)) - 1;
 #else
   int oflow = (int) FLOOR_MP ((MP_REAL_T) MAX_REPR_INT / (2 * MP_REAL_RADIX * MP_REAL_RADIX)) - 1;
 #endif
 // Work with positive operands.
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T x_1 = MP_DIGIT (x, 1), y_1 = y;
   MP_DIGIT (x, 1) = ABS (x_1);
   MP_STATUS (z) = (MP_T) INIT_MASK;
@@ -1098,7 +1098,7 @@ MP_T *div_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
     round_internal_mp (z, w, digs);
   }
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   MP_T z_1 = MP_DIGIT (z, 1);
   MP_DIGIT (x, 1) = x_1;
   MP_DIGIT (z, 1) = ((x_1 * y_1) >= 0 ? z_1 : -z_1);
@@ -1115,13 +1115,13 @@ MP_T *over_mp_digit (NODE_T * p, MP_T * z, MP_T * x, MP_T y, int digs)
     return NaN_MP;
   }
   int digs_g = FUN_DIGITS (digs);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *x_g = len_mp (p, x, digs, digs_g), *z_g = nil_mp (p, digs_g);
   (void) div_mp_digit (p, z_g, x_g, y, digs_g);
   trunc_mp (p, z_g, z_g, digs_g);
   (void) shorten_mp (p, z, digs, z_g, digs_g);
 // Restore and exit.
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1133,9 +1133,9 @@ MP_T *rec_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
     errno = ERANGE;
     return NaN_MP;
   }
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   (void) div_mp (p, z, mp_one (digs), x, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return z;
 }
 
@@ -1153,7 +1153,7 @@ void genie_pi_mp (NODE_T * p)
 
 MP_T *pow_mp_int (NODE_T * p, MP_T * z, MP_T * x, INT_T n, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int bit, digs_g = FUN_DIGITS (digs);
   MP_T *x_g = len_mp (p, x, digs, digs_g), *z_g = lit_mp (p, 1, 0, digs_g);
   BOOL_T negative = (BOOL_T) (n < 0);
@@ -1169,7 +1169,7 @@ MP_T *pow_mp_int (NODE_T * p, MP_T * z, MP_T * x, INT_T n, int digs)
     bit <<= 1;
   }
   (void) shorten_mp (p, z, digs, z_g, digs_g);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   if (negative) {
     (void) rec_mp (p, z, z, digs);
   }
@@ -1191,7 +1191,7 @@ MP_T *pow_mp (NODE_T * p, MP_T * z, MP_T * x, MP_T * y, int digs)
 
 MP_T *ten_up_mp (NODE_T * p, MP_T * z, int n, int digs)
 {
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
   static MP_T y[LOG_MP_RADIX] = { 1, 10, 100, 1000, 10000, 100000, 1000000, 10000000, 100000000 };
 #else
   static MP_T y[LOG_MP_RADIX] = { 1, 10, 100, 1000, 10000, 100000, 1000000 };
@@ -1207,74 +1207,74 @@ MP_T *ten_up_mp (NODE_T * p, MP_T * z, int n, int digs)
 
 //! @brief Comparison of "x" and "y".
 
-void eq_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void eq_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) == 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) == 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief Comparison of "x" and "y".
 
-void ne_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void ne_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) != 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) != 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief Comparison of "x" and "y".
 
-void lt_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void lt_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) < 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) < 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief Comparison of "x" and "y".
 
-void le_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void le_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) <= 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) <= 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief Comparison of "x" and "y".
 
-void gt_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void gt_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) > 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) > 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief Comparison of "x" and "y".
 
-void ge_mp (NODE_T * p, A68_BOOL * z, MP_T * x, MP_T * y, int digs)
+void ge_mp (NODE_T * p, A68G_BOOL * z, MP_T * x, MP_T * y, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   MP_T *v = nil_mp (p, digs);
   (void) sub_mp (p, v, x, y, digs);
   STATUS (z) = INIT_MASK;
-  VALUE (z) = (MP_DIGIT (v, 1) >= 0 ? A68_TRUE : A68_FALSE);
-  A68_SP = pop_sp;
+  VALUE (z) = (MP_DIGIT (v, 1) >= 0 ? A68G_TRUE : A68G_FALSE);
+  A68G_SP = pop_sp;
 }
 
 //! @brief round (x).
