@@ -99,10 +99,10 @@ void pad_node (NODE_T * p, int a)
 
 void a68g_extension (NODE_T * p)
 {
-  if (OPTION_PORTCHECK (&A68_JOB)) {
-    diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_EXTENSION);
+  if (OPTION_PORTCHECK (&A68G_JOB)) {
+    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_EXTENSION);
   } else {
-    diagnostic (A68_WARNING, p, WARNING_EXTENSION);
+    diagnostic (A68G_WARNING, p, WARNING_EXTENSION);
   }
 }
 
@@ -110,7 +110,7 @@ void a68g_extension (NODE_T * p)
 
 void empty_clause (NODE_T * p)
 {
-  diagnostic (A68_SYNTAX_ERROR, p, ERROR_CLAUSE_WITHOUT_VALUE);
+  diagnostic (A68G_SYNTAX_ERROR, p, ERROR_CLAUSE_WITHOUT_VALUE);
 }
 
 #if !defined (BUILD_PARALLEL_CLAUSE)
@@ -119,7 +119,7 @@ void empty_clause (NODE_T * p)
 
 void par_clause (NODE_T * p)
 {
-  diagnostic (A68_SYNTAX_ERROR, p, ERROR_NO_PARALLEL_CLAUSE);
+  diagnostic (A68G_SYNTAX_ERROR, p, ERROR_NO_PARALLEL_CLAUSE);
 }
 
 #endif
@@ -129,7 +129,7 @@ void par_clause (NODE_T * p)
 void strange_tokens (NODE_T * p)
 {
   NODE_T *q = ((p != NO_NODE && NEXT (p) != NO_NODE) ? NEXT (p) : p);
-  diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_TOKENS);
+  diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_TOKENS);
 }
 
 //! @brief Diagnose for strange separator.
@@ -137,7 +137,7 @@ void strange_tokens (NODE_T * p)
 void strange_separator (NODE_T * p)
 {
   NODE_T *q = ((p != NO_NODE && NEXT (p) != NO_NODE) ? NEXT (p) : p);
-  diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_TOKENS);
+  diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_STRANGE_TOKENS);
 }
 
 //! @brief If match then reduce a sentence, the core BU parser routine.
@@ -152,10 +152,10 @@ void reduce (NODE_T * p, void (*a) (NODE_T *), BOOL_T * z, ...)
   {
     BOOL_T keep_matching;
     if (p == NO_NODE) {
-      keep_matching = A68_FALSE;
+      keep_matching = A68G_FALSE;
     } else if (expect == WILDCARD) {
 // WILDCARD matches any Algol68G non terminal, but no keyword.
-      keep_matching = (BOOL_T) (non_terminal_string (A68 (edit_line), ATTRIBUTE (p)) != NO_TEXT);
+      keep_matching = (BOOL_T) (non_terminal_string (A68G (edit_line), ATTRIBUTE (p)) != NO_TEXT);
     } else {
       if (expect == SKIP) {
 // Stray "~" matches expected SKIP.
@@ -178,26 +178,26 @@ void reduce (NODE_T * p, void (*a) (NODE_T *), BOOL_T * z, ...)
     }
   }
 // Print parser reductions.
-  if (head != NO_NODE && OPTION_REDUCTIONS (&A68_JOB) && LINE_NUMBER (head) > 0) {
-    A68_PARSER (reductions)++;
+  if (head != NO_NODE && OPTION_REDUCTIONS (&A68G_JOB) && LINE_NUMBER (head) > 0) {
+    A68G_PARSER (reductions)++;
     WIS (head);
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "\nReduction %d: %s<-", A68_PARSER (reductions), non_terminal_string (A68 (edit_line), result)) >= 0);
-    WRITE (A68_STDOUT, A68 (output_line));
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "\nReduction %d: %s<-", A68G_PARSER (reductions), non_terminal_string (A68G (edit_line), result)) >= 0);
+    WRITE (A68G_STDOUT, A68G (output_line));
     int count = 0;
     for (NODE_T *q = head; q != NO_NODE && tail != NO_NODE && q != NEXT (tail); FORWARD (q), count++) {
       int gatt = ATTRIBUTE (q);
-      char *str = non_terminal_string (A68 (input_line), gatt);
+      char *str = non_terminal_string (A68G (input_line), gatt);
       if (count > 0) {
-        WRITE (A68_STDOUT, ", ");
+        WRITE (A68G_STDOUT, ", ");
       }
       if (str != NO_TEXT) {
-        WRITE (A68_STDOUT, str);
+        WRITE (A68G_STDOUT, str);
         if (gatt == IDENTIFIER || gatt == OPERATOR || gatt == DENOTATION || gatt == INDICANT) {
-          ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (q)) >= 0);
-          WRITE (A68_STDOUT, A68 (output_line));
+          ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, " \"%s\"", NSYMBOL (q)) >= 0);
+          WRITE (A68G_STDOUT, A68G (output_line));
         }
       } else {
-        WRITE (A68_STDOUT, NSYMBOL (q));
+        WRITE (A68G_STDOUT, NSYMBOL (q));
       }
     }
   }
@@ -208,7 +208,7 @@ void reduce (NODE_T * p, void (*a) (NODE_T *), BOOL_T * z, ...)
   make_sub (head, tail, result);
   va_end (list);
   if (z != NO_TICK) {
-    *z = A68_TRUE;
+    *z = A68G_TRUE;
   }
 }
 
@@ -221,10 +221,10 @@ void ignore_superfluous_semicolons (NODE_T * p)
   for (; p != NO_NODE; FORWARD (p)) {
     ignore_superfluous_semicolons (SUB (p));
     if (NEXT (p) != NO_NODE && IS (NEXT (p), SEMI_SYMBOL) && NEXT_NEXT (p) == NO_NODE) {
-      diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, NEXT (p), WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (NEXT (p)));
+      diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, NEXT (p), WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (NEXT (p)));
       NEXT (p) = NO_NODE;
     } else if (IS (p, SEMI_SYMBOL) && is_semicolon_less (NEXT (p))) {
-      diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (p));
+      diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_SKIPPED_SUPERFLUOUS, ATTRIBUTE (p));
       if (PREVIOUS (p) != NO_NODE) {
         NEXT (PREVIOUS (p)) = NEXT (p);
       }
@@ -238,20 +238,20 @@ void ignore_superfluous_semicolons (NODE_T * p)
 void bottom_up_parser (NODE_T * p)
 {
   if (p != NO_NODE) {
-    if (!setjmp (A68_PARSER (bottom_up_crash_exit))) {
+    if (!setjmp (A68G_PARSER (bottom_up_crash_exit))) {
       NODE_T *q;
-      int error_count_0 = ERROR_COUNT (&A68_JOB);
+      int error_count_0 = ERROR_COUNT (&A68G_JOB);
       ignore_superfluous_semicolons (p);
 // A program is "label sequence; particular program".
       extract_labels (p, SERIAL_CLAUSE);
 // Parse the program itself.
       for (q = p; q != NO_NODE; FORWARD (q)) {
-        BOOL_T siga = A68_TRUE;
+        BOOL_T siga = A68G_TRUE;
         if (SUB (q) != NO_NODE) {
           reduce_branch (q, SOME_CLAUSE);
         }
         while (siga) {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
           reduce (q, NO_NOTE, &siga, LABEL, DEFINING_IDENTIFIER, COLON_SYMBOL, STOP);
           reduce (q, NO_NOTE, &siga, LABEL, LABEL, DEFINING_IDENTIFIER, COLON_SYMBOL, STOP);
         }
@@ -276,7 +276,7 @@ void bottom_up_parser (NODE_T * p)
       reduce (q, NO_NOTE, NO_TICK, PARTICULAR_PROGRAM, LABEL, ENCLOSED_CLAUSE, STOP);
       reduce (q, NO_NOTE, NO_TICK, PARTICULAR_PROGRAM, ENCLOSED_CLAUSE, STOP);
       if (SUB (p) == NO_NODE || NEXT (p) != NO_NODE) {
-        recover_from_error (p, PARTICULAR_PROGRAM, (BOOL_T) ((ERROR_COUNT (&A68_JOB) - error_count_0) > MAX_ERRORS));
+        recover_from_error (p, PARTICULAR_PROGRAM, (BOOL_T) ((ERROR_COUNT (&A68G_JOB) - error_count_0) > MAX_ERRORS));
       }
     }
   }
@@ -286,9 +286,9 @@ void bottom_up_parser (NODE_T * p)
 
 void reduce_code_clause (NODE_T * p)
 {
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
   while (siga) {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (NODE_T *u = p; u != NO_NODE; FORWARD (u)) {
       reduce (u, NO_NOTE, &siga, CODE_LIST, CODE_SYMBOL, ROW_CHAR_DENOTATION, STOP);
       reduce (u, NO_NOTE, &siga, CODE_LIST, CODE_LIST, ROW_CHAR_DENOTATION, STOP);
@@ -306,19 +306,19 @@ void reduce_branch (NODE_T * q, int expect)
 // as the parser can repair some faults. This gives less spurious diagnostics.
   if (q != NO_NODE && SUB (q) != NO_NODE) {
     NODE_T *p = SUB (q), *u = NO_NODE;
-    int error_count_0 = ERROR_COUNT (&A68_JOB), error_count_02;
-    BOOL_T declarer_pack = A68_FALSE, no_error;
+    int error_count_0 = ERROR_COUNT (&A68G_JOB), error_count_02;
+    BOOL_T declarer_pack = A68G_FALSE, no_error;
     switch (expect) {
     case STRUCTURE_PACK:
     case PARAMETER_PACK:
     case FORMAL_DECLARERS:
     case UNION_PACK:
     case SPECIFIER: {
-        declarer_pack = A68_TRUE;
+        declarer_pack = A68G_TRUE;
         break;
       }
     default: {
-        declarer_pack = A68_FALSE;
+        declarer_pack = A68G_FALSE;
         break;
       }
     }
@@ -329,21 +329,21 @@ void reduce_branch (NODE_T * q, int expect)
       extract_priorities (p);
       extract_operators (p);
     }
-    error_count_02 = ERROR_COUNT (&A68_JOB);
+    error_count_02 = ERROR_COUNT (&A68G_JOB);
     elaborate_bold_tags (p);
-    if ((ERROR_COUNT (&A68_JOB) - error_count_02) > 0) {
-      longjmp (A68_PARSER (bottom_up_crash_exit), 1);
+    if ((ERROR_COUNT (&A68G_JOB) - error_count_02) > 0) {
+      longjmp (A68G_PARSER (bottom_up_crash_exit), 1);
     }
 // Now we can reduce declarers, knowing which bold tags are indicants.
     reduce_declarers (p, expect);
 // Parse the phrase, as appropriate.
     if (expect == CODE_CLAUSE) {
       reduce_code_clause (p);
-    } else if (declarer_pack == A68_FALSE) {
-      error_count_02 = ERROR_COUNT (&A68_JOB);
+    } else if (declarer_pack == A68G_FALSE) {
+      error_count_02 = ERROR_COUNT (&A68G_JOB);
       extract_declarations (p);
-      if ((ERROR_COUNT (&A68_JOB) - error_count_02) > 0) {
-        longjmp (A68_PARSER (bottom_up_crash_exit), 1);
+      if ((ERROR_COUNT (&A68G_JOB) - error_count_02) > 0) {
+        longjmp (A68G_PARSER (bottom_up_crash_exit), 1);
       }
       extract_labels (p, expect);
       for (u = p; u != NO_NODE; FORWARD (u)) {
@@ -429,10 +429,10 @@ void reduce_branch (NODE_T * q, int expect)
     }
 // Do something if parsing failed.
     if (SUB (p) == NO_NODE || NEXT (p) != NO_NODE) {
-      recover_from_error (p, expect, (BOOL_T) ((ERROR_COUNT (&A68_JOB) - error_count_0) > MAX_ERRORS));
-      no_error = A68_FALSE;
+      recover_from_error (p, expect, (BOOL_T) ((ERROR_COUNT (&A68G_JOB) - error_count_0) > MAX_ERRORS));
+      no_error = A68G_FALSE;
     } else {
-      no_error = A68_TRUE;
+      no_error = A68G_TRUE;
     }
     ATTRIBUTE (q) = ATTRIBUTE (p);
     if (no_error) {
@@ -448,11 +448,11 @@ void reduce_declarers (NODE_T * p, int expect)
   NODE_T *q; BOOL_T siga; // Must be in this scope.
 // Reduce lengtheties.
   for (q = p; q != NO_NODE; FORWARD (q)) {
-    siga = A68_TRUE;
+    siga = A68G_TRUE;
     reduce (q, NO_NOTE, NO_TICK, LONGETY, LONG_SYMBOL, STOP);
     reduce (q, NO_NOTE, NO_TICK, SHORTETY, SHORT_SYMBOL, STOP);
     while (siga) {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, LONGETY, LONGETY, LONG_SYMBOL, STOP);
       reduce (q, NO_NOTE, &siga, SHORTETY, SHORTETY, SHORT_SYMBOL, STOP);
     }
@@ -480,28 +480,28 @@ void reduce_declarers (NODE_T * p, int expect)
     if (whether (q, LONGETY, INDICANT, STOP)) {
       int a;
       if (SUB_NEXT (q) == NO_NODE) {
-        diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
+        diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
         reduce (q, NO_NOTE, NO_TICK, DECLARER, LONGETY, INDICANT, STOP);
       } else {
         a = ATTRIBUTE (SUB_NEXT (q));
         if (a == INT_SYMBOL || a == REAL_SYMBOL || a == BITS_SYMBOL || a == BYTES_SYMBOL || a == COMPLEX_SYMBOL || a == COMPL_SYMBOL) {
           reduce (q, NO_NOTE, NO_TICK, DECLARER, LONGETY, INDICANT, STOP);
         } else {
-          diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
+          diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
           reduce (q, NO_NOTE, NO_TICK, DECLARER, LONGETY, INDICANT, STOP);
         }
       }
     } else if (whether (q, SHORTETY, INDICANT, STOP)) {
       int a;
       if (SUB_NEXT (q) == NO_NODE) {
-        diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
+        diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
         reduce (q, NO_NOTE, NO_TICK, DECLARER, SHORTETY, INDICANT, STOP);
       } else {
         a = ATTRIBUTE (SUB_NEXT (q));
         if (a == INT_SYMBOL || a == REAL_SYMBOL || a == BITS_SYMBOL || a == BYTES_SYMBOL || a == COMPLEX_SYMBOL || a == COMPL_SYMBOL) {
           reduce (q, NO_NOTE, NO_TICK, DECLARER, SHORTETY, INDICANT, STOP);
         } else {
-          diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
+          diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_EXPECTED, INFO_APPROPRIATE_DECLARER);
           reduce (q, NO_NOTE, NO_TICK, DECLARER, LONGETY, INDICANT, STOP);
         }
       }
@@ -535,9 +535,9 @@ void reduce_declarers (NODE_T * p, int expect)
     }
   }
 // Reduce row, proc or op declarers.
-  siga = A68_TRUE;
+  siga = A68G_TRUE;
   while (siga) {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (q = p; q != NO_NODE; FORWARD (q)) {
 // FLEX DECL.
       if (whether (q, FLEX_SYMBOL, DECLARER, STOP)) {
@@ -598,17 +598,17 @@ void reduce_declarers (NODE_T * p, int expect)
 // Reduce packs etcetera.
   if (expect == STRUCTURE_PACK) {
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, STRUCTURED_FIELD, DECLARER, IDENTIFIER, STOP);
         reduce (q, NO_NOTE, &siga, STRUCTURED_FIELD, STRUCTURED_FIELD, COMMA_SYMBOL, IDENTIFIER, STOP);
       }
     }
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, STRUCTURED_FIELD_LIST, STRUCTURED_FIELD, STOP);
         reduce (q, NO_NOTE, &siga, STRUCTURED_FIELD_LIST, STRUCTURED_FIELD_LIST, COMMA_SYMBOL, STRUCTURED_FIELD, STOP);
         reduce (q, strange_separator, &siga, STRUCTURED_FIELD_LIST, STRUCTURED_FIELD_LIST, STRUCTURED_FIELD, STOP);
@@ -619,17 +619,17 @@ void reduce_declarers (NODE_T * p, int expect)
     reduce (q, NO_NOTE, NO_TICK, STRUCTURE_PACK, OPEN_SYMBOL, STRUCTURED_FIELD_LIST, CLOSE_SYMBOL, STOP);
   } else if (expect == PARAMETER_PACK) {
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, PARAMETER, DECLARER, IDENTIFIER, STOP);
         reduce (q, NO_NOTE, &siga, PARAMETER, PARAMETER, COMMA_SYMBOL, IDENTIFIER, STOP);
       }
     }
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, PARAMETER_LIST, PARAMETER, STOP);
         reduce (q, NO_NOTE, &siga, PARAMETER_LIST, PARAMETER_LIST, COMMA_SYMBOL, PARAMETER, STOP);
       }
@@ -638,9 +638,9 @@ void reduce_declarers (NODE_T * p, int expect)
     reduce (q, NO_NOTE, NO_TICK, PARAMETER_PACK, OPEN_SYMBOL, PARAMETER_LIST, CLOSE_SYMBOL, STOP);
   } else if (expect == FORMAL_DECLARERS) {
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, FORMAL_DECLARERS_LIST, DECLARER, STOP);
         reduce (q, NO_NOTE, &siga, FORMAL_DECLARERS_LIST, FORMAL_DECLARERS_LIST, COMMA_SYMBOL, DECLARER, STOP);
         reduce (q, strange_separator, &siga, FORMAL_DECLARERS_LIST, FORMAL_DECLARERS_LIST, SEMI_SYMBOL, DECLARER, STOP);
@@ -651,9 +651,9 @@ void reduce_declarers (NODE_T * p, int expect)
     reduce (q, NO_NOTE, NO_TICK, FORMAL_DECLARERS, OPEN_SYMBOL, FORMAL_DECLARERS_LIST, CLOSE_SYMBOL, STOP);
   } else if (expect == UNION_PACK) {
     for (q = p; q != NO_NODE; FORWARD (q)) {
-      siga = A68_TRUE;
+      siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, UNION_DECLARER_LIST, DECLARER, STOP);
         reduce (q, NO_NOTE, &siga, UNION_DECLARER_LIST, VOID_SYMBOL, STOP);
         reduce (q, NO_NOTE, &siga, UNION_DECLARER_LIST, UNION_DECLARER_LIST, COMMA_SYMBOL, DECLARER, STOP);
@@ -788,9 +788,9 @@ void reduce_primary_parts (NODE_T * p, int expect)
     reduce (q, NO_NOTE, NO_TICK, DENOTATION, FALSE_SYMBOL, STOP);
     reduce (q, NO_NOTE, NO_TICK, DENOTATION, EMPTY_SYMBOL, STOP);
     if (expect == SERIAL_CLAUSE || expect == ENQUIRY_CLAUSE || expect == SOME_CLAUSE) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, LABEL, DEFINING_IDENTIFIER, COLON_SYMBOL, STOP);
         reduce (q, NO_NOTE, &siga, LABEL, LABEL, DEFINING_IDENTIFIER, COLON_SYMBOL, STOP);
       }
@@ -818,7 +818,7 @@ void reduce_primaries (NODE_T * p, int expect)
 {
   NODE_T *q = p;
   while (q != NO_NODE) {
-    BOOL_T fwd = A68_TRUE, siga;
+    BOOL_T fwd = A68G_TRUE, siga;
 // Primaries excepts call and slice.
     reduce (q, NO_NOTE, NO_TICK, PRIMARY, IDENTIFIER, STOP);
     reduce (q, NO_NOTE, NO_TICK, PRIMARY, DENOTATION, STOP);
@@ -829,10 +829,10 @@ void reduce_primaries (NODE_T * p, int expect)
     reduce (q, NO_NOTE, NO_TICK, PRIMARY, ENCLOSED_CLAUSE, STOP);
     reduce (q, NO_NOTE, NO_TICK, PRIMARY, FORMAT_TEXT, STOP);
 // Call and slice.
-    siga = A68_TRUE;
+    siga = A68G_TRUE;
     while (siga) {
       NODE_T *x = NEXT (q);
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       if (IS (q, PRIMARY) && x != NO_NODE) {
         if (IS (x, OPEN_SYMBOL)) {
           reduce_branch (NEXT (q), GENERIC_ARGUMENT);
@@ -855,7 +855,7 @@ void reduce_primaries (NODE_T * p, int expect)
       reduce (q, NO_NOTE, NO_TICK, ENCLOSED_CLAUSE, CONFORMITY_CLAUSE, STOP);
       if (PREVIOUS (q) != NO_NODE) {
         BACKWARD (q);
-        fwd = A68_FALSE;
+        fwd = A68G_FALSE;
       }
     }
 // Format text items.
@@ -894,7 +894,7 @@ void ambiguous_patterns (NODE_T * p)
     case COMPLEX_PATTERN:
     case BITS_PATTERN: {
         if (last_pat != NO_NODE) {
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_COMMA_MUST_SEPARATE, ATTRIBUTE (last_pat), ATTRIBUTE (q));
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_COMMA_MUST_SEPARATE, ATTRIBUTE (last_pat), ATTRIBUTE (q));
         }
         last_pat = q;
         break;
@@ -969,9 +969,9 @@ void reduce_format_texts (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, INSERTION, REPLICATOR, INSERTION, STOP);
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-    BOOL_T siga = A68_TRUE;
+    BOOL_T siga = A68G_TRUE;
     while (siga) {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, INSERTION, INSERTION, INSERTION, STOP);
     }
   }
@@ -1022,9 +1022,9 @@ void reduce_format_texts (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, STRING_PATTERN, FORMAT_A_FRAME, STOP);
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-    BOOL_T siga = A68_TRUE;
+    BOOL_T siga = A68G_TRUE;
     while (siga) {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, STRING_PATTERN, STRING_PATTERN, STRING_PATTERN, STOP);
       reduce (q, NO_NOTE, &siga, STRING_PATTERN, STRING_PATTERN, INSERTION, STRING_PATTERN, STOP);
     }
@@ -1035,9 +1035,9 @@ void reduce_format_texts (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, INTEGRAL_MOULD, FORMAT_D_FRAME, STOP);
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-    BOOL_T siga = A68_TRUE;
+    BOOL_T siga = A68G_TRUE;
     while (siga) {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, INTEGRAL_MOULD, INTEGRAL_MOULD, INTEGRAL_MOULD, STOP);
       reduce (q, NO_NOTE, &siga, INTEGRAL_MOULD, INTEGRAL_MOULD, INSERTION, STOP);
     }
@@ -1106,37 +1106,37 @@ void reduce_format_texts (NODE_T * p)
   }
   ambiguous_patterns (p);
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, BITS_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, CHAR_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, FIXED_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, FLOAT_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, GENERAL_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, INTEGRAL_C_PATTERN, STOP);
-    reduce (q, a68g_extension, NO_TICK, A68_PATTERN, STRING_C_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, BITS_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, BOOLEAN_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, CHOICE_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, COMPLEX_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, FORMAT_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, GENERAL_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, INTEGRAL_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, REAL_PATTERN, STOP);
-    reduce (q, NO_NOTE, NO_TICK, A68_PATTERN, STRING_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, BITS_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, CHAR_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, FIXED_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, FLOAT_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, GENERAL_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, INTEGRAL_C_PATTERN, STOP);
+    reduce (q, a68g_extension, NO_TICK, A68G_PATTERN, STRING_C_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, BITS_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, BOOLEAN_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, CHOICE_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, COMPLEX_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, FORMAT_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, GENERAL_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, INTEGRAL_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, REAL_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, A68G_PATTERN, STRING_PATTERN, STOP);
   }
 // Pictures.
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     reduce (q, NO_NOTE, NO_TICK, PICTURE, INSERTION, STOP);
-    reduce (q, NO_NOTE, NO_TICK, PICTURE, A68_PATTERN, STOP);
+    reduce (q, NO_NOTE, NO_TICK, PICTURE, A68G_PATTERN, STOP);
     reduce (q, NO_NOTE, NO_TICK, PICTURE, COLLECTION, STOP);
     reduce (q, NO_NOTE, NO_TICK, PICTURE, REPLICATOR, COLLECTION, STOP);
   }
 // Picture lists.
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     if (IS (q, PICTURE)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       reduce (q, NO_NOTE, NO_TICK, PICTURE_LIST, PICTURE, STOP);
       while (siga) {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, PICTURE_LIST, PICTURE_LIST, COMMA_SYMBOL, PICTURE, STOP);
 // We filtered ambiguous patterns, so commas may be omitted 
         reduce (q, NO_NOTE, &siga, PICTURE_LIST, PICTURE_LIST, PICTURE, STOP);
@@ -1157,9 +1157,9 @@ void reduce_secondaries (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, GENERATOR, NEW_SYMBOL, DECLARER, STOP);
     reduce (q, NO_NOTE, NO_TICK, SECONDARY, GENERATOR, STOP);
   }
-  siga = A68_TRUE;
+  siga = A68G_TRUE;
   while (siga) {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (q = p; NEXT (q) != NO_NODE; FORWARD (q)) {
       ;
     }
@@ -1193,7 +1193,7 @@ void reduce_formulae (NODE_T * p)
   for (int prio = MAX_PRIORITY; prio >= 0; prio--) {
     for (q = p; q != NO_NODE; FORWARD (q)) {
       if (operator_with_priority (q, prio)) {
-        BOOL_T siga = A68_FALSE;
+        BOOL_T siga = A68G_FALSE;
         NODE_T *op = NEXT (q);
         if (IS (q, SECONDARY)) {
           reduce (q, NO_NOTE, &siga, FORMULA, SECONDARY, OPERATOR, SECONDARY, STOP);
@@ -1205,12 +1205,12 @@ void reduce_formulae (NODE_T * p)
           reduce (q, NO_NOTE, &siga, FORMULA, MONADIC_FORMULA, OPERATOR, FORMULA, STOP);
         }
         if (prio == 0 && siga) {
-          diagnostic (A68_SYNTAX_ERROR, op, ERROR_NO_PRIORITY);
+          diagnostic (A68G_SYNTAX_ERROR, op, ERROR_NO_PRIORITY);
         }
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
         while (siga) {
           NODE_T *op2 = NEXT (q);
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
           if (operator_with_priority (q, prio)) {
             reduce (q, NO_NOTE, &siga, FORMULA, FORMULA, OPERATOR, SECONDARY, STOP);
           }
@@ -1221,7 +1221,7 @@ void reduce_formulae (NODE_T * p)
             reduce (q, NO_NOTE, &siga, FORMULA, FORMULA, OPERATOR, FORMULA, STOP);
           }
           if (prio == 0 && siga) {
-            diagnostic (A68_SYNTAX_ERROR, op2, ERROR_NO_PRIORITY);
+            diagnostic (A68G_SYNTAX_ERROR, op2, ERROR_NO_PRIORITY);
           }
         }
       }
@@ -1276,9 +1276,9 @@ void reduce_tertiaries (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, TERTIARY, FORMULA, STOP);
     reduce (q, NO_NOTE, NO_TICK, TERTIARY, SECONDARY, STOP);
   }
-  siga = A68_TRUE;
+  siga = A68G_TRUE;
   while (siga) {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
       reduce (q, NO_NOTE, &siga, TRANSPOSE_FUNCTION, TRANSPOSE_SYMBOL, TERTIARY, STOP);
       reduce (q, NO_NOTE, &siga, DIAGONAL_FUNCTION, TERTIARY, DIAGONAL_SYMBOL, TERTIARY, STOP);
@@ -1381,7 +1381,7 @@ void reduce_generic_arguments (NODE_T * p)
   reduce (q, NO_NOTE, NO_TICK, GENERIC_ARGUMENT_LIST, UNIT, STOP);
   reduce (q, NO_NOTE, NO_TICK, GENERIC_ARGUMENT_LIST, TRIMMER, STOP);
   do {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     reduce (q, NO_NOTE, &siga, GENERIC_ARGUMENT_LIST, GENERIC_ARGUMENT_LIST, COMMA_SYMBOL, UNIT, STOP);
     reduce (q, NO_NOTE, &siga, GENERIC_ARGUMENT_LIST, GENERIC_ARGUMENT_LIST, COMMA_SYMBOL, TRIMMER, STOP);
     reduce (q, strange_separator, &siga, GENERIC_ARGUMENT_LIST, GENERIC_ARGUMENT_LIST, UNIT, STOP);
@@ -1405,7 +1405,7 @@ void reduce_bounds (NODE_T * p)
   reduce (q, NO_NOTE, NO_TICK, ALT_FORMAL_BOUNDS_LIST, COLON_SYMBOL, STOP);
   reduce (q, NO_NOTE, NO_TICK, ALT_FORMAL_BOUNDS_LIST, DOTDOT_SYMBOL, STOP);
   do {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     reduce (q, NO_NOTE, &siga, BOUNDS_LIST, BOUNDS_LIST, COMMA_SYMBOL, BOUND, STOP);
     reduce (q, NO_NOTE, &siga, FORMAL_BOUNDS_LIST, FORMAL_BOUNDS_LIST, COMMA_SYMBOL, STOP);
     reduce (q, NO_NOTE, &siga, ALT_FORMAL_BOUNDS_LIST, FORMAL_BOUNDS_LIST, COLON_SYMBOL, STOP);
@@ -1424,7 +1424,7 @@ void reduce_arguments (NODE_T * p)
     BOOL_T siga;
     reduce (q, NO_NOTE, NO_TICK, ARGUMENT_LIST, UNIT, STOP);
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, ARGUMENT_LIST, ARGUMENT_LIST, COMMA_SYMBOL, UNIT, STOP);
       reduce (q, strange_separator, &siga, ARGUMENT_LIST, ARGUMENT_LIST, UNIT, STOP);
     } while (siga);
@@ -1457,7 +1457,7 @@ void reduce_basic_declarations (NODE_T * p)
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     BOOL_T siga;
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, ENVIRON_NAME, ENVIRON_NAME, COMMA_SYMBOL, ROW_CHAR_DENOTATION, STOP);
       reduce (q, NO_NOTE, &siga, PRIORITY_DECLARATION, PRIORITY_DECLARATION, COMMA_SYMBOL, DEFINING_OPERATOR, EQUALS_SYMBOL, PRIORITY, STOP);
       reduce (q, NO_NOTE, &siga, MODE_DECLARATION, MODE_DECLARATION, COMMA_SYMBOL, DEFINING_INDICANT, EQUALS_SYMBOL, DECLARER, STOP);
@@ -1485,7 +1485,7 @@ void reduce_declaration_lists (NODE_T * p)
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     BOOL_T siga;
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, IDENTITY_DECLARATION, IDENTITY_DECLARATION, COMMA_SYMBOL, DEFINING_IDENTIFIER, EQUALS_SYMBOL, UNIT, STOP);
       reduce (q, NO_NOTE, &siga, VARIABLE_DECLARATION, VARIABLE_DECLARATION, COMMA_SYMBOL, DEFINING_IDENTIFIER, ASSIGN_SYMBOL, UNIT, STOP);
       if (!whether (q, VARIABLE_DECLARATION, COMMA_SYMBOL, DEFINING_IDENTIFIER, ASSIGN_SYMBOL, UNIT, STOP)) {
@@ -1499,7 +1499,7 @@ void reduce_declaration_lists (NODE_T * p)
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     BOOL_T siga;
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, OPERATOR_DECLARATION, OPERATOR_DECLARATION, COMMA_SYMBOL, DEFINING_OPERATOR, EQUALS_SYMBOL, UNIT, STOP);
     } while (siga);
   }
@@ -1517,7 +1517,7 @@ void reduce_declaration_lists (NODE_T * p)
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     BOOL_T siga;
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       reduce (q, NO_NOTE, &siga, DECLARATION_LIST, DECLARATION_LIST, COMMA_SYMBOL, DECLARATION_LIST, STOP);
     } while (siga);
   }
@@ -1534,17 +1534,17 @@ void reduce_serial_clauses (NODE_T * p)
     for (u = q; u != NO_NODE; FORWARD (u)) {
       if (IS (u, EXIT_SYMBOL)) {
         if (NEXT (u) == NO_NODE || !IS (NEXT (u), LABELED_UNIT)) {
-          diagnostic (A68_SYNTAX_ERROR, u, ERROR_LABELED_UNIT_MUST_FOLLOW);
+          diagnostic (A68G_SYNTAX_ERROR, u, ERROR_LABELED_UNIT_MUST_FOLLOW);
         }
       }
     }
 // Check wrong jumps and declarations.
-    for (u = q, label_seen = A68_FALSE; u != NO_NODE; FORWARD (u)) {
+    for (u = q, label_seen = A68G_FALSE; u != NO_NODE; FORWARD (u)) {
       if (IS (u, LABELED_UNIT)) {
-        label_seen = A68_TRUE;
+        label_seen = A68G_TRUE;
       } else if (IS (u, DECLARATION_LIST)) {
         if (label_seen) {
-          diagnostic (A68_SYNTAX_ERROR, u, ERROR_LABEL_BEFORE_DECLARATION);
+          diagnostic (A68G_SYNTAX_ERROR, u, ERROR_LABEL_BEFORE_DECLARATION);
         }
       }
     }
@@ -1553,7 +1553,7 @@ void reduce_serial_clauses (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, SERIAL_CLAUSE, UNIT, STOP);
     reduce (q, NO_NOTE, NO_TICK, INITIALISER_SERIES, DECLARATION_LIST, STOP);
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       if (IS (q, SERIAL_CLAUSE)) {
         reduce (q, NO_NOTE, &siga, SERIAL_CLAUSE, SERIAL_CLAUSE, SEMI_SYMBOL, UNIT, STOP);
         reduce (q, NO_NOTE, &siga, SERIAL_CLAUSE, SERIAL_CLAUSE, EXIT_SYMBOL, LABELED_UNIT, STOP);
@@ -1599,7 +1599,7 @@ void reduce_enquiry_clauses (NODE_T * p)
     reduce (q, NO_NOTE, NO_TICK, ENQUIRY_CLAUSE, UNIT, STOP);
     reduce (q, NO_NOTE, NO_TICK, INITIALISER_SERIES, DECLARATION_LIST, STOP);
     do {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
       if (IS (q, ENQUIRY_CLAUSE)) {
         reduce (q, NO_NOTE, &siga, ENQUIRY_CLAUSE, ENQUIRY_CLAUSE, SEMI_SYMBOL, UNIT, STOP);
         reduce (q, NO_NOTE, &siga, INITIALISER_SERIES, ENQUIRY_CLAUSE, SEMI_SYMBOL, DECLARATION_LIST, STOP);
@@ -1634,7 +1634,7 @@ void reduce_collateral_clauses (NODE_T * p)
       BOOL_T siga;
       reduce (q, NO_NOTE, NO_TICK, UNIT_LIST, UNIT, STOP);
       do {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, UNIT_LIST, UNIT_LIST, COMMA_SYMBOL, UNIT, STOP);
         reduce (q, strange_separator, &siga, UNIT_LIST, UNIT_LIST, UNIT, STOP);
       } while (siga);
@@ -1642,7 +1642,7 @@ void reduce_collateral_clauses (NODE_T * p)
       BOOL_T siga;
       reduce (q, NO_NOTE, NO_TICK, SPECIFIED_UNIT_LIST, SPECIFIED_UNIT, STOP);
       do {
-        siga = A68_FALSE;
+        siga = A68G_FALSE;
         reduce (q, NO_NOTE, &siga, SPECIFIED_UNIT_LIST, SPECIFIED_UNIT_LIST, COMMA_SYMBOL, SPECIFIED_UNIT, STOP);
         reduce (q, strange_separator, &siga, SPECIFIED_UNIT_LIST, SPECIFIED_UNIT_LIST, SPECIFIED_UNIT, STOP);
       } while (siga);
@@ -1863,14 +1863,14 @@ void recover_from_error (NODE_T * p, int expect, BOOL_T suppress)
     NODE_T *w = p;
     char *seq = phrase_to_text (p, &w);
     if (strlen (seq) == 0) {
-      if (ERROR_COUNT (&A68_JOB) == 0) {
-        diagnostic (A68_SYNTAX_ERROR, w, ERROR_SYNTAX_EXPECTED, expect);
+      if (ERROR_COUNT (&A68G_JOB) == 0) {
+        diagnostic (A68G_SYNTAX_ERROR, w, ERROR_SYNTAX_EXPECTED, expect);
       }
     } else {
-      diagnostic (A68_SYNTAX_ERROR, w, ERROR_SYNTAX_SENTENCE, seq);
+      diagnostic (A68G_SYNTAX_ERROR, w, ERROR_SYNTAX_SENTENCE, seq);
     }
-    if (ERROR_COUNT (&A68_JOB) >= MAX_ERRORS) {
-      longjmp (A68_PARSER (bottom_up_crash_exit), 1);
+    if (ERROR_COUNT (&A68G_JOB) >= MAX_ERRORS) {
+      longjmp (A68G_PARSER (bottom_up_crash_exit), 1);
     }
   }
 // Try to prevent spurious diagnostics by guessing what was expected.
@@ -1923,7 +1923,7 @@ void recover_from_error (NODE_T * p, int expect, BOOL_T suppress)
     make_sub (p, q, DO_PART);
   } else if (is_one_of (p, ALT_DO_SYMBOL, ALT_DO_PART, STOP)) {
     make_sub (p, q, ALT_DO_PART);
-  } else if (non_terminal_string (A68 (edit_line), expect) != NO_TEXT) {
+  } else if (non_terminal_string (A68G (edit_line), expect) != NO_TEXT) {
     make_sub (p, q, expect);
   }
 }
@@ -1938,15 +1938,15 @@ void reduce_erroneous_units (NODE_T * p)
 // of ambiguity. Algol68G follows RR, so some extra attention here to guide an
 // unsuspecting user.
     if (whether (q, SELECTOR, -SECONDARY, STOP)) {
-      diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, SECONDARY);
+      diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, SECONDARY);
       reduce (q, NO_NOTE, NO_TICK, UNIT, SELECTOR, WILDCARD, STOP);
     }
 // Attention for identity relations that require tertiaries.
     if (whether (q, -TERTIARY, IS_SYMBOL, TERTIARY, STOP) || whether (q, TERTIARY, IS_SYMBOL, -TERTIARY, STOP) || whether (q, -TERTIARY, IS_SYMBOL, -TERTIARY, STOP)) {
-      diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, TERTIARY);
+      diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, TERTIARY);
       reduce (q, NO_NOTE, NO_TICK, UNIT, WILDCARD, IS_SYMBOL, WILDCARD, STOP);
     } else if (whether (q, -TERTIARY, ISNT_SYMBOL, TERTIARY, STOP) || whether (q, TERTIARY, ISNT_SYMBOL, -TERTIARY, STOP) || whether (q, -TERTIARY, ISNT_SYMBOL, -TERTIARY, STOP)) {
-      diagnostic (A68_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, TERTIARY);
+      diagnostic (A68G_SYNTAX_ERROR, NEXT (q), ERROR_SYNTAX_EXPECTED, TERTIARY);
       reduce (q, NO_NOTE, NO_TICK, UNIT, WILDCARD, ISNT_SYMBOL, WILDCARD, STOP);
     }
   }
@@ -1963,7 +1963,7 @@ void bottom_up_error_check (NODE_T * p)
       int k = 0;
       count_pictures (SUB (p), &k);
       if (!(k == 0 || k == 2)) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_FORMAT_PICTURE_NUMBER, ATTRIBUTE (p));
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_FORMAT_PICTURE_NUMBER, ATTRIBUTE (p));
       }
     } else {
       bottom_up_error_check (SUB (p));
