@@ -78,7 +78,7 @@
 void mode_checker (NODE_T * p)
 {
   if (IS (p, PARTICULAR_PROGRAM)) {
-    A68 (top_soid_list) = NO_SOID;
+    A68G (top_soid_list) = NO_SOID;
     SOID_T x, y;
     MOID (&y) = NO_MOID;
     make_soid (&x, STRONG, M_VOID, 0);
@@ -131,7 +131,7 @@ void mode_check_identity_declaration (NODE_T * p)
     case DECLARER: {
         mode_check_declarer (SUB (p));
         mode_check_identity_declaration (NEXT (p));
-        break;
+        return;
       }
     case DEFINING_IDENTIFIER: {
         SOID_T x, y;
@@ -143,12 +143,12 @@ void mode_check_identity_declaration (NODE_T * p)
 // Check for instance, REF INT i = LOC REF INT.
           semantic_pitfall (NEXT_NEXT (p), MOID (&x), IDENTITY_DECLARATION, GENERATOR);
         }
-        break;
+        return;
       }
     default: {
         mode_check_identity_declaration (SUB (p));
         mode_check_identity_declaration (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -163,7 +163,7 @@ void mode_check_variable_declaration (NODE_T * p)
     case DECLARER: {
         mode_check_declarer (SUB (p));
         mode_check_variable_declaration (NEXT (p));
-        break;
+        return;
       }
     case DEFINING_IDENTIFIER: {
         if (whether (p, DEFINING_IDENTIFIER, ASSIGN_SYMBOL, UNIT, STOP)) {
@@ -177,12 +177,12 @@ void mode_check_variable_declaration (NODE_T * p)
             semantic_pitfall (NEXT_NEXT (p), MOID (&x), VARIABLE_DECLARATION, GENERATOR);
           }
         }
-        break;
+        return;
       }
     default: {
         mode_check_variable_declaration (SUB (p));
         mode_check_variable_declaration (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -269,33 +269,33 @@ void mode_check_declaration_list (NODE_T * p)
     switch (ATTRIBUTE (p)) {
     case IDENTITY_DECLARATION: {
         mode_check_identity_declaration (SUB (p));
-        break;
+        return;
       }
     case VARIABLE_DECLARATION: {
         mode_check_variable_declaration (SUB (p));
-        break;
+        return;
       }
     case MODE_DECLARATION: {
         mode_check_declarer (SUB (p));
-        break;
+        return;
       }
     case PROCEDURE_DECLARATION:
     case PROCEDURE_VARIABLE_DECLARATION: {
         mode_check_proc_declaration (SUB (p));
-        break;
+        return;
       }
     case BRIEF_OPERATOR_DECLARATION: {
         mode_check_brief_op_declaration (SUB (p));
-        break;
+        return;
       }
     case OPERATOR_DECLARATION: {
         mode_check_op_declaration (SUB (p));
-        break;
+        return;
       }
     default: {
         mode_check_declaration_list (SUB (p));
         mode_check_declaration_list (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -308,7 +308,7 @@ void mode_check_serial (SOID_T ** r, NODE_T * p, SOID_T * x, BOOL_T k)
   if (p == NO_NODE) {
     return;
   } else if (IS (p, INITIALISER_SERIES)) {
-    mode_check_serial (r, SUB (p), x, A68_FALSE);
+    mode_check_serial (r, SUB (p), x, A68G_FALSE);
     mode_check_serial (r, NEXT (p), x, k);
   } else if (IS (p, DECLARATION_LIST)) {
     mode_check_declaration_list (SUB (p));
@@ -317,13 +317,13 @@ void mode_check_serial (SOID_T ** r, NODE_T * p, SOID_T * x, BOOL_T k)
   } else if (is_one_of (p, SERIAL_CLAUSE, ENQUIRY_CLAUSE, STOP)) {
     if (NEXT (p) != NO_NODE) {
       if (IS (NEXT (p), EXIT_SYMBOL) || IS (NEXT (p), END_SYMBOL) || IS (NEXT (p), CLOSE_SYMBOL)) {
-        mode_check_serial (r, SUB (p), x, A68_TRUE);
+        mode_check_serial (r, SUB (p), x, A68G_TRUE);
       } else {
-        mode_check_serial (r, SUB (p), x, A68_FALSE);
+        mode_check_serial (r, SUB (p), x, A68G_FALSE);
       }
       mode_check_serial (r, NEXT (p), x, k);
     } else {
-      mode_check_serial (r, SUB (p), x, A68_TRUE);
+      mode_check_serial (r, SUB (p), x, A68G_TRUE);
     }
   } else if (IS (p, LABELED_UNIT)) {
     mode_check_serial (r, SUB (p), x, k);
@@ -352,7 +352,7 @@ void mode_check_serial_units (NODE_T * p, SOID_T * x, SOID_T * y, int att)
 {
   SOID_T *top_sl = NO_SOID;
   (void) att;
-  mode_check_serial (&top_sl, SUB (p), x, A68_TRUE);
+  mode_check_serial (&top_sl, SUB (p), x, A68G_TRUE);
   if (is_balanced (p, top_sl, SORT (x))) {
     MOID_T *result = pack_soids_in_moid (top_sl, SERIES_MODE);
     make_soid (y, SORT (x), result, SERIAL_CLAUSE);
@@ -430,7 +430,7 @@ void mode_check_specified_unit_list (SOID_T ** r, NODE_T * p, SOID_T * x, MOID_T
     } else if (IS (p, SPECIFIER)) {
       MOID_T *m = MOID (NEXT_SUB (p));
       if (u != NO_MOID && !is_unitable (m, u, SAFE_DEFLEXING)) {
-        diagnostic (A68_ERROR, p, ERROR_NO_COMPONENT, m, u);
+        diagnostic (A68G_ERROR, p, ERROR_NO_COMPONENT, m, u);
       }
     } else if (IS (p, UNIT)) {
       SOID_T y;
@@ -479,7 +479,7 @@ void mode_check_united_case_parts (SOID_T ** ry, NODE_T * p, SOID_T * x)
         w = absorb_related_subsets (u);
       }
     } else {
-      diagnostic (A68_ERROR, NEXT_SUB (p), ERROR_NO_UNION, u);
+      diagnostic (A68G_ERROR, NEXT_SUB (p), ERROR_NO_UNION, u);
       return;
     }
   }
@@ -490,7 +490,7 @@ void mode_check_united_case_parts (SOID_T ** ry, NODE_T * p, SOID_T * x)
 // OUSE, OUT, ESAC.
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, OUT_PART, CHOICE, STOP)) {
-      mode_check_serial (ry, NEXT_SUB (p), x, A68_TRUE);
+      mode_check_serial (ry, NEXT_SUB (p), x, A68G_TRUE);
     } else if (is_one_of (p, CONFORMITY_OUSE_PART, BRIEF_CONFORMITY_OUSE_PART, STOP)) {
       mode_check_united_case_parts (ry, SUB (p), x);
     }
@@ -567,7 +567,7 @@ void mode_check_collateral (NODE_T * p, SOID_T * x, SOID_T * y)
   } else if (whether (p, BEGIN_SYMBOL, END_SYMBOL, STOP) || whether (p, OPEN_SYMBOL, CLOSE_SYMBOL, STOP)) {
     if (SORT (x) == STRONG) {
       if (MOID (x) == NO_MOID) {
-        diagnostic (A68_ERROR, p, ERROR_VACUUM, "REF MODE");
+        diagnostic (A68G_ERROR, p, ERROR_VACUUM, "REF MODE");
       } else {
         make_soid (y, STRONG, M_VACUUM, 0);
       }
@@ -595,10 +595,10 @@ void mode_check_conditional_2 (SOID_T ** ry, NODE_T * p, SOID_T * x)
     cannot_coerce (p, MOID (&enq_yield), MOID (&enq_expct), MEEK, SAFE_DEFLEXING, ENQUIRY_CLAUSE);
   }
   FORWARD (p);
-  mode_check_serial (ry, NEXT_SUB (p), x, A68_TRUE);
+  mode_check_serial (ry, NEXT_SUB (p), x, A68G_TRUE);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, ELSE_PART, CHOICE, STOP)) {
-      mode_check_serial (ry, NEXT_SUB (p), x, A68_TRUE);
+      mode_check_serial (ry, NEXT_SUB (p), x, A68G_TRUE);
     } else if (is_one_of (p, ELIF_PART, BRIEF_ELIF_PART, STOP)) {
       mode_check_conditional_2 (ry, SUB (p), x);
     }
@@ -638,7 +638,7 @@ void mode_check_int_case_2 (SOID_T ** ry, NODE_T * p, SOID_T * x)
   mode_check_unit_list (ry, NEXT_SUB (p), x);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, OUT_PART, CHOICE, STOP)) {
-      mode_check_serial (ry, NEXT_SUB (p), x, A68_TRUE);
+      mode_check_serial (ry, NEXT_SUB (p), x, A68G_TRUE);
     } else if (is_one_of (p, CASE_OUSE_PART, BRIEF_OUSE_PART, STOP)) {
       mode_check_int_case_2 (ry, SUB (p), x);
     }
@@ -694,7 +694,7 @@ void mode_check_loop_2 (NODE_T * p, SOID_T * y)
     SOID_T ix;
     make_soid (&ix, STRONG, M_VOID, 0);
     if (IS (do_p, SERIAL_CLAUSE)) {
-      mode_check_serial (&z, do_p, &ix, A68_TRUE);
+      mode_check_serial (&z, do_p, &ix, A68G_TRUE);
       un_p = NEXT (do_p);
     } else {
       un_p = do_p;
@@ -753,9 +753,9 @@ void mode_check_enclosed (NODE_T * p, SOID_T * x, SOID_T * y)
 TAG_T *search_table_for_operator (TAG_T * t, const char *n, MOID_T * x, MOID_T * y)
 {
   if (is_mode_isnt_well (x)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   } else if (y != NO_MOID && is_mode_isnt_well (y)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   }
   for (; t != NO_TAG; FORWARD (t)) {
     if (NSYMBOL (NODE (t)) == n) {
@@ -780,9 +780,9 @@ TAG_T *search_table_for_operator (TAG_T * t, const char *n, MOID_T * x, MOID_T *
 TAG_T *search_table_chain_for_operator (TABLE_T * s, char *n, MOID_T * x, MOID_T * y)
 {
   if (is_mode_isnt_well (x)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   } else if (y != NO_MOID && is_mode_isnt_well (y)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   }
   while (s != NO_TABLE) {
     TAG_T *z = search_table_for_operator (OPERATORS (s), n, x, y);
@@ -804,9 +804,9 @@ TAG_T *find_operator (TABLE_T * s, char *n, MOID_T * x, MOID_T * y)
   if (x == NO_MOID && y == NO_MOID) {
     return NO_TAG;
   } else if (is_mode_isnt_well (x)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   } else if (y != NO_MOID && is_mode_isnt_well (y)) {
-    return A68_PARSER (error_tag);
+    return A68G_PARSER (error_tag);
   }
 // (B) MONADs.
   if (x != NO_MOID && y == NO_MOID) {
@@ -816,19 +816,19 @@ TAG_T *find_operator (TABLE_T * s, char *n, MOID_T * x, MOID_T * y)
     } else {
 // (B.2) A little trick to allow - (0, 1) or ABS (1, long pi).
       if (is_coercible (x, M_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-        z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_COMPLEX, NO_MOID);
+        z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_COMPLEX, NO_MOID);
         if (z != NO_TAG) {
           return z;
         }
       }
       if (is_coercible (x, M_LONG_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-        z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_COMPLEX, NO_MOID);
+        z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_COMPLEX, NO_MOID);
         if (z != NO_TAG) {
           return z;
         }
       }
       if (is_coercible (x, M_LONG_LONG_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-        z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_LONG_COMPLEX, NO_MOID);
+        z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_LONG_COMPLEX, NO_MOID);
       }
     }
     return NO_TAG;
@@ -846,30 +846,30 @@ TAG_T *find_operator (TABLE_T * s, char *n, MOID_T * x, MOID_T * y)
       || (u == M_ROW_COMPLEX || u == M_ROW_ROW_COMPLEX)
       || (v == M_ROW_COMPLEX || v == M_ROW_ROW_COMPLEX)) {
     if (u == M_INT) {
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_REAL, y);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_REAL, y);
       if (z != NO_TAG) {
         return z;
       }
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_COMPLEX, y);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_COMPLEX, y);
       if (z != NO_TAG) {
         return z;
       }
     } else if (v == M_INT) {
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, x, M_REAL);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, x, M_REAL);
       if (z != NO_TAG) {
         return z;
       }
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, x, M_COMPLEX);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, x, M_COMPLEX);
       if (z != NO_TAG) {
         return z;
       }
     } else if (u == M_REAL) {
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_COMPLEX, y);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_COMPLEX, y);
       if (z != NO_TAG) {
         return z;
       }
     } else if (v == M_REAL) {
-      z = search_table_for_operator (OPERATORS (A68_STANDENV), n, x, M_COMPLEX);
+      z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, x, M_COMPLEX);
       if (z != NO_TAG) {
         return z;
       }
@@ -879,49 +879,49 @@ TAG_T *find_operator (TABLE_T * s, char *n, MOID_T * x, MOID_T * y)
   u = make_series_from_moids (x, y);
   u = make_united_mode (u);
   v = get_balanced_mode (u, STRONG, NO_DEPREF, SAFE_DEFLEXING);
-  z = search_table_for_operator (OPERATORS (A68_STANDENV), n, v, v);
+  z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, v, v);
   if (z != NO_TAG) {
     return z;
   }
   if (is_coercible_series (u, M_REAL, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_REAL, M_REAL);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_REAL, M_REAL);
     if (z != NO_TAG) {
       return z;
     }
   }
   if (is_coercible_series (u, M_LONG_REAL, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_REAL, M_LONG_REAL);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_REAL, M_LONG_REAL);
     if (z != NO_TAG) {
       return z;
     }
   }
   if (is_coercible_series (u, M_LONG_LONG_REAL, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_LONG_REAL, M_LONG_LONG_REAL);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_LONG_REAL, M_LONG_LONG_REAL);
     if (z != NO_TAG) {
       return z;
     }
   }
   if (is_coercible_series (u, M_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_COMPLEX, M_COMPLEX);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_COMPLEX, M_COMPLEX);
     if (z != NO_TAG) {
       return z;
     }
   }
   if (is_coercible_series (u, M_LONG_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_COMPLEX, M_LONG_COMPLEX);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_COMPLEX, M_LONG_COMPLEX);
     if (z != NO_TAG) {
       return z;
     }
   }
   if (is_coercible_series (u, M_LONG_LONG_COMPLEX, STRONG, SAFE_DEFLEXING)) {
-    z = search_table_for_operator (OPERATORS (A68_STANDENV), n, M_LONG_LONG_COMPLEX, M_LONG_LONG_COMPLEX);
+    z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, M_LONG_LONG_COMPLEX, M_LONG_LONG_COMPLEX);
     if (z != NO_TAG) {
       return z;
     }
   }
 // (C.4) Now allow for depreffing for REF REAL +:= INT and alike.
   v = get_balanced_mode (u, STRONG, DEPREF, SAFE_DEFLEXING);
-  z = search_table_for_operator (OPERATORS (A68_STANDENV), n, v, v);
+  z = search_table_for_operator (OPERATORS (A68G_STANDENV), n, v, v);
   if (z != NO_TAG) {
     return z;
   }
@@ -938,17 +938,17 @@ void mode_check_monadic_operator (NODE_T * p, SOID_T * x, SOID_T * y)
     if (is_mode_isnt_well (u)) {
       make_soid (y, SORT (x), M_ERROR, 0);
     } else if (u == M_HIP) {
-      diagnostic (A68_ERROR, NEXT (p), ERROR_INVALID_OPERAND, u);
+      diagnostic (A68G_ERROR, NEXT (p), ERROR_INVALID_OPERAND, u);
       make_soid (y, SORT (x), M_ERROR, 0);
     } else {
       if (strchr (NOMADS, *(NSYMBOL (p))) != NO_TEXT) {
         t = NO_TAG;
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_OPERATOR_INVALID, NOMADS);
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_OPERATOR_INVALID, NOMADS);
         make_soid (y, SORT (x), M_ERROR, 0);
       } else {
         t = find_operator (TABLE (p), NSYMBOL (p), u, NO_MOID);
         if (t == NO_TAG) {
-          diagnostic (A68_ERROR, p, ERROR_NO_MONADIC, u);
+          diagnostic (A68G_ERROR, p, ERROR_NO_MONADIC, u);
           make_soid (y, SORT (x), M_ERROR, 0);
         }
       }
@@ -956,7 +956,7 @@ void mode_check_monadic_operator (NODE_T * p, SOID_T * x, SOID_T * y)
         MOID (p) = MOID (t);
       }
       TAX (p) = t;
-      if (t != NO_TAG && t != A68_PARSER (error_tag)) {
+      if (t != NO_TAG && t != A68G_PARSER (error_tag)) {
         MOID (p) = MOID (t);
         make_soid (y, SORT (x), SUB_MOID (t), 0);
       } else {
@@ -1013,22 +1013,22 @@ void mode_check_formula (NODE_T * p, SOID_T * x, SOID_T * y)
     if (is_mode_isnt_well (u) || is_mode_isnt_well (v)) {
       make_soid (y, SORT (x), M_ERROR, 0);
     } else if (u == M_HIP) {
-      diagnostic (A68_ERROR, p, ERROR_INVALID_OPERAND, u);
+      diagnostic (A68G_ERROR, p, ERROR_INVALID_OPERAND, u);
       make_soid (y, SORT (x), M_ERROR, 0);
     } else if (v == M_HIP) {
-      diagnostic (A68_ERROR, q, ERROR_INVALID_OPERAND, u);
+      diagnostic (A68G_ERROR, q, ERROR_INVALID_OPERAND, u);
       make_soid (y, SORT (x), M_ERROR, 0);
     } else {
       TAG_T *op = find_operator (TABLE (NEXT (p)), NSYMBOL (NEXT (p)), u, v);
       if (op == NO_TAG) {
-        diagnostic (A68_ERROR, NEXT (p), ERROR_NO_DYADIC, u, v);
+        diagnostic (A68G_ERROR, NEXT (p), ERROR_NO_DYADIC, u, v);
         make_soid (y, SORT (x), M_ERROR, 0);
       }
       if (op != NO_TAG) {
         MOID (NEXT (p)) = MOID (op);
       }
       TAX (NEXT (p)) = op;
-      if (op != NO_TAG && op != A68_PARSER (error_tag)) {
+      if (op != NO_TAG && op != A68G_PARSER (error_tag)) {
         make_soid (y, SORT (x), SUB_MOID (op), 0);
       } else {
         make_soid (y, SORT (x), M_ERROR, 0);
@@ -1050,7 +1050,7 @@ void mode_check_assignation (NODE_T * p, SOID_T * x, SOID_T * y)
   MOID_T *name_moid = deproc_completely (ori);
   if (ATTRIBUTE (name_moid) != REF_SYMBOL) {
     if (IF_MODE_IS_WELL (name_moid)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_NAME, ori, ATTRIBUTE (SUB (p)));
+      diagnostic (A68G_ERROR, p, ERROR_NO_NAME, ori, ATTRIBUTE (SUB (p)));
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
@@ -1082,15 +1082,15 @@ void mode_check_identity_relation (NODE_T * p, SOID_T * x, SOID_T * y)
   MOID_T *lhs = deproc_completely (oril);
   MOID_T *rhs = deproc_completely (orir);
   if (IF_MODE_IS_WELL (lhs) && lhs != M_HIP && ATTRIBUTE (lhs) != REF_SYMBOL) {
-    diagnostic (A68_ERROR, ln, ERROR_NO_NAME, oril, ATTRIBUTE (SUB (ln)));
+    diagnostic (A68G_ERROR, ln, ERROR_NO_NAME, oril, ATTRIBUTE (SUB (ln)));
     lhs = M_ERROR;
   }
   if (IF_MODE_IS_WELL (rhs) && rhs != M_HIP && ATTRIBUTE (rhs) != REF_SYMBOL) {
-    diagnostic (A68_ERROR, rn, ERROR_NO_NAME, orir, ATTRIBUTE (SUB (rn)));
+    diagnostic (A68G_ERROR, rn, ERROR_NO_NAME, orir, ATTRIBUTE (SUB (rn)));
     rhs = M_ERROR;
   }
   if (lhs == M_HIP && rhs == M_HIP) {
-    diagnostic (A68_ERROR, p, ERROR_NO_UNIQUE_MODE);
+    diagnostic (A68G_ERROR, p, ERROR_NO_UNIQUE_MODE);
   }
   if (is_coercible (lhs, rhs, STRONG, SAFE_DEFLEXING)) {
     lhs = rhs;
@@ -1132,7 +1132,7 @@ void mode_check_cast (NODE_T * p, SOID_T * x, SOID_T * y)
   SOID_T w;
   mode_check_declarer (p);
   make_soid (&w, STRONG, MOID (p), 0);
-  CAST (&w) = A68_TRUE;
+  CAST (&w) = A68G_TRUE;
   mode_check_enclosed (SUB_NEXT (p), &w, y);
   if (!is_coercible_in_context (y, &w, SAFE_DEFLEXING)) {
     cannot_coerce (NEXT (p), MOID (y), MOID (&w), STRONG, SAFE_DEFLEXING, ENCLOSED_CLAUSE);
@@ -1177,7 +1177,7 @@ void mode_check_argument_list (SOID_T ** r, NODE_T * p, PACK_T ** x, PACK_T ** v
     } else if (IS (p, TRIMMER)) {
       SOID_T z;
       if (SUB (p) != NO_NODE) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_SYNTAX, ARGUMENT);
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_SYNTAX, ARGUMENT);
         make_soid (&z, STRONG, M_ERROR, 0);
         add_mode_to_pack_end (v, M_VOID, NO_TEXT, p);
         add_mode_to_pack_end (w, MOID (*x), NO_TEXT, p);
@@ -1191,8 +1191,8 @@ void mode_check_argument_list (SOID_T ** r, NODE_T * p, PACK_T ** x, PACK_T ** v
         make_soid (&z, STRONG, NO_MOID, 0);
       }
       add_to_soid_list (r, p, &z);
-    } else if (IS (p, SUB_SYMBOL) && !OPTION_BRACKETS (&A68_JOB)) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_SYNTAX, CALL);
+    } else if (IS (p, SUB_SYMBOL) && !OPTION_BRACKETS (&A68G_JOB)) {
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_SYNTAX, CALL);
     }
   }
 }
@@ -1273,10 +1273,10 @@ void mode_check_call (NODE_T * p, MOID_T * n, SOID_T * x, SOID_T * y)
   mode_check_argument_list_2 (NEXT (p), PACK (n), &d, &PACK (PARTIAL_LOCALE (GINFO (p))), &PACK (PARTIAL_PROC (GINFO (p))));
   DIM (PARTIAL_PROC (GINFO (p))) = count_pack_members (PACK (PARTIAL_PROC (GINFO (p))));
   DIM (PARTIAL_LOCALE (GINFO (p))) = count_pack_members (PACK (PARTIAL_LOCALE (GINFO (p))));
-  PARTIAL_PROC (GINFO (p)) = register_extra_mode (&TOP_MOID (&A68_JOB), PARTIAL_PROC (GINFO (p)));
-  PARTIAL_LOCALE (GINFO (p)) = register_extra_mode (&TOP_MOID (&A68_JOB), PARTIAL_LOCALE (GINFO (p)));
+  PARTIAL_PROC (GINFO (p)) = register_extra_mode (&TOP_MOID (&A68G_JOB), PARTIAL_PROC (GINFO (p)));
+  PARTIAL_LOCALE (GINFO (p)) = register_extra_mode (&TOP_MOID (&A68G_JOB), PARTIAL_LOCALE (GINFO (p)));
   if (DIM (MOID (&d)) != DIM (n)) {
-    diagnostic (A68_ERROR, p, ERROR_ARGUMENT_NUMBER, n);
+    diagnostic (A68G_ERROR, p, ERROR_ARGUMENT_NUMBER, n);
     make_soid (y, SORT (x), SUB (n), 0);
 //  make_soid (y, SORT (x), M_ERROR, 0);.
   } else {
@@ -1286,8 +1286,8 @@ void mode_check_call (NODE_T * p, MOID_T * n, SOID_T * x, SOID_T * y)
     if (DIM (PARTIAL_PROC (GINFO (p))) == 0) {
       make_soid (y, SORT (x), SUB (n), 0);
     } else {
-      if (OPTION_PORTCHECK (&A68_JOB)) {
-        diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, NEXT (p), WARNING_EXTENSION);
+      if (OPTION_PORTCHECK (&A68G_JOB)) {
+        diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, NEXT (p), WARNING_EXTENSION);
       }
       make_soid (y, SORT (x), PARTIAL_PROC (GINFO (p)), 0);
     }
@@ -1305,7 +1305,7 @@ void mode_check_slice (NODE_T * p, MOID_T * ori, SOID_T * x, SOID_T * y)
   }
   if (n == NO_MOID || !(SLICE (DEFLEX (n)) != NO_MOID || is_ref_row (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_ROW_OR_PROC, n, ATTRIBUTE (SUB (p)));
+      diagnostic (A68G_ERROR, p, ERROR_NO_ROW_OR_PROC, n, ATTRIBUTE (SUB (p)));
     }
     make_soid (y, SORT (x), M_ERROR, 0);
   }
@@ -1320,7 +1320,7 @@ void mode_check_slice (NODE_T * p, MOID_T * ori, SOID_T * x, SOID_T * y)
     dim = DIM (DEFLEX (n));
   }
   if ((subs + trims) != dim) {
-    diagnostic (A68_ERROR, p, ERROR_INDEXER_NUMBER, n);
+    diagnostic (A68G_ERROR, p, ERROR_INDEXER_NUMBER, n);
     make_soid (y, SORT (x), M_ERROR, 0);
   } else {
     MOID_T *m;
@@ -1372,7 +1372,7 @@ int mode_check_specification (NODE_T * p, SOID_T * x, SOID_T * y)
     return SLICE;
   } else {
     if (m != M_ERROR) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_MODE_SPECIFICATION, m);
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_MODE_SPECIFICATION, m);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return PRIMARY;
@@ -1383,7 +1383,7 @@ int mode_check_specification (NODE_T * p, SOID_T * x, SOID_T * y)
 
 void mode_check_selection (NODE_T * p, SOID_T * x, SOID_T * y)
 {
-  BOOL_T deflex = A68_FALSE;
+  BOOL_T deflex = A68G_FALSE;
   NODE_T *secondary = SUB_NEXT (p);
   SOID_T w, d;
   make_soid (&w, WEAK, NO_MOID, 0);
@@ -1391,34 +1391,34 @@ void mode_check_selection (NODE_T * p, SOID_T * x, SOID_T * y)
   MOID_T *n, *ori;
   n = ori = determine_unique_mode (&d, SAFE_DEFLEXING);
   PACK_T *t = NO_PACK, *t_2 = NO_PACK;
-  BOOL_T coerce = A68_TRUE;
+  BOOL_T coerce = A68G_TRUE;
   while (coerce) {
     if (IS (n, STRUCT_SYMBOL)) {
-      coerce = A68_FALSE;
+      coerce = A68G_FALSE;
       t = PACK (n);
     } else if (IS_REF (n) && (IS_ROW (SUB (n)) || IS_FLEX (SUB (n))) && MULTIPLE (n) != NO_MOID) {
-      coerce = A68_FALSE;
-      deflex = A68_TRUE;
+      coerce = A68G_FALSE;
+      deflex = A68G_TRUE;
       t = PACK (MULTIPLE (n));
     } else if ((IS_ROW (n) || IS_FLEX (n)) && MULTIPLE (n) != NO_MOID) {
-      coerce = A68_FALSE;
-      deflex = A68_TRUE;
+      coerce = A68G_FALSE;
+      deflex = A68G_TRUE;
       t = PACK (MULTIPLE (n));
     } else if (IS_REF (n) && is_name_struct (n)) {
-      coerce = A68_FALSE;
+      coerce = A68G_FALSE;
       t = PACK (NAME (n));
     } else if (is_deprefable (n)) {
-      coerce = A68_TRUE;
+      coerce = A68G_TRUE;
       n = SUB (n);
       t = NO_PACK;
     } else {
-      coerce = A68_FALSE;
+      coerce = A68G_FALSE;
       t = NO_PACK;
     }
   }
   if (t == NO_PACK) {
     if (IF_MODE_IS_WELL (MOID (&d))) {
-      diagnostic (A68_ERROR, secondary, ERROR_NO_STRUCT, ori, ATTRIBUTE (secondary));
+      diagnostic (A68G_ERROR, secondary, ERROR_NO_STRUCT, ori, ATTRIBUTE (secondary));
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
@@ -1451,7 +1451,7 @@ void mode_check_selection (NODE_T * p, SOID_T * x, SOID_T * y)
     FORWARD (t_2);
   }
   make_soid (&d, NO_SORT, n, 0);
-  diagnostic (A68_ERROR, p, ERROR_NO_FIELD, str, fs);
+  diagnostic (A68G_ERROR, p, ERROR_NO_FIELD, str, fs);
   make_soid (y, SORT (x), M_ERROR, 0);
 }
 
@@ -1480,26 +1480,26 @@ void mode_check_diagonal (NODE_T * p, SOID_T * x, SOID_T * y)
   }
   if (n != NO_MOID && (IS_FLEX (n) || IS_REF_FLEX (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   if (n == NO_MOID || !(SLICE (DEFLEX (n)) != NO_MOID || is_ref_row (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   BOOL_T is_ref; int dim;
-  if ((is_ref = is_ref_row (n)) != A68_FALSE) {
+  if ((is_ref = is_ref_row (n)) != A68G_FALSE) {
     dim = DIM (DEFLEX (SUB (n)));
   } else {
     dim = DIM (DEFLEX (n));
   }
   if (dim != 2) {
-    diagnostic (A68_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
+    diagnostic (A68G_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
@@ -1529,26 +1529,26 @@ void mode_check_transpose (NODE_T * p, SOID_T * x, SOID_T * y)
   }
   if (n != NO_MOID && (IS_FLEX (n) || IS_REF_FLEX (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   if (n == NO_MOID || !(SLICE (DEFLEX (n)) != NO_MOID || is_ref_row (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   int dim;
-  if (is_ref_row (n) != A68_FALSE) {
+  if (is_ref_row (n) != A68G_FALSE) {
     dim = DIM (DEFLEX (SUB (n)));
   } else {
     dim = DIM (DEFLEX (n));
   }
   if (dim != 2) {
-    diagnostic (A68_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
+    diagnostic (A68G_ERROR, p, ERROR_NO_MATRIX, ori, TERTIARY);
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
@@ -1582,26 +1582,26 @@ void mode_check_row_column_function (NODE_T * p, SOID_T * x, SOID_T * y)
   }
   if (n != NO_MOID && (IS_FLEX (n) || IS_REF_FLEX (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_FLEX_ARGUMENT, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   if (n == NO_MOID || !(SLICE (DEFLEX (n)) != NO_MOID || is_ref_row (n))) {
     if (IF_MODE_IS_WELL (n)) {
-      diagnostic (A68_ERROR, p, ERROR_NO_VECTOR, ori, TERTIARY);
+      diagnostic (A68G_ERROR, p, ERROR_NO_VECTOR, ori, TERTIARY);
     }
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
   int dim;
-  if (is_ref_row (n) != A68_FALSE) {
+  if (is_ref_row (n) != A68G_FALSE) {
     dim = DIM (DEFLEX (SUB (n)));
   } else {
     dim = DIM (DEFLEX (n));
   }
   if (dim != 1) {
-    diagnostic (A68_ERROR, p, ERROR_NO_VECTOR, ori, TERTIARY);
+    diagnostic (A68G_ERROR, p, ERROR_NO_VECTOR, ori, TERTIARY);
     make_soid (y, SORT (x), M_ERROR, 0);
     return;
   }
@@ -1664,7 +1664,7 @@ void mode_check_unit (NODE_T * p, SOID_T * x, SOID_T * y)
       int att = first_tag_global (TABLE (p), NSYMBOL (p));
       if (att == STOP) {
         (void) add_tag (TABLE (p), IDENTIFIER, p, M_ERROR, NORMAL_IDENTIFIER);
-        diagnostic (A68_ERROR, p, ERROR_UNDECLARED_TAG);
+        diagnostic (A68G_ERROR, p, ERROR_UNDECLARED_TAG);
         MOID (p) = M_ERROR;
       } else {
         TAG_T *z = find_tag_global (TABLE (p), att, NSYMBOL (p));
@@ -1672,7 +1672,7 @@ void mode_check_unit (NODE_T * p, SOID_T * x, SOID_T * y)
           MOID (p) = MOID (z);
         } else {
           (void) add_tag (TABLE (p), IDENTIFIER, p, M_ERROR, NORMAL_IDENTIFIER);
-          diagnostic (A68_ERROR, p, ERROR_UNDECLARED_TAG);
+          diagnostic (A68G_ERROR, p, ERROR_UNDECLARED_TAG);
           MOID (p) = M_ERROR;
         }
       }
@@ -1716,7 +1716,7 @@ void mode_check_unit (NODE_T * p, SOID_T * x, SOID_T * y)
 // Ex unit.
   } else if (is_one_of (p, JUMP, SKIP, STOP)) {
     if (SORT (x) != STRONG) {
-      diagnostic (A68_WARNING, p, WARNING_HIP, SORT (x));
+      diagnostic (A68G_WARNING, p, WARNING_HIP, SORT (x));
     }
 //  make_soid (y, STRONG, M_HIP, 0);
     make_soid (y, SORT (x), M_HIP, 0);
