@@ -64,18 +64,18 @@ void coerce_identity_declaration (NODE_T * p)
     case DECLARER: {
         coerce_declarer (SUB (p));
         coerce_identity_declaration (NEXT (p));
-        break;
+        return;
       }
     case DEFINING_IDENTIFIER: {
         SOID_T q;
         make_soid (&q, STRONG, MOID (p), 0);
         coerce_unit (NEXT_NEXT (p), &q);
-        break;
+        return;
       }
     default: {
         coerce_identity_declaration (SUB (p));
         coerce_identity_declaration (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -90,20 +90,20 @@ void coerce_variable_declaration (NODE_T * p)
     case DECLARER: {
         coerce_declarer (SUB (p));
         coerce_variable_declaration (NEXT (p));
-        break;
+        return;
       }
     case DEFINING_IDENTIFIER: {
         if (whether (p, DEFINING_IDENTIFIER, ASSIGN_SYMBOL, UNIT, STOP)) {
           SOID_T q;
           make_soid (&q, STRONG, SUB_MOID (p), 0);
           coerce_unit (NEXT_NEXT (p), &q);
-          break;
+          return;
         }
       }
     default: {
         coerce_variable_declaration (SUB (p));
         coerce_variable_declaration (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -173,33 +173,33 @@ void coerce_declaration_list (NODE_T * p)
     switch (ATTRIBUTE (p)) {
     case IDENTITY_DECLARATION: {
         coerce_identity_declaration (SUB (p));
-        break;
+        return;
       }
     case VARIABLE_DECLARATION: {
         coerce_variable_declaration (SUB (p));
-        break;
+        return;
       }
     case MODE_DECLARATION: {
         coerce_declarer (SUB (p));
-        break;
+        return;
       }
     case PROCEDURE_DECLARATION:
     case PROCEDURE_VARIABLE_DECLARATION: {
         coerce_proc_declaration (SUB (p));
-        break;
+        return;
       }
     case BRIEF_OPERATOR_DECLARATION: {
         coerce_brief_op_declaration (SUB (p));
-        break;
+        return;
       }
     case OPERATOR_DECLARATION: {
         coerce_op_declaration (SUB (p));
-        break;
+        return;
       }
     default: {
         coerce_declaration_list (SUB (p));
         coerce_declaration_list (NEXT (p));
-        break;
+        return;
       }
     }
   }
@@ -212,7 +212,7 @@ void coerce_serial (NODE_T * p, SOID_T * q, BOOL_T k)
   if (p == NO_NODE) {
     return;
   } else if (IS (p, INITIALISER_SERIES)) {
-    coerce_serial (SUB (p), q, A68_FALSE);
+    coerce_serial (SUB (p), q, A68G_FALSE);
     coerce_serial (NEXT (p), q, k);
   } else if (IS (p, DECLARATION_LIST)) {
     coerce_declaration_list (SUB (p));
@@ -222,12 +222,12 @@ void coerce_serial (NODE_T * p, SOID_T * q, BOOL_T k)
     NODE_T *z = NEXT (p);
     if (z != NO_NODE) {
       if (IS (z, EXIT_SYMBOL) || IS (z, END_SYMBOL) || IS (z, CLOSE_SYMBOL) || IS (z, OCCA_SYMBOL)) {
-        coerce_serial (SUB (p), q, A68_TRUE);
+        coerce_serial (SUB (p), q, A68G_TRUE);
       } else {
-        coerce_serial (SUB (p), q, A68_FALSE);
+        coerce_serial (SUB (p), q, A68G_FALSE);
       }
     } else {
-      coerce_serial (SUB (p), q, A68_TRUE);
+      coerce_serial (SUB (p), q, A68G_TRUE);
     }
     coerce_serial (NEXT (p), q, k);
   } else if (IS (p, LABELED_UNIT)) {
@@ -248,7 +248,7 @@ void coerce_serial (NODE_T * p, SOID_T * q, BOOL_T k)
 void coerce_closed (NODE_T * p, SOID_T * q)
 {
   if (IS (p, SERIAL_CLAUSE)) {
-    coerce_serial (p, q, A68_TRUE);
+    coerce_serial (p, q, A68G_TRUE);
   } else if (is_one_of (p, OPEN_SYMBOL, BEGIN_SYMBOL, STOP)) {
     coerce_closed (NEXT (p), q);
   }
@@ -260,12 +260,12 @@ void coerce_conditional (NODE_T * p, SOID_T * q)
 {
   SOID_T w;
   make_soid (&w, MEEK, M_BOOL, 0);
-  coerce_serial (NEXT_SUB (p), &w, A68_TRUE);
+  coerce_serial (NEXT_SUB (p), &w, A68G_TRUE);
   FORWARD (p);
-  coerce_serial (NEXT_SUB (p), q, A68_TRUE);
+  coerce_serial (NEXT_SUB (p), q, A68G_TRUE);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, ELSE_PART, CHOICE, STOP)) {
-      coerce_serial (NEXT_SUB (p), q, A68_TRUE);
+      coerce_serial (NEXT_SUB (p), q, A68G_TRUE);
     } else if (is_one_of (p, ELIF_PART, BRIEF_ELIF_PART, STOP)) {
       coerce_conditional (SUB (p), q);
     }
@@ -295,12 +295,12 @@ void coerce_int_case (NODE_T * p, SOID_T * q)
 {
   SOID_T w;
   make_soid (&w, MEEK, M_INT, 0);
-  coerce_serial (NEXT_SUB (p), &w, A68_TRUE);
+  coerce_serial (NEXT_SUB (p), &w, A68G_TRUE);
   FORWARD (p);
   coerce_unit_list (NEXT_SUB (p), q);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, OUT_PART, CHOICE, STOP)) {
-      coerce_serial (NEXT_SUB (p), q, A68_TRUE);
+      coerce_serial (NEXT_SUB (p), q, A68G_TRUE);
     } else if (is_one_of (p, CASE_OUSE_PART, BRIEF_OUSE_PART, STOP)) {
       coerce_int_case (SUB (p), q);
     }
@@ -326,12 +326,12 @@ void coerce_united_case (NODE_T * p, SOID_T * q)
 {
   SOID_T w;
   make_soid (&w, MEEK, MOID (SUB (p)), 0);
-  coerce_serial (NEXT_SUB (p), &w, A68_TRUE);
+  coerce_serial (NEXT_SUB (p), &w, A68G_TRUE);
   FORWARD (p);
   coerce_spec_unit_list (NEXT_SUB (p), q);
   if ((FORWARD (p)) != NO_NODE) {
     if (is_one_of (p, OUT_PART, CHOICE, STOP)) {
-      coerce_serial (NEXT_SUB (p), q, A68_TRUE);
+      coerce_serial (NEXT_SUB (p), q, A68G_TRUE);
     } else if (is_one_of (p, CONFORMITY_OUSE_PART, BRIEF_CONFORMITY_OUSE_PART, STOP)) {
       coerce_united_case (SUB (p), q);
     }
@@ -352,13 +352,13 @@ void coerce_loop (NODE_T * p)
   } else if (IS (p, WHILE_PART)) {
     SOID_T w;
     make_soid (&w, MEEK, M_BOOL, 0);
-    coerce_serial (NEXT_SUB (p), &w, A68_TRUE);
+    coerce_serial (NEXT_SUB (p), &w, A68G_TRUE);
     coerce_loop (NEXT (p));
   } else if (is_one_of (p, DO_PART, ALT_DO_PART, STOP)) {
     SOID_T w;
     NODE_T *do_p = NEXT_SUB (p), *un_p;
     make_soid (&w, STRONG, M_VOID, 0);
-    coerce_serial (do_p, &w, A68_TRUE);
+    coerce_serial (do_p, &w, A68G_TRUE);
     if (IS (do_p, SERIAL_CLAUSE)) {
       un_p = NEXT (do_p);
     } else {
@@ -367,7 +367,7 @@ void coerce_loop (NODE_T * p)
     if (un_p != NO_NODE && IS (un_p, UNTIL_PART)) {
       SOID_T sw;
       make_soid (&sw, MEEK, M_BOOL, 0);
-      coerce_serial (NEXT_SUB (un_p), &sw, A68_TRUE);
+      coerce_serial (NEXT_SUB (un_p), &sw, A68G_TRUE);
     }
   }
 }
@@ -443,7 +443,7 @@ void coerce_enclosed (NODE_T * p, SOID_T * q)
 
 MOID_T *get_monad_moid (NODE_T * p)
 {
-  if (TAX (p) != NO_TAG && TAX (p) != A68_PARSER (error_tag)) {
+  if (TAX (p) != NO_TAG && TAX (p) != A68G_PARSER (error_tag)) {
     MOID (p) = MOID (TAX (p));
     return MOID (PACK (MOID (p)));
   } else {
@@ -502,7 +502,7 @@ void coerce_formula (NODE_T * p, SOID_T * q)
   if (IS (p, MONADIC_FORMULA) && NEXT (p) == NO_NODE) {
     coerce_monad_formula (SUB (p));
   } else {
-    if (TAX (NEXT (p)) != NO_TAG && TAX (NEXT (p)) != A68_PARSER (error_tag)) {
+    if (TAX (NEXT (p)) != NO_TAG && TAX (NEXT (p)) != A68G_PARSER (error_tag)) {
       SOID_T s;
       NODE_T *op = NEXT (p), *nq = NEXT_NEXT (p);
       MOID_T *w = MOID (op);
@@ -751,7 +751,7 @@ void coerce_unit (NODE_T * p, SOID_T * q)
 // Ex tertiary.
   } else if (IS (p, NIHIL)) {
     if (ATTRIBUTE (MOID (q)) != REF_SYMBOL && MOID (q) != M_VOID) {
-      diagnostic (A68_ERROR, p, ERROR_NO_NAME_REQUIRED);
+      diagnostic (A68G_ERROR, p, ERROR_NO_NAME_REQUIRED);
     }
     MOID (p) = depref_rows (MOID (p), MOID (q));
   } else if (IS (p, FORMULA)) {
@@ -807,8 +807,8 @@ void widen_denotation (NODE_T * p)
   STATUS_SET (q, OPTIMAL_MASK);\
   }
 #define WARN_WIDENING\
-  if (OPTION_PORTCHECK (&A68_JOB) && !(STATUS_TEST (SUB (q), OPTIMAL_MASK))) {\
-    diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, q, WARNING_WIDENING_NOT_PORTABLE);\
+  if (OPTION_PORTCHECK (&A68G_JOB) && !(STATUS_TEST (SUB (q), OPTIMAL_MASK))) {\
+    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, q, WARNING_WIDENING_NOT_PORTABLE);\
   }
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     widen_denotation (SUB (q));
