@@ -112,8 +112,8 @@ int first_tag_global (TABLE_T * table, char *name)
 }
 
 #define PORTCHECK_TAX(p, q) {\
-  if (q == A68_FALSE) {\
-    diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);\
+  if (q == A68G_FALSE) {\
+    diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);\
   }}
 
 //! @brief Check portability of sub tree.
@@ -122,18 +122,18 @@ void portcheck (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     portcheck (SUB (p));
-    if (OPTION_PORTCHECK (&A68_JOB)) {
+    if (OPTION_PORTCHECK (&A68G_JOB)) {
       if (IS (p, INDICANT) && MOID (p) != NO_MOID) {
         PORTCHECK_TAX (p, PORTABLE (MOID (p)));
-        PORTABLE (MOID (p)) = A68_TRUE;
+        PORTABLE (MOID (p)) = A68G_TRUE;
       } else if (IS (p, IDENTIFIER)) {
         PORTCHECK_TAX (p, PORTABLE (TAX (p)));
-        PORTABLE (TAX (p)) = A68_TRUE;
+        PORTABLE (TAX (p)) = A68G_TRUE;
       } else if (IS (p, OPERATOR)) {
         PORTCHECK_TAX (p, PORTABLE (TAX (p)));
-        PORTABLE (TAX (p)) = A68_TRUE;
+        PORTABLE (TAX (p)) = A68G_TRUE;
       } else if (IS (p, ASSERTION)) {
-        diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);
+        diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_TAG_NOT_PORTABLE);
       }
     }
   }
@@ -146,7 +146,7 @@ BOOL_T is_mappable_routine (char *z)
 #define ACCEPT(u, v) {\
   if (strlen (u) >= strlen (v)) {\
     if (strcmp (&u[strlen (u) - strlen (v)], v) == 0) {\
-      return A68_TRUE;\
+      return A68G_TRUE;\
   }}}
 // Math routines.
   ACCEPT (z, "arccos");
@@ -200,7 +200,7 @@ BOOL_T is_mappable_routine (char *z)
   ACCEPT (z, "bitswidth");
   ACCEPT (z, "byteswidth");
   ACCEPT (z, "smallreal");
-  return A68_FALSE;
+  return A68G_FALSE;
 #undef ACCEPT
 }
 
@@ -214,8 +214,8 @@ TAG_T *bind_lengthety_identifier (char *u)
   if (CAR (u, "short")) {
     do {
       u = &u[strlen ("short")];
-      char *v = TEXT (add_token (&A68 (top_token), u));
-      TAG_T *w = find_tag_local (A68_STANDENV, IDENTIFIER, v);
+      char *v = TEXT (add_token (&A68G (top_token), u));
+      TAG_T *w = find_tag_local (A68G_STANDENV, IDENTIFIER, v);
       if (w != NO_TAG && is_mappable_routine (v)) {
         return w;
       }
@@ -223,8 +223,8 @@ TAG_T *bind_lengthety_identifier (char *u)
   } else if (CAR (u, "long")) {
     do {
       u = &u[strlen ("long")];
-      char *v = TEXT (add_token (&A68 (top_token), u));
-      TAG_T *w = find_tag_local (A68_STANDENV, IDENTIFIER, v);
+      char *v = TEXT (add_token (&A68G (top_token), u));
+      TAG_T *w = find_tag_local (A68G_STANDENV, IDENTIFIER, v);
       if (w != NO_TAG && is_mappable_routine (v)) {
         return w;
       }
@@ -257,7 +257,7 @@ void bind_identifier_tag_to_symbol_table (NODE_T * p)
         } else if ((z = bind_lengthety_identifier (NSYMBOL (p))) != NO_TAG) {
           MOID (p) = MOID (z);
         } else {
-          diagnostic (A68_ERROR, p, ERROR_UNDECLARED_TAG);
+          diagnostic (A68G_ERROR, p, ERROR_UNDECLARED_TAG);
           z = add_tag (TABLE (p), IDENTIFIER, p, M_ERROR, NORMAL_IDENTIFIER);
           MOID (p) = M_ERROR;
         }
@@ -387,7 +387,7 @@ void tax_routine_texts (NODE_T * p)
       TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, MOID (p), ROUTINE_TEXT);
       TAX (p) = z;
       HEAP (z) = LOC_SYMBOL;
-      USE (z) = A68_TRUE;
+      USE (z) = A68G_TRUE;
     }
   }
 }
@@ -401,11 +401,11 @@ void tax_format_texts (NODE_T * p)
     if (IS (p, FORMAT_TEXT)) {
       TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, M_FORMAT, FORMAT_TEXT);
       TAX (p) = z;
-      USE (z) = A68_TRUE;
+      USE (z) = A68G_TRUE;
     } else if (IS (p, FORMAT_DELIMITER_SYMBOL) && NEXT (p) != NO_NODE) {
       TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, M_FORMAT, FORMAT_IDENTIFIER);
       TAX (p) = z;
-      USE (z) = A68_TRUE;
+      USE (z) = A68G_TRUE;
     }
   }
 }
@@ -432,7 +432,7 @@ void tax_generators (NODE_T * p)
       if (IS (SUB (p), LOC_SYMBOL)) {
         TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, SUB_MOID (SUB (p)), GENERATOR);
         HEAP (z) = LOC_SYMBOL;
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
         TAX (p) = z;
       }
     }
@@ -478,11 +478,11 @@ void test_firmly_related_ops_local (NODE_T * p, TAG_T * s)
       MOID_T *r = (NEXT (u) != NO_PACK ? MOID (NEXT (u)) : NO_MOID);
       TAG_T *t = find_firmly_related_op (TAG_TABLE (s), NSYMBOL (NODE (s)), l, r, s);
       if (t != NO_TAG) {
-        if (TAG_TABLE (t) == A68_STANDENV) {
-          diagnostic (A68_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
-          ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        if (TAG_TABLE (t) == A68G_STANDENV) {
+          diagnostic (A68G_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
+          ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
         } else {
-          diagnostic (A68_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
+          diagnostic (A68G_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
         }
       }
     }
@@ -522,7 +522,7 @@ void collect_taxes (NODE_T * p)
   bind_identifier_tag_to_symbol_table (p);
   bind_indicant_tag_to_symbol_table (p);
   test_firmly_related_ops (p);
-  test_firmly_related_ops_local (NO_NODE, OPERATORS (A68_STANDENV));
+  test_firmly_related_ops_local (NO_NODE, OPERATORS (A68G_STANDENV));
 }
 
 //! @brief Whether tag has already been declared in this range.
@@ -530,7 +530,7 @@ void collect_taxes (NODE_T * p)
 void already_declared (NODE_T * n, int a)
 {
   if (find_tag_local (TABLE (n), a, NSYMBOL (n)) != NO_TAG) {
-    diagnostic (A68_ERROR, n, ERROR_MULTIPLE_TAG);
+    diagnostic (A68G_ERROR, n, ERROR_MULTIPLE_TAG);
   }
 }
 
@@ -539,14 +539,14 @@ void already_declared (NODE_T * n, int a)
 void already_declared_hidden (NODE_T * n, int a)
 {
   if (find_tag_local (TABLE (n), a, NSYMBOL (n)) != NO_TAG) {
-    diagnostic (A68_ERROR, n, ERROR_MULTIPLE_TAG);
+    diagnostic (A68G_ERROR, n, ERROR_MULTIPLE_TAG);
   }
   TAG_T *s = find_tag_global (PREVIOUS (TABLE (n)), a, NSYMBOL (n));
   if (s != NO_TAG) {
-    if (TAG_TABLE (s) == A68_STANDENV) {
-      diagnostic (A68_WARNING, n, WARNING_HIDES_PRELUDE, MOID (s), NSYMBOL (n));
+    if (TAG_TABLE (s) == A68G_STANDENV) {
+      diagnostic (A68G_WARNING, n, WARNING_HIDES_PRELUDE, MOID (s), NSYMBOL (n));
     } else {
-      diagnostic (A68_WARNING, n, WARNING_HIDES, NSYMBOL (n));
+      diagnostic (A68G_WARNING, n, WARNING_HIDES, NSYMBOL (n));
     }
   }
 }
@@ -599,7 +599,7 @@ TAG_T *add_tag (TABLE_T * s, int a, NODE_T * n, MOID_T * m, int p)
         break;
       }
     default: {
-        ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
       }
     }
     return z;
@@ -636,7 +636,7 @@ TAG_T *find_tag_global (TABLE_T * table, int a, char *name)
         break;
       }
     default: {
-        ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
         break;
       }
     }
@@ -689,7 +689,7 @@ TAG_T *find_tag_local (TABLE_T * table, int a, const char *name)
     } else if (a == LABEL) {
       s = LABELS (table);
     } else {
-      ABEND (A68_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
     }
     for (; s != NO_TAG; FORWARD (s)) {
       if (NSYMBOL (NODE (s)) == name) {
@@ -772,7 +772,7 @@ void tax_variable_dec (NODE_T * p, int *q, MOID_T ** m)
       if (*q == LOC_SYMBOL) {
         TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, SUB (*m), GENERATOR);
         HEAP (z) = LOC_SYMBOL;
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
         BODY (entry) = z;
       } else {
         BODY (entry) = NO_TAG;
@@ -806,7 +806,7 @@ void tax_proc_variable_dec (NODE_T * p, int *q)
       if (*q == LOC_SYMBOL) {
         TAG_T *z = add_tag (TABLE (p), ANONYMOUS, p, SUB_MOID (p), GENERATOR);
         HEAP (z) = LOC_SYMBOL;
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
         BODY (entry) = z;
       } else {
         BODY (entry) = NO_TAG;
@@ -858,13 +858,13 @@ void check_operator_dec (NODE_T * p, MOID_T * u)
     k = count_pack_members (PACK (u));
   }
   if (k < 1 || k > 2) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_OPERAND_NUMBER);
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_OPERAND_NUMBER);
     k = 0;
   }
   if (k == 1 && strchr (NOMADS, NSYMBOL (p)[0]) != NO_TEXT) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_OPERATOR_INVALID, NOMADS);
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_OPERATOR_INVALID, NOMADS);
   } else if (k == 2 && !find_tag_global (TABLE (p), PRIO_SYMBOL, NSYMBOL (p))) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_DYADIC_PRIORITY);
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_DYADIC_PRIORITY);
   }
 }
 
@@ -987,7 +987,7 @@ void reset_symbol_table_nest_count (NODE_T * p)
 {
   for (; p != NO_NODE; FORWARD (p)) {
     if (SUB (p) != NO_NODE && is_new_lexical_level (p)) {
-      NEST (TABLE (SUB (p))) = A68 (symbol_table_count)++;
+      NEST (TABLE (SUB (p))) = A68G (symbol_table_count)++;
     }
     reset_symbol_table_nest_count (SUB (p));
   }
@@ -1112,7 +1112,7 @@ void finalise_symbol_table_setup (NODE_T * p, int l)
 void preliminary_symbol_table_setup (NODE_T * p)
 {
   TABLE_T *s = TABLE (p);
-  BOOL_T not_a_for_range = A68_FALSE;
+  BOOL_T not_a_for_range = A68G_FALSE;
 // let the tree point to the current symbol table.
   for (NODE_T *q = p; q != NO_NODE; FORWARD (q)) {
     TABLE (q) = s;
@@ -1134,7 +1134,7 @@ void preliminary_symbol_table_setup (NODE_T * p)
           TABLE (SUB (q)) = new_symbol_table (s);
           preliminary_symbol_table_setup (SUB (q));
           if ((FORWARD (q)) == NO_NODE) {
-            not_a_for_range = A68_TRUE;
+            not_a_for_range = A68G_TRUE;
           } else {
             if (IS (q, THEN_BAR_SYMBOL)) {
               TABLE (SUB (q)) = new_symbol_table (s);
@@ -1160,7 +1160,7 @@ void preliminary_symbol_table_setup (NODE_T * p)
           TABLE (SUB (q)) = new_symbol_table (s);
           preliminary_symbol_table_setup (SUB (q));
           if ((FORWARD (q)) == NO_NODE) {
-            not_a_for_range = A68_TRUE;
+            not_a_for_range = A68G_TRUE;
           } else {
             if (IS (q, ELSE_SYMBOL)) {
               TABLE (SUB (q)) = new_symbol_table (s);
@@ -1185,7 +1185,7 @@ void preliminary_symbol_table_setup (NODE_T * p)
           TABLE (SUB (q)) = new_symbol_table (s);
           preliminary_symbol_table_setup (SUB (q));
           if ((FORWARD (q)) == NO_NODE) {
-            not_a_for_range = A68_TRUE;
+            not_a_for_range = A68G_TRUE;
           } else {
             if (IS (q, OUT_SYMBOL)) {
               TABLE (SUB (q)) = new_symbol_table (s);
@@ -1211,7 +1211,7 @@ void preliminary_symbol_table_setup (NODE_T * p)
         TABLE (SUB (q)) = u;
         preliminary_symbol_table_setup (SUB (q));
         if ((FORWARD (q)) == NO_NODE) {
-          not_a_for_range = A68_TRUE;
+          not_a_for_range = A68G_TRUE;
         } else if (IS (q, ALT_DO_SYMBOL)) {
           TABLE (SUB (q)) = new_symbol_table (u);
           preliminary_symbol_table_setup (SUB (q));
@@ -1243,9 +1243,9 @@ void preliminary_symbol_table_setup (NODE_T * p)
 
 void mark_mode (MOID_T * m)
 {
-  if (m != NO_MOID && USE (m) == A68_FALSE) {
+  if (m != NO_MOID && USE (m) == A68G_FALSE) {
     PACK_T *p = PACK (m);
-    USE (m) = A68_TRUE;
+    USE (m) = A68G_TRUE;
     for (; p != NO_PACK; FORWARD (p)) {
       mark_mode (MOID (p));
       mark_mode (SUB (m));
@@ -1279,20 +1279,20 @@ void mark_auxilliary (NODE_T * p)
     } else if (IS (p, OPERATOR)) {
       TAG_T *z;
       if (TAX (p) != NO_TAG) {
-        USE (TAX (p)) = A68_TRUE;
+        USE (TAX (p)) = A68G_TRUE;
       }
       if ((z = find_tag_global (TABLE (p), PRIO_SYMBOL, NSYMBOL (p))) != NO_TAG) {
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
       }
     } else if (IS (p, INDICANT)) {
       TAG_T *z = find_tag_global (TABLE (p), INDICANT, NSYMBOL (p));
       if (z != NO_TAG) {
         TAX (p) = z;
-        USE (z) = A68_TRUE;
+        USE (z) = A68G_TRUE;
       }
     } else if (IS (p, IDENTIFIER)) {
       if (TAX (p) != NO_TAG) {
-        USE (TAX (p)) = A68_TRUE;
+        USE (TAX (p)) = A68G_TRUE;
       }
     }
   }
@@ -1304,7 +1304,7 @@ void unused (TAG_T * s)
 {
   for (; s != NO_TAG; FORWARD (s)) {
     if (LINE_NUMBER (NODE (s)) > 0 && !USE (s)) {
-      diagnostic (A68_WARNING, NODE (s), WARNING_TAG_UNUSED, NODE (s));
+      diagnostic (A68G_WARNING, NODE (s), WARNING_TAG_UNUSED, NODE (s));
     }
   }
 }
@@ -1337,17 +1337,18 @@ void jumps_from_procs (NODE_T * p)
       if (IS (u, GOTO_SYMBOL)) {
         FORWARD (u);
       }
-      USE (TAX (u)) = A68_TRUE;
+      USE (TAX (u)) = A68G_TRUE;
     } else if (IS (p, JUMP)) {
       NODE_T *u = SUB (p);
       if (IS (u, GOTO_SYMBOL)) {
         FORWARD (u);
       }
       if ((TAX (u) == NO_TAG) && (MOID (u) == NO_MOID) && (find_tag_global (TABLE (u), LABEL, NSYMBOL (u)) == NO_TAG)) {
-        (void) add_tag (TABLE (u), LABEL, u, NO_MOID, LOCAL_LABEL);
-        diagnostic (A68_ERROR, u, ERROR_UNDECLARED_TAG);
-      } else {
-        USE (TAX (u)) = A68_TRUE;
+        TAG_T *t = add_tag (TABLE (u), LABEL, u, NO_MOID, LOCAL_LABEL);
+        USE (t) = A68G_TRUE;
+        diagnostic (A68G_ERROR, u, ERROR_UNDECLARED_TAG);
+      } else if (TAX (u) != NO_TAG) {
+        USE (TAX (u)) = A68G_TRUE;
       }
     } else {
       jumps_from_procs (SUB (p));
@@ -1378,7 +1379,7 @@ void assign_offsets_table (TABLE_T * c)
   AP_INCREMENT (c) = assign_offset_tags (IDENTIFIERS (c), 0);
   AP_INCREMENT (c) = assign_offset_tags (OPERATORS (c), AP_INCREMENT (c));
   AP_INCREMENT (c) = assign_offset_tags (ANONYMOUS (c), AP_INCREMENT (c));
-  AP_INCREMENT (c) = A68_ALIGN (AP_INCREMENT (c));
+  AP_INCREMENT (c) = A68G_ALIGN (AP_INCREMENT (c));
 }
 
 //! @brief Assign offsets.
