@@ -34,14 +34,14 @@
 
 // OP - = (INT) INT.
 
-A68_MONAD (genie_minus_int, A68_INT, -);
+A68G_MONAD (genie_minus_int, A68G_INT, -);
 
 // OP ABS = (INT) INT
 
 void genie_abs_int (NODE_T * p)
 {
-  A68_INT *j;
-  POP_OPERAND_ADDRESS (p, j, A68_INT);
+  A68G_INT *j;
+  POP_OPERAND_ADDRESS (p, j, A68G_INT);
   VALUE (j) = ABS (VALUE (j));
 }
 
@@ -49,8 +49,8 @@ void genie_abs_int (NODE_T * p)
 
 void genie_sign_int (NODE_T * p)
 {
-  A68_INT *j;
-  POP_OPERAND_ADDRESS (p, j, A68_INT);
+  A68G_INT *j;
+  POP_OPERAND_ADDRESS (p, j, A68G_INT);
   VALUE (j) = SIGN (VALUE (j));
 }
 
@@ -58,17 +58,17 @@ void genie_sign_int (NODE_T * p)
 
 void genie_odd_int (NODE_T * p)
 {
-  A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
-  PUSH_VALUE (p, (BOOL_T) ((VALUE (&j) >= 0 ? VALUE (&j) : -VALUE (&j)) % 2 == 1), A68_BOOL);
+  A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
+  PUSH_VALUE (p, (BOOL_T) ((VALUE (&j) >= 0 ? VALUE (&j) : -VALUE (&j)) % 2 == 1), A68G_BOOL);
 }
 
 // OP + = (INT, INT) INT
 
 void genie_add_int (NODE_T * p)
 {
-  A68_INT *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
+  A68G_INT *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_INT);
   errno = 0;
   VALUE (i) = a68g_add_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
@@ -78,8 +78,8 @@ void genie_add_int (NODE_T * p)
 
 void genie_sub_int (NODE_T * p)
 {
-  A68_INT *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
+  A68G_INT *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_INT);
   errno = 0;
   VALUE (i) = a68g_sub_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
@@ -89,8 +89,8 @@ void genie_sub_int (NODE_T * p)
 
 void genie_mul_int (NODE_T * p)
 {
-  A68_INT *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
+  A68G_INT *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_INT);
   errno = 0;
   VALUE (i) = a68g_mul_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
@@ -100,8 +100,8 @@ void genie_mul_int (NODE_T * p)
 
 void genie_over_int (NODE_T * p)
 {
-  A68_INT *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
+  A68G_INT *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_INT);
   errno = 0;
   VALUE (i) = a68g_over_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, ERROR_DIVISION_BY_ZERO);
@@ -111,8 +111,8 @@ void genie_over_int (NODE_T * p)
 
 void genie_mod_int (NODE_T * p)
 {
-  A68_INT *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_INT);
+  A68G_INT *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_INT);
   errno = 0;
   VALUE (i) = a68g_mod_int (VALUE (i), VALUE (j));
   MATH_RTE (p, errno != 0, M_INT, ERROR_DIVISION_BY_ZERO);
@@ -122,11 +122,11 @@ void genie_mod_int (NODE_T * p)
 
 void genie_div_int (NODE_T * p)
 {
-  A68_INT i, j;
-  POP_OBJECT (p, &j, A68_INT);
-  POP_OBJECT (p, &i, A68_INT);
+  A68G_INT i, j;
+  POP_OBJECT (p, &j, A68G_INT);
+  POP_OBJECT (p, &i, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_div_int (VALUE (&i), VALUE (&j)), A68_REAL);
+  PUSH_VALUE (p, a68g_div_int (VALUE (&i), VALUE (&j)), A68G_REAL);
   MATH_RTE (p, errno != 0, M_INT, "M division by zero");
 }
 
@@ -134,31 +134,31 @@ void genie_div_int (NODE_T * p)
 
 void genie_pow_int (NODE_T * p)
 {
-  A68_INT i, j;
-  POP_OBJECT (p, &j, A68_INT);
+  A68G_INT i, j;
+  POP_OBJECT (p, &j, A68G_INT);
   PRELUDE_ERROR (VALUE (&j) < 0, p, ERROR_EXPONENT_INVALID, M_INT);
-  POP_OBJECT (p, &i, A68_INT);
+  POP_OBJECT (p, &i, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_m_up_n (VALUE (&i), VALUE (&j)), A68_INT);
+  PUSH_VALUE (p, a68g_m_up_n (VALUE (&i), VALUE (&j)), A68G_INT);
   MATH_RTE (p, errno != 0, M_INT, "M overflow");
 }
 
 // OP (INT, INT) BOOL.
 
-#define A68_CMP_INT(n, OP)\
+#define A68G_CMP_INT(n, OP)\
 void n (NODE_T * p) {\
-  A68_INT i, j;\
-  POP_OBJECT (p, &j, A68_INT);\
-  POP_OBJECT (p, &i, A68_INT);\
-  PUSH_VALUE (p, (BOOL_T) (VALUE (&i) OP VALUE (&j)), A68_BOOL);\
+  A68G_INT i, j;\
+  POP_OBJECT (p, &j, A68G_INT);\
+  POP_OBJECT (p, &i, A68G_INT);\
+  PUSH_VALUE (p, (BOOL_T) (VALUE (&i) OP VALUE (&j)), A68G_BOOL);\
   }
 
-A68_CMP_INT (genie_eq_int, ==);
-A68_CMP_INT (genie_ne_int, !=);
-A68_CMP_INT (genie_lt_int, <);
-A68_CMP_INT (genie_gt_int, >);
-A68_CMP_INT (genie_le_int, <=);
-A68_CMP_INT (genie_ge_int, >=);
+A68G_CMP_INT (genie_eq_int, ==);
+A68G_CMP_INT (genie_ne_int, !=);
+A68G_CMP_INT (genie_lt_int, <);
+A68G_CMP_INT (genie_gt_int, >);
+A68G_CMP_INT (genie_le_int, <=);
+A68G_CMP_INT (genie_ge_int, >=);
 
 // OP +:= = (REF INT, INT) REF INT
 
@@ -199,14 +199,14 @@ void genie_modab_int (NODE_T * p)
 
 // OP - = (REAL) REAL.
 
-A68_MONAD (genie_minus_real, A68_REAL, -);
+A68G_MONAD (genie_minus_real, A68G_REAL, -);
 
 // OP ABS = (REAL) REAL
 
 void genie_abs_real (NODE_T * p)
 {
-  A68_REAL *x;
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);
+  A68G_REAL *x;
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);
   VALUE (x) = ABS (VALUE (x));
 }
 
@@ -214,37 +214,37 @@ void genie_abs_real (NODE_T * p)
 
 void genie_round_real (NODE_T * p)
 {
-  A68_REAL x;
-  POP_OBJECT (p, &x, A68_REAL);
-  PRELUDE_ERROR (VALUE (&x) < -(REAL_T) A68_MAX_INT || VALUE (&x) > (REAL_T) A68_MAX_INT, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  PUSH_VALUE (p, a68g_round (VALUE (&x)), A68_INT);
+  A68G_REAL x;
+  POP_OBJECT (p, &x, A68G_REAL);
+  PRELUDE_ERROR (VALUE (&x) < -(REAL_T) A68G_MAX_INT || VALUE (&x) > (REAL_T) A68G_MAX_INT, p, ERROR_OUT_OF_BOUNDS, M_INT);
+  PUSH_VALUE (p, a68g_round (VALUE (&x)), A68G_INT);
 }
 
 // OP ENTIER = (REAL) INT
 
 void genie_entier_real (NODE_T * p)
 {
-  A68_REAL x;
-  POP_OBJECT (p, &x, A68_REAL);
-  PRELUDE_ERROR (VALUE (&x) < -(REAL_T) A68_MAX_INT || VALUE (&x) > (REAL_T) A68_MAX_INT, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  PUSH_VALUE (p, (INT_T) floor (VALUE (&x)), A68_INT);
+  A68G_REAL x;
+  POP_OBJECT (p, &x, A68G_REAL);
+  PRELUDE_ERROR (VALUE (&x) < -(REAL_T) A68G_MAX_INT || VALUE (&x) > (REAL_T) A68G_MAX_INT, p, ERROR_OUT_OF_BOUNDS, M_INT);
+  PUSH_VALUE (p, (INT_T) floor (VALUE (&x)), A68G_INT);
 }
 
 // OP SIGN = (REAL) INT
 
 void genie_sign_real (NODE_T * p)
 {
-  A68_REAL x;
-  POP_OBJECT (p, &x, A68_REAL);
-  PUSH_VALUE (p, SIGN (VALUE (&x)), A68_INT);
+  A68G_REAL x;
+  POP_OBJECT (p, &x, A68G_REAL);
+  PUSH_VALUE (p, SIGN (VALUE (&x)), A68G_INT);
 }
 
 // OP + = (REAL, REAL) REAL
 
 void genie_add_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   VALUE (x) += VALUE (y);
   CHECK_REAL (p, VALUE (x));
 }
@@ -253,8 +253,8 @@ void genie_add_real (NODE_T * p)
 
 void genie_sub_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   VALUE (x) -= VALUE (y);
   CHECK_REAL (p, VALUE (x));
 }
@@ -263,8 +263,8 @@ void genie_sub_real (NODE_T * p)
 
 void genie_mul_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   VALUE (x) *= VALUE (y);
   CHECK_REAL (p, VALUE (x));
 }
@@ -273,8 +273,8 @@ void genie_mul_real (NODE_T * p)
 
 void genie_div_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   PRELUDE_ERROR (VALUE (y) == 0.0, p, ERROR_DIVISION_BY_ZERO, M_REAL);
   VALUE (x) /= VALUE (y);
 }
@@ -283,44 +283,44 @@ void genie_div_real (NODE_T * p)
 
 void genie_pow_real_int (NODE_T * p)
 {
-  A68_INT j;
-  A68_REAL x;
-  POP_OBJECT (p, &j, A68_INT);
-  POP_OBJECT (p, &x, A68_REAL);
+  A68G_INT j;
+  A68G_REAL x;
+  POP_OBJECT (p, &j, A68G_INT);
+  POP_OBJECT (p, &x, A68G_REAL);
   REAL_T z = a68g_x_up_n_real (VALUE (&x), VALUE (&j));
   CHECK_REAL (p, z);
-  PUSH_VALUE (p, z, A68_REAL);
+  PUSH_VALUE (p, z, A68G_REAL);
 }
 
 // OP ** = (REAL, REAL) REAL
 
 void genie_pow_real (NODE_T * p)
 {
-  A68_REAL x, y;
-  POP_OBJECT (p, &y, A68_REAL);
-  POP_OBJECT (p, &x, A68_REAL);
+  A68G_REAL x, y;
+  POP_OBJECT (p, &y, A68G_REAL);
+  POP_OBJECT (p, &x, A68G_REAL);
   errno = 0;
   REAL_T z = a68g_x_up_y (VALUE (&x), VALUE (&y));
   MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);
-  PUSH_VALUE (p, z, A68_REAL);
+  PUSH_VALUE (p, z, A68G_REAL);
 }
 
 // OP (REAL, REAL) BOOL.
 
-#define A68_CMP_REAL(n, OP)\
+#define A68G_CMP_REAL(n, OP)\
 void n (NODE_T * p) {\
-  A68_REAL i, j;\
-  POP_OBJECT (p, &j, A68_REAL);\
-  POP_OBJECT (p, &i, A68_REAL);\
-  PUSH_VALUE (p, (BOOL_T) (VALUE (&i) OP VALUE (&j)), A68_BOOL);\
+  A68G_REAL i, j;\
+  POP_OBJECT (p, &j, A68G_REAL);\
+  POP_OBJECT (p, &i, A68G_REAL);\
+  PUSH_VALUE (p, (BOOL_T) (VALUE (&i) OP VALUE (&j)), A68G_BOOL);\
   }
 
-A68_CMP_REAL (genie_eq_real, ==);
-A68_CMP_REAL (genie_ne_real, !=);
-A68_CMP_REAL (genie_lt_real, <);
-A68_CMP_REAL (genie_gt_real, >);
-A68_CMP_REAL (genie_le_real, <=);
-A68_CMP_REAL (genie_ge_real, >=);
+A68G_CMP_REAL (genie_eq_real, ==);
+A68G_CMP_REAL (genie_ne_real, !=);
+A68G_CMP_REAL (genie_lt_real, <);
+A68G_CMP_REAL (genie_gt_real, >);
+A68G_CMP_REAL (genie_le_real, <=);
+A68G_CMP_REAL (genie_ge_real, >=);
 
 // OP +:= = (REF REAL, REAL) REF REAL
 
@@ -354,8 +354,8 @@ void genie_divab_real (NODE_T * p)
 
 void genie_first_random (NODE_T * p)
 {
-  A68_INT i;
-  POP_OBJECT (p, &i, A68_INT);
+  A68G_INT i;
+  POP_OBJECT (p, &i, A68G_INT);
   init_rng ((unt) VALUE (&i));
 }
 
@@ -363,14 +363,14 @@ void genie_first_random (NODE_T * p)
 
 void genie_next_random (NODE_T * p)
 {
-  PUSH_VALUE (p, a68g_unif_rand (), A68_REAL);
+  PUSH_VALUE (p, a68g_unif_rand (), A68G_REAL);
 }
 
 // @brief PROC REAL rnd
 
 void genie_next_rnd (NODE_T * p)
 {
-  PUSH_VALUE (p, 2 * a68g_unif_rand () - 1, A68_REAL);
+  PUSH_VALUE (p, 2 * a68g_unif_rand () - 1, A68G_REAL);
 }
 
 // @brief PROC (REAL) REAL sqrt
@@ -391,8 +391,8 @@ void genie_curt_real (NODE_T * p)
 
 void genie_exp_real (NODE_T * p)
 {
-  A68_REAL *x;
-  POP_OPERAND_ADDRESS (p, x, A68_REAL);
+  A68G_REAL *x;
+  POP_OPERAND_ADDRESS (p, x, A68G_REAL);
   errno = 0;
   VALUE (x) = exp (VALUE (x));
   MATH_RTE (p, errno != 0, M_REAL, NO_TEXT);
@@ -514,8 +514,8 @@ void genie_atan_real (NODE_T * p)
 
 void genie_atan2_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (x) == 0.0 && VALUE (y) == 0.0, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
   VALUE (x) = a68g_atan2_real (VALUE (y), VALUE (x));
@@ -610,8 +610,8 @@ void genie_acotdg_real (NODE_T * p)
 
 void genie_atan2dg_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   errno = 0;
   PRELUDE_ERROR (VALUE (x) == 0.0 && VALUE (y) == 0.0, p, ERROR_INVALID_ARGUMENT, M_LONG_REAL);
   VALUE (x) = CONST_180_OVER_PI * a68g_atan2_real (VALUE (y), VALUE (x));
@@ -734,8 +734,8 @@ void genie_ln_gamma_real (NODE_T * p)
 
 void genie_beta_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   errno = 0;
   VALUE (x) = a68g_beta_real (VALUE (x), VALUE (y));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
@@ -745,8 +745,8 @@ void genie_beta_real (NODE_T * p)
 
 void genie_ln_beta_real (NODE_T * p)
 {
-  A68_REAL *x, *y;
-  POP_OPERAND_ADDRESSES (p, x, y, A68_REAL);
+  A68G_REAL *x, *y;
+  POP_OPERAND_ADDRESSES (p, x, y, A68G_REAL);
   errno = 0;
   VALUE (x) = a68g_ln_beta_real (VALUE (x), VALUE (y));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
@@ -756,8 +756,8 @@ void genie_ln_beta_real (NODE_T * p)
 
 void genie_beta_inc_cf_real (NODE_T * p)
 {
-  A68_REAL *s, *t, *x;
-  POP_3_OPERAND_ADDRESSES (p, s, t, x, A68_REAL);
+  A68G_REAL *s, *t, *x;
+  POP_3_OPERAND_ADDRESSES (p, s, t, x, A68G_REAL);
   errno = 0;
   VALUE (s) = a68g_beta_inc_real (VALUE (s), VALUE (t), VALUE (x));
   PRELUDE_ERROR (errno != 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
@@ -767,8 +767,8 @@ void genie_beta_inc_cf_real (NODE_T * p)
 
 void genie_lj_e_12_6 (NODE_T * p)
 {
-  A68_REAL *e, *s, *r;
-  POP_3_OPERAND_ADDRESSES (p, e, s, r, A68_REAL);
+  A68G_REAL *e, *s, *r;
+  POP_3_OPERAND_ADDRESSES (p, e, s, r, A68G_REAL);
   PRELUDE_ERROR (VALUE (r) == 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
   REAL_T u = (VALUE (s) / VALUE (r));
   REAL_T u2 = u * u;
@@ -780,8 +780,8 @@ void genie_lj_e_12_6 (NODE_T * p)
 
 void genie_lj_f_12_6 (NODE_T * p)
 {
-  A68_REAL *e, *s, *r;
-  POP_3_OPERAND_ADDRESSES (p, e, s, r, A68_REAL);
+  A68G_REAL *e, *s, *r;
+  POP_3_OPERAND_ADDRESSES (p, e, s, r, A68G_REAL);
   PRELUDE_ERROR (VALUE (r) == 0, p, ERROR_MATH_EXCEPTION, NO_TEXT);
   REAL_T u = (VALUE (s) / VALUE (r));
   REAL_T u2 = u * u;
@@ -808,11 +808,11 @@ void genie_i_complex (NODE_T * p)
 
 void genie_i_int_complex (NODE_T * p)
 {
-  A68_INT re, im;
-  POP_OBJECT (p, &im, A68_INT);
-  POP_OBJECT (p, &re, A68_INT);
-  PUSH_VALUE (p, (REAL_T) VALUE (&re), A68_REAL);
-  PUSH_VALUE (p, (REAL_T) VALUE (&im), A68_REAL);
+  A68G_INT re, im;
+  POP_OBJECT (p, &im, A68G_INT);
+  POP_OBJECT (p, &re, A68G_INT);
+  PUSH_VALUE (p, (REAL_T) VALUE (&re), A68G_REAL);
+  PUSH_VALUE (p, (REAL_T) VALUE (&im), A68G_REAL);
 }
 
 // OP RE = (COMPLEX) REAL
@@ -826,18 +826,18 @@ void genie_re_complex (NODE_T * p)
 
 void genie_im_complex (NODE_T * p)
 {
-  A68_REAL im;
-  POP_OBJECT (p, &im, A68_REAL);
-  *(A68_REAL *) (STACK_OFFSET (-SIZE (M_REAL))) = im;
+  A68G_REAL im;
+  POP_OBJECT (p, &im, A68G_REAL);
+  *(A68G_REAL *) (STACK_OFFSET (-SIZE (M_REAL))) = im;
 }
 
 // OP - = (COMPLEX) COMPLEX
 
 void genie_minus_complex (NODE_T * p)
 {
-  A68_REAL *re_x, *im_x;
-  im_x = (A68_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
-  re_x = (A68_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
+  A68G_REAL *re_x, *im_x;
+  im_x = (A68G_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
+  re_x = (A68G_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
   VALUE (im_x) = -VALUE (im_x);
   VALUE (re_x) = -VALUE (re_x);
   (void) p;
@@ -847,27 +847,27 @@ void genie_minus_complex (NODE_T * p)
 
 void genie_abs_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x;
+  A68G_REAL re_x, im_x;
   POP_COMPLEX (p, &re_x, &im_x);
-  PUSH_VALUE (p, a68g_hypot_real (VALUE (&re_x), VALUE (&im_x)), A68_REAL);
+  PUSH_VALUE (p, a68g_hypot_real (VALUE (&re_x), VALUE (&im_x)), A68G_REAL);
 }
 
 // OP ARG = (COMPLEX) REAL
 
 void genie_arg_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x;
+  A68G_REAL re_x, im_x;
   POP_COMPLEX (p, &re_x, &im_x);
   PRELUDE_ERROR (VALUE (&re_x) == 0.0 && VALUE (&im_x) == 0.0, p, ERROR_INVALID_ARGUMENT, M_COMPLEX);
-  PUSH_VALUE (p, atan2 (VALUE (&im_x), VALUE (&re_x)), A68_REAL);
+  PUSH_VALUE (p, atan2 (VALUE (&im_x), VALUE (&re_x)), A68G_REAL);
 }
 
 // OP CONJ = (COMPLEX) COMPLEX
 
 void genie_conj_complex (NODE_T * p)
 {
-  A68_REAL *im;
-  POP_OPERAND_ADDRESS (p, im, A68_REAL);
+  A68G_REAL *im;
+  POP_OPERAND_ADDRESS (p, im, A68G_REAL);
   VALUE (im) = -VALUE (im);
 }
 
@@ -875,10 +875,10 @@ void genie_conj_complex (NODE_T * p)
 
 void genie_add_complex (NODE_T * p)
 {
-  A68_REAL *re_x, *im_x, re_y, im_y;
+  A68G_REAL *re_x, *im_x, re_y, im_y;
   POP_COMPLEX (p, &re_y, &im_y);
-  im_x = (A68_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
-  re_x = (A68_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
+  im_x = (A68G_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
+  re_x = (A68G_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
   VALUE (im_x) += VALUE (&im_y);
   VALUE (re_x) += VALUE (&re_y);
   CHECK_COMPLEX (p, VALUE (re_x), VALUE (im_x));
@@ -888,10 +888,10 @@ void genie_add_complex (NODE_T * p)
 
 void genie_sub_complex (NODE_T * p)
 {
-  A68_REAL *re_x, *im_x, re_y, im_y;
+  A68G_REAL *re_x, *im_x, re_y, im_y;
   POP_COMPLEX (p, &re_y, &im_y);
-  im_x = (A68_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
-  re_x = (A68_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
+  im_x = (A68G_REAL *) (STACK_OFFSET (-SIZE (M_REAL)));
+  re_x = (A68G_REAL *) (STACK_OFFSET (-2 * SIZE (M_REAL)));
   VALUE (im_x) -= VALUE (&im_y);
   VALUE (re_x) -= VALUE (&re_y);
   CHECK_COMPLEX (p, VALUE (re_x), VALUE (im_x));
@@ -901,7 +901,7 @@ void genie_sub_complex (NODE_T * p)
 
 void genie_mul_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x, re_y, im_y;
+  A68G_REAL re_x, im_x, re_y, im_y;
   POP_COMPLEX (p, &re_y, &im_y);
   POP_COMPLEX (p, &re_x, &im_x);
   REAL_T re = VALUE (&re_x) * VALUE (&re_y) - VALUE (&im_x) * VALUE (&im_y);
@@ -914,7 +914,7 @@ void genie_mul_complex (NODE_T * p)
 
 void genie_div_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x, re_y, im_y;
+  A68G_REAL re_x, im_x, re_y, im_y;
   REAL_T re = 0.0, im = 0.0;
   POP_COMPLEX (p, &re_y, &im_y);
   POP_COMPLEX (p, &re_x, &im_x);
@@ -938,9 +938,9 @@ void genie_div_complex (NODE_T * p)
 
 void genie_pow_complex_int (NODE_T * p)
 {
-  A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
-  A68_REAL re_x, im_x;
+  A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
+  A68G_REAL re_x, im_x;
   POP_COMPLEX (p, &re_x, &im_x);
   REAL_T re_z = 1.0, im_z = 0.0;
   REAL_T re_y = VALUE (&re_x), im_y = VALUE (&im_x);
@@ -963,14 +963,14 @@ void genie_pow_complex_int (NODE_T * p)
   }
   CHECK_COMPLEX (p, re_z, im_z);
   if (neg) {
-    PUSH_VALUE (p, 1.0, A68_REAL);
-    PUSH_VALUE (p, 0.0, A68_REAL);
-    PUSH_VALUE (p, re_z, A68_REAL);
-    PUSH_VALUE (p, im_z, A68_REAL);
+    PUSH_VALUE (p, 1.0, A68G_REAL);
+    PUSH_VALUE (p, 0.0, A68G_REAL);
+    PUSH_VALUE (p, re_z, A68G_REAL);
+    PUSH_VALUE (p, im_z, A68G_REAL);
     genie_div_complex (p);
   } else {
-    PUSH_VALUE (p, re_z, A68_REAL);
-    PUSH_VALUE (p, im_z, A68_REAL);
+    PUSH_VALUE (p, re_z, A68G_REAL);
+    PUSH_VALUE (p, im_z, A68G_REAL);
   }
 }
 
@@ -978,20 +978,20 @@ void genie_pow_complex_int (NODE_T * p)
 
 void genie_eq_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x, re_y, im_y;
+  A68G_REAL re_x, im_x, re_y, im_y;
   POP_COMPLEX (p, &re_y, &im_y);
   POP_COMPLEX (p, &re_x, &im_x);
-  PUSH_VALUE (p, (BOOL_T) ((VALUE (&re_x) == VALUE (&re_y)) && (VALUE (&im_x) == VALUE (&im_y))), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) ((VALUE (&re_x) == VALUE (&re_y)) && (VALUE (&im_x) == VALUE (&im_y))), A68G_BOOL);
 }
 
 // OP /= = (COMPLEX, COMPLEX) BOOL
 
 void genie_ne_complex (NODE_T * p)
 {
-  A68_REAL re_x, im_x, re_y, im_y;
+  A68G_REAL re_x, im_x, re_y, im_y;
   POP_COMPLEX (p, &re_y, &im_y);
   POP_COMPLEX (p, &re_x, &im_x);
-  PUSH_VALUE (p, (BOOL_T) ! ((VALUE (&re_x) == VALUE (&re_y)) && (VALUE (&im_x) == VALUE (&im_y))), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) ! ((VALUE (&re_x) == VALUE (&re_y)) && (VALUE (&im_x) == VALUE (&im_y))), A68G_BOOL);
 }
 
 // OP +:= = (REF COMPLEX, COMPLEX) REF COMPLEX
@@ -1023,14 +1023,14 @@ void genie_divab_complex (NODE_T * p)
 }
 
 #define C_C_FUNCTION(p, f)\
-  A68_REAL re, im;\
-  POP_OBJECT (p, &im, A68_REAL);\
-  POP_OBJECT (p, &re, A68_REAL);\
+  A68G_REAL re, im;\
+  POP_OBJECT (p, &im, A68G_REAL);\
+  POP_OBJECT (p, &re, A68G_REAL);\
   errno = 0;\
   COMPLEX_T z = VALUE (&re) + VALUE (&im) * _Complex_I;\
   z = f (z);\
-  PUSH_VALUE (p, (REAL_T) creal (z), A68_REAL);\
-  PUSH_VALUE (p, (REAL_T) cimag (z), A68_REAL);\
+  PUSH_VALUE (p, (REAL_T) creal (z), A68G_REAL);\
+  PUSH_VALUE (p, (REAL_T) cimag (z), A68G_REAL);\
   MATH_RTE (p, errno != 0, M_COMPLEX, NO_TEXT);
 
 // @brief PROC (COMPLEX) COMPLEX csqrt
@@ -1148,105 +1148,105 @@ void genie_atanh_complex (NODE_T * p)
 
 //! @brief PROC (COMPLEX) COMPLEX csqrt
 
-void a68g_sqrt_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sqrt_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, csqrt);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cexp
 
-void a68g_exp_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_exp_real_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, cexp);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cln
 
-void a68g_ln_complex (A68_REAL * z, A68_REAL * x)
+void a68g_ln_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, clog);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX csin
 
-void a68g_sin_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sin_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, csin);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ccos
 
-void a68g_cos_complex (A68_REAL * z, A68_REAL * x)
+void a68g_cos_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, ccos);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ctan
 
-void a68g_tan_complex (A68_REAL * z, A68_REAL * x)
+void a68g_tan_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, ctan);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX casin
 
-void a68g_asin_complex (A68_REAL * z, A68_REAL * x)
+void a68g_asin_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, casin);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cacos
 
-void a68g_acos_complex (A68_REAL * z, A68_REAL * x)
+void a68g_acos_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, cacos);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX catan
 
-void a68g_atan_complex (A68_REAL * z, A68_REAL * x)
+void a68g_atan_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, catan);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX csinh
 
-void a68g_sinh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_sinh_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, csinh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ccosh
 
-void a68g_cosh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_cosh_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, ccosh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX ctanh
 
-void a68g_tanh_complex (A68_REAL * z, A68_REAL * x)
+void a68g_tanh_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, ctanh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX casinh
 
-void a68g_asinh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_asinh_real_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, casinh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX cacosh
 
-void a68g_acosh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_acosh_real_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, cacosh);
 }
 
 //! @brief PROC (COMPLEX) COMPLEX catanh
 
-void a68g_atanh_real_complex (A68_REAL * z, A68_REAL * x)
+void a68g_atanh_real_complex (A68G_REAL * z, A68G_REAL * x)
 {
   C_C_INLINE (z, x, catanh);
 }
@@ -1255,10 +1255,10 @@ void a68g_atanh_real_complex (A68_REAL * z, A68_REAL * x)
 
 void genie_fact_real (NODE_T * p)
 {
-  A68_INT n;
-  POP_OBJECT (p, &n, A68_INT);
+  A68G_INT n;
+  POP_OBJECT (p, &n, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_fact_real (VALUE (&n)), A68_REAL);
+  PUSH_VALUE (p, a68g_fact_real (VALUE (&n)), A68G_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
@@ -1266,20 +1266,20 @@ void genie_fact_real (NODE_T * p)
 
 void genie_ln_fact_real (NODE_T * p)
 {
-  A68_INT n;
-  POP_OBJECT (p, &n, A68_INT);
+  A68G_INT n;
+  POP_OBJECT (p, &n, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_ln_fact_real (VALUE (&n)), A68_REAL);
+  PUSH_VALUE (p, a68g_ln_fact_real (VALUE (&n)), A68G_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
 void genie_choose_real (NODE_T * p)
 {
-  A68_INT n, m;
-  POP_OBJECT (p, &m, A68_INT);
-  POP_OBJECT (p, &n, A68_INT);
+  A68G_INT n, m;
+  POP_OBJECT (p, &m, A68G_INT);
+  POP_OBJECT (p, &n, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
+  PUSH_VALUE (p, a68g_choose_real (VALUE (&n), VALUE (&m)), A68G_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
@@ -1287,17 +1287,17 @@ void genie_choose_real (NODE_T * p)
 
 void genie_ln_choose_real (NODE_T * p)
 {
-  A68_INT n, m;
-  POP_OBJECT (p, &m, A68_INT);
-  POP_OBJECT (p, &n, A68_INT);
+  A68G_INT n, m;
+  POP_OBJECT (p, &m, A68G_INT);
+  POP_OBJECT (p, &n, A68G_INT);
   errno = 0;
-  PUSH_VALUE (p, a68g_ln_choose_real (VALUE (&n), VALUE (&m)), A68_REAL);
+  PUSH_VALUE (p, a68g_ln_choose_real (VALUE (&n), VALUE (&m)), A68G_REAL);
   MATH_RTE (p, errno != 0, M_INT, NO_TEXT);
 }
 
 // OP / = (COMPLEX, COMPLEX) COMPLEX
 
-void a68g_div_complex (A68_REAL * z, A68_REAL * x, A68_REAL * y)
+void a68g_div_complex (A68G_REAL * z, A68G_REAL * x, A68G_REAL * y)
 {
   STATUS_RE (z) = INIT_MASK;
   STATUS_IM (z) = INIT_MASK;
@@ -1320,18 +1320,18 @@ void a68g_div_complex (A68_REAL * z, A68_REAL * x, A68_REAL * y)
 
 void genie_max_bits (NODE_T * p)
 {
-  PUSH_VALUE (p, A68_MAX_BITS, A68_BITS);
+  PUSH_VALUE (p, A68G_MAX_BITS, A68G_BITS);
 }
 
 // OP NOT = (BITS) BITS.
-A68_MONAD (genie_not_bits, A68_BITS, ~);
+A68G_MONAD (genie_not_bits, A68G_BITS, ~);
 
 // OP AND = (BITS, BITS) BITS
 
 void genie_and_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   VALUE (i) = VALUE (i) & VALUE (j);
 }
 
@@ -1339,8 +1339,8 @@ void genie_and_bits (NODE_T * p)
 
 void genie_or_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   VALUE (i) = VALUE (i) | VALUE (j);
 }
 
@@ -1348,8 +1348,8 @@ void genie_or_bits (NODE_T * p)
 
 void genie_xor_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   VALUE (i) = VALUE (i) ^ VALUE (j);
 }
 
@@ -1357,8 +1357,8 @@ void genie_xor_bits (NODE_T * p)
 
 void genie_add_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   CHECK_BITS_ADDITION (p, VALUE (i), VALUE (j));
   VALUE (i) = VALUE (i) + VALUE (j);
 }
@@ -1367,8 +1367,8 @@ void genie_add_bits (NODE_T * p)
 
 void genie_sub_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   CHECK_BITS_SUBTRACTION (p, VALUE (i), VALUE (j));
   VALUE (i) = VALUE (i) - VALUE (j);
 }
@@ -1377,8 +1377,8 @@ void genie_sub_bits (NODE_T * p)
 
 void genie_times_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   CHECK_BITS_MULTIPLICATION (p, VALUE (i), VALUE (j));
   VALUE (i) = VALUE (i) * VALUE (j);
 }
@@ -1387,8 +1387,8 @@ void genie_times_bits (NODE_T * p)
 
 void genie_over_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   PRELUDE_ERROR (VALUE (j) == 0, p, ERROR_DIVISION_BY_ZERO, M_BITS);
   VALUE (i) = VALUE (i) / VALUE (j);
 }
@@ -1397,58 +1397,58 @@ void genie_over_bits (NODE_T * p)
 
 void genie_mod_bits (NODE_T * p)
 {
-  A68_BITS *i, *j;
-  POP_OPERAND_ADDRESSES (p, i, j, A68_BITS);
+  A68G_BITS *i, *j;
+  POP_OPERAND_ADDRESSES (p, i, j, A68G_BITS);
   PRELUDE_ERROR (VALUE (j) == 0, p, ERROR_DIVISION_BY_ZERO, M_BITS);
   VALUE (i) = VALUE (i) % VALUE (j);
 }
 
 // OP = = (BITS, BITS) BOOL.
 
-#define A68_CMP_BITS(n, OP)\
+#define A68G_CMP_BITS(n, OP)\
 void n (NODE_T * p) {\
-  A68_BITS i, j;\
-  POP_OBJECT (p, &j, A68_BITS);\
-  POP_OBJECT (p, &i, A68_BITS);\
-  PUSH_VALUE (p, (BOOL_T) ((UNSIGNED_T) VALUE (&i) OP (UNSIGNED_T) VALUE (&j)), A68_BOOL);\
+  A68G_BITS i, j;\
+  POP_OBJECT (p, &j, A68G_BITS);\
+  POP_OBJECT (p, &i, A68G_BITS);\
+  PUSH_VALUE (p, (BOOL_T) ((UNSIGNED_T) VALUE (&i) OP (UNSIGNED_T) VALUE (&j)), A68G_BOOL);\
   }
 
-A68_CMP_BITS (genie_eq_bits, ==);
-A68_CMP_BITS (genie_ne_bits, !=);
+A68G_CMP_BITS (genie_eq_bits, ==);
+A68G_CMP_BITS (genie_ne_bits, !=);
 
 // OP <= = (BITS, BITS) BOOL
 
 void genie_le_bits (NODE_T * p)
 {
-  A68_BITS i, j;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_BITS);
-  PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&j)), A68_BOOL);
+  A68G_BITS i, j;
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_BITS);
+  PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&j)), A68G_BOOL);
 }
 
 // OP >= = (BITS, BITS) BOOL
 
 void genie_ge_bits (NODE_T * p)
 {
-  A68_BITS i, j;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_BITS);
-  PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&i)), A68_BOOL);
+  A68G_BITS i, j;
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_BITS);
+  PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&i)), A68G_BOOL);
 }
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 
 // OP < = (BITS, BITS) BOOL
 
 void genie_lt_bits (NODE_T * p)
 {
-  A68_BITS i, j;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_BITS);
+  A68G_BITS i, j;
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_BITS);
   if (VALUE (&i) == VALUE (&j)) {
-    PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+    PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
   } else {
-    PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&j)), A68_BOOL);
+    PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&j)), A68G_BOOL);
   }
 }
 
@@ -1456,13 +1456,13 @@ void genie_lt_bits (NODE_T * p)
 
 void genie_gt_bits (NODE_T * p)
 {
-  A68_BITS i, j;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_BITS);
+  A68G_BITS i, j;
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_BITS);
   if (VALUE (&i) == VALUE (&j)) {
-    PUSH_VALUE (p, A68_FALSE, A68_BOOL);
+    PUSH_VALUE (p, A68G_FALSE, A68G_BOOL);
   } else {
-    PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&i)), A68_BOOL);
+    PUSH_VALUE (p, (BOOL_T) ((VALUE (&i) | VALUE (&j)) == VALUE (&i)), A68G_BOOL);
   }
 }
 
@@ -1472,9 +1472,9 @@ void genie_gt_bits (NODE_T * p)
 
 void genie_shl_bits (NODE_T * p)
 {
-  A68_BITS i; A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
-  POP_OBJECT (p, &i, A68_BITS);
+  A68G_BITS i; A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
+  POP_OBJECT (p, &i, A68G_BITS);
   UNSIGNED_T z = VALUE (&i);
   int n = VALUE (&j);
   if (n >= 0) {
@@ -1482,13 +1482,13 @@ void genie_shl_bits (NODE_T * p)
       PRELUDE_ERROR (!MODULAR_MATH (p) && (z & D_SIGN), p, ERROR_MATH, M_BITS);
       z = z << 1;
     }
-    PUSH_VALUE (p, z, A68_BITS);
+    PUSH_VALUE (p, z, A68G_BITS);
   } else {
     for (int k = 0; k < -n; k++) {
 //    PRELUDE_ERROR (!MODULAR_MATH (p) && (z & 0x1), p, ERROR_MATH, M_BITS);
       z = z >> 1;
     }
-    PUSH_VALUE (p, z, A68_BITS);
+    PUSH_VALUE (p, z, A68G_BITS);
   }
 }
 
@@ -1496,8 +1496,8 @@ void genie_shl_bits (NODE_T * p)
 
 void genie_shr_bits (NODE_T * p)
 {
-  A68_INT *j;
-  POP_OPERAND_ADDRESS (p, j, A68_INT);
+  A68G_INT *j;
+  POP_OPERAND_ADDRESS (p, j, A68G_INT);
   VALUE (j) = -VALUE (j);
   genie_shl_bits (p);           // Conform RR
 }
@@ -1506,9 +1506,9 @@ void genie_shr_bits (NODE_T * p)
 
 void genie_rol_bits (NODE_T * p)
 {
-  A68_BITS i; A68_INT j;
-  POP_OBJECT (p, &j, A68_INT);
-  POP_OBJECT (p, &i, A68_BITS);
+  A68G_BITS i; A68G_INT j;
+  POP_OBJECT (p, &j, A68G_INT);
+  POP_OBJECT (p, &i, A68G_BITS);
   CHECK_INT_SHORTEN (p, VALUE (&j));
   UNSIGNED_T w = VALUE (&i);
   int n = VALUE (&j);
@@ -1524,15 +1524,15 @@ void genie_rol_bits (NODE_T * p)
       w = (w >> 1) | carry;
     }
   }
-  PUSH_VALUE (p, w, A68_BITS);
+  PUSH_VALUE (p, w, A68G_BITS);
 }
 
 // OP ROR = (BITS, INT) BITS
 
 void genie_ror_bits (NODE_T * p)
 {
-  A68_INT *j;
-  POP_OPERAND_ADDRESS (p, j, A68_INT);
+  A68G_INT *j;
+  POP_OPERAND_ADDRESS (p, j, A68G_INT);
   VALUE (j) = -VALUE (j);
   genie_rol_bits (p);
 }
@@ -1541,90 +1541,90 @@ void genie_ror_bits (NODE_T * p)
 
 void genie_elem_bits (NODE_T * p)
 {
-  A68_BITS j; A68_INT i;
+  A68G_BITS j; A68G_INT i;
   UNSIGNED_T mask = 0x1;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_INT);
-  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  for (int n = 0; n < (A68_BITS_WIDTH - VALUE (&i)); n++) {
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_INT);
+  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68G_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
+  for (int n = 0; n < (A68G_BITS_WIDTH - VALUE (&i)); n++) {
     mask = mask << 1;
   }
-  PUSH_VALUE (p, (BOOL_T) ((VALUE (&j) & mask) != 0 ? A68_TRUE : A68_FALSE), A68_BOOL);
+  PUSH_VALUE (p, (BOOL_T) ((VALUE (&j) & mask) != 0 ? A68G_TRUE : A68G_FALSE), A68G_BOOL);
 }
 
 // OP SET = (INT, BITS) BITS
 
 void genie_set_bits (NODE_T * p)
 {
-  A68_BITS j; A68_INT i;
+  A68G_BITS j; A68G_INT i;
   UNSIGNED_T mask = 0x1;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_INT);
-  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  for (int n = 0; n < (A68_BITS_WIDTH - VALUE (&i)); n++) {
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_INT);
+  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68G_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
+  for (int n = 0; n < (A68G_BITS_WIDTH - VALUE (&i)); n++) {
     mask = mask << 1;
   }
-  PUSH_VALUE (p, VALUE (&j) | mask, A68_BITS);
+  PUSH_VALUE (p, VALUE (&j) | mask, A68G_BITS);
 }
 
 // OP CLEAR = (INT, BITS) BITS
 
 void genie_clear_bits (NODE_T * p)
 {
-  A68_BITS j; A68_INT i;
+  A68G_BITS j; A68G_INT i;
   UNSIGNED_T mask = 0x1;
-  POP_OBJECT (p, &j, A68_BITS);
-  POP_OBJECT (p, &i, A68_INT);
-  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
-  for (int n = 0; n < (A68_BITS_WIDTH - VALUE (&i)); n++) {
+  POP_OBJECT (p, &j, A68G_BITS);
+  POP_OBJECT (p, &i, A68G_INT);
+  PRELUDE_ERROR (VALUE (&i) < 1 || VALUE (&i) > A68G_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_INT);
+  for (int n = 0; n < (A68G_BITS_WIDTH - VALUE (&i)); n++) {
     mask = mask << 1;
   }
-  PUSH_VALUE (p, VALUE (&j) & ~mask, A68_BITS);
+  PUSH_VALUE (p, VALUE (&j) & ~mask, A68G_BITS);
 }
 
 // OP ABS = (BITS) INT
 
 void genie_abs_bits (NODE_T * p)
 {
-  A68_BITS i;
-  POP_OBJECT (p, &i, A68_BITS);
-  PUSH_VALUE (p, (INT_T) (VALUE (&i)), A68_INT);
+  A68G_BITS i;
+  POP_OBJECT (p, &i, A68G_BITS);
+  PUSH_VALUE (p, (INT_T) (VALUE (&i)), A68G_INT);
 }
 
 // OP BIN = (INT) BITS
 
 void genie_bin_int (NODE_T * p)
 {
-  A68_INT i;
-  POP_OBJECT (p, &i, A68_INT);
+  A68G_INT i;
+  POP_OBJECT (p, &i, A68G_INT);
   if (!MODULAR_MATH (p) && VALUE (&i) < 0) {
 // RR does not convert negative numbers.
     errno = EDOM;
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_OUT_OF_BOUNDS, M_BITS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  PUSH_VALUE (p, (UNSIGNED_T) (VALUE (&i)), A68_BITS);
+  PUSH_VALUE (p, (UNSIGNED_T) (VALUE (&i)), A68G_BITS);
 }
 
 // @brief PROC ([] BOOL) BITS bits pack
 
 void genie_bits_pack (NODE_T * p)
 {
-  A68_ARRAY *arr; A68_TUPLE *tup;
-  A68_REF z;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
+  A68G_REF z;
   POP_REF (p, &z);
   CHECK_REF (p, z, M_ROW_BOOL);
   GET_DESCRIPTOR (arr, tup, &z);
   int size = ROW_SIZE (tup);
-  PRELUDE_ERROR (size < 0 || size > A68_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_ROW_BOOL);
-  A68_BITS b;
+  PRELUDE_ERROR (size < 0 || size > A68G_BITS_WIDTH, p, ERROR_OUT_OF_BOUNDS, M_ROW_BOOL);
+  A68G_BITS b;
   VALUE (&b) = 0x0;
   if (ROW_SIZE (tup) > 0) {
     BYTE_T *base = DEREF (BYTE_T, &ARRAY (arr));
     UNSIGNED_T bit = 0x1;
     for (int k = UPB (tup); k >= LWB (tup); k--) {
       int addr = INDEX_1_DIM (arr, tup, k);
-      A68_BOOL *boo = (A68_BOOL *) & (base[addr]);
+      A68G_BOOL *boo = (A68G_BOOL *) & (base[addr]);
       CHECK_INIT (p, INITIALISED (boo), M_BOOL);
       if (VALUE (boo)) {
         VALUE (&b) |= bit;
@@ -1633,5 +1633,5 @@ void genie_bits_pack (NODE_T * p)
     }
   }
   STATUS (&b) = INIT_MASK;
-  PUSH_OBJECT (p, b, A68_BITS);
+  PUSH_OBJECT (p, b, A68G_BITS);
 }
