@@ -26,32 +26,32 @@
 #if !defined (__A68G_PRELUDE_H__)
 #define __A68G_PRELUDE_H__
 
-#define A68_STD A68_TRUE
-#define A68_EXT A68_FALSE
+#define A68G_STD A68G_TRUE
+#define A68G_EXT A68G_FALSE
 
 // ALGOL68C type procs.
 
 #define A68C_DEFIO(name, pname, mode) {\
   m = a68g_proc (MODE (mode), M_REF_FILE, NO_MOID);\
-  a68g_idf (A68_EXT, "get" #name, m, genie_get_##pname);\
+  a68g_idf (A68G_EXT, "get" #name, m, genie_get_##pname);\
   m = a68g_proc (M_VOID, M_REF_FILE, MODE (mode), NO_MOID);\
-  a68g_idf (A68_EXT, "put" #name, m, genie_put_##pname);\
+  a68g_idf (A68G_EXT, "put" #name, m, genie_put_##pname);\
   m = a68g_proc (MODE (mode), NO_MOID);\
-  a68g_idf (A68_EXT, "read" #name, m, genie_read_##pname);\
+  a68g_idf (A68G_EXT, "read" #name, m, genie_read_##pname);\
   m = a68g_proc (M_VOID, MODE (mode), NO_MOID);\
-  a68g_idf (A68_EXT, "print" #name, m, genie_print_##pname);\
+  a68g_idf (A68G_EXT, "print" #name, m, genie_print_##pname);\
 }
 
 #define IS_NL_FF(ch) ((ch) == NEWLINE_CHAR || (ch) == FORMFEED_CHAR)
 
-#define A68_MONAD(n, MODE, OP)\
+#define A68G_MONAD(n, MODE, OP)\
 void n (NODE_T * p) {\
   MODE *i;\
   POP_OPERAND_ADDRESS (p, i, MODE);\
   VALUE (i) = OP (VALUE (i));\
 }
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 GPROC genie_lt_bits;
 GPROC genie_gt_bits;
 DOUBLE_T mp_to_double (NODE_T *, MP_T *, int);
@@ -63,21 +63,22 @@ void a68g_idf (BOOL_T, char *, MOID_T *, GPROC *);
 void a68g_prio (char *, int);
 void a68g_op (BOOL_T, char *, MOID_T *, GPROC *);
 void a68g_mode (int, char *, MOID_T **);
-A68_REF c_string_to_row_char (NODE_T *, char *, int);
-A68_REF c_to_a_string (NODE_T *, char *, int);
-A68_REF empty_row (NODE_T *, MOID_T *);
-A68_REF empty_string (NODE_T *);
-A68_REF genie_make_row (NODE_T *, MOID_T *, int, ADDR_T);
-A68_REF genie_store (NODE_T *, MOID_T *, A68_REF *, A68_REF *);
-A68_REF heap_generator_2 (NODE_T *, MOID_T *, int, int);
-A68_REF heap_generator_3 (NODE_T *, MOID_T *, int, int, int);
-A68_REF heap_generator (NODE_T *, MOID_T *, int);
-A68_REF tmp_to_a68g_string (NODE_T *, char *);
-ADDR_T calculate_internal_index (A68_TUPLE *, int);
-BOOL_T close_device (NODE_T *, A68_FILE *);
+A68G_REF c_string_to_row_char (NODE_T *, char *, int);
+A68G_REF c_to_a_string (NODE_T *, char *, int);
+A68G_REF empty_row (NODE_T *, MOID_T *);
+A68G_REF empty_string (NODE_T *);
+A68G_REF genie_make_row (NODE_T *, MOID_T *, int, ADDR_T);
+A68G_REF genie_store (NODE_T *, MOID_T *, A68G_REF *, A68G_REF *);
+A68G_REF heap_generator_2 (NODE_T *, MOID_T *, int, int);
+A68G_REF heap_generator_3 (NODE_T *, MOID_T *, int, int, int);
+A68G_REF heap_generator (NODE_T *, MOID_T *, int);
+A68G_REF tmp_to_a68g_string (NODE_T *, char *);
+ADDR_T calculate_internal_index (A68G_TUPLE *, int);
+BOOL_T close_device (NODE_T *, A68G_FILE *);
 BOOL_T genie_int_case_unit (NODE_T *, int, int *);
-BOOL_T increment_internal_index (A68_TUPLE *, int);
-char *a_to_c_string (NODE_T *, char *, A68_REF);
+BOOL_T increment_internal_index (A68G_TUPLE *, int);
+BOOL_T moid_needs_colouring (MOID_T *);
+char *a_to_c_string (NODE_T *, char *, A68G_REF);
 char *propagator_name (const PROP_PROC * p);
 FILE *a68g_fopen (char *, char *, char *);
 GPROC get_global_level;
@@ -85,30 +86,31 @@ GPROC initialise_frame;
 int a68g_finite_real (REAL_T);
 int a68g_isinf_real (REAL_T);
 int a68g_isnan_real (REAL_T);
-int a68g_string_size (NODE_T *, A68_REF);
+int a68g_string_size (NODE_T *, A68G_REF);
 int char_value (int);
 int grep_in_string (char *, char *, int *, int *);
 INT_T a68g_round (REAL_T);
 PROP_T genie_generator (NODE_T *);
 REAL_T seconds (void);
 REAL_T ten_up (int);
+REAL_T wall_seconds (void);
 ssize_t io_read_conv (FILE_T, void *, size_t);
 ssize_t io_read (FILE_T, void *, size_t);
 ssize_t io_write_conv (FILE_T, const void *, size_t);
 ssize_t io_write (FILE_T, const void *, size_t);
 unt heap_available (void);
-void a68g_div_complex (A68_REAL *, A68_REAL *, A68_REAL *);
+void a68g_div_complex (A68G_REAL *, A68G_REAL *, A68G_REAL *);
 void a68g_exit (int);
-void a68g_exp_real_complex (A68_REAL *, A68_REAL *);
+void a68g_exp_real_complex (A68G_REAL *, A68G_REAL *);
 void change_breakpoints (NODE_T *, unt, int, BOOL_T *, char *);
 void change_masks (NODE_T *, unt, BOOL_T);
 void colour_object (BYTE_T *, MOID_T *);
 void deltagammainc (REAL_T *, REAL_T *, REAL_T, REAL_T, REAL_T, REAL_T);
 void exit_genie (NODE_T *, int);
 void gc_heap (NODE_T *, ADDR_T);
-void genie_call_event_routine (NODE_T *, MOID_T *, A68_PROCEDURE *, ADDR_T, ADDR_T);
+void genie_call_event_routine (NODE_T *, MOID_T *, A68G_PROCEDURE *, ADDR_T, ADDR_T);
 void genie_call_operator (NODE_T *, ADDR_T);
-void genie_call_procedure (NODE_T *, MOID_T *, MOID_T *, MOID_T *, A68_PROCEDURE *, ADDR_T, ADDR_T);
+void genie_call_procedure (NODE_T *, MOID_T *, MOID_T *, MOID_T *, A68G_PROCEDURE *, ADDR_T, ADDR_T);
 void genie_check_initialisation (NODE_T *, BYTE_T *, MOID_T *);
 void genie_f_and_becomes (NODE_T *, MOID_T *, GPROC *);
 void genie_find_proc_op (NODE_T *, int *);
@@ -118,30 +120,30 @@ void genie_generator_stowed (NODE_T *, BYTE_T *, NODE_T **, ADDR_T *);
 void genie_init_rng (void);
 void genie_preprocess (NODE_T *, int *, void *);
 void genie_push_undefined (NODE_T *, MOID_T *);
-void genie_read_standard_format (NODE_T *, MOID_T *, BYTE_T *, A68_REF, int *);
-void genie_read_standard (NODE_T *, MOID_T *, BYTE_T *, A68_REF);
+void genie_read_standard_format (NODE_T *, MOID_T *, BYTE_T *, A68G_REF, int *);
+void genie_read_standard (NODE_T *, MOID_T *, BYTE_T *, A68G_REF);
 void genie_serial_clause (NODE_T *, jmp_buf *);
 void genie_serial_units (NODE_T *, NODE_T **, jmp_buf *, ADDR_T);
-void genie_string_to_value (NODE_T *, MOID_T *, BYTE_T *, A68_REF);
-void genie_subscript (NODE_T *, A68_TUPLE **, INT_T *, NODE_T **);
+void genie_string_to_value (NODE_T *, MOID_T *, BYTE_T *, A68G_REF);
+void genie_subscript (NODE_T *, A68G_TUPLE **, INT_T *, NODE_T **);
 void genie_value_to_string (NODE_T *, MOID_T *, BYTE_T *, int);
 void genie_variable_dec (NODE_T *, NODE_T **, ADDR_T);
-void genie_write_standard_format (NODE_T *, MOID_T *, BYTE_T *, A68_REF, int *);
-void genie_write_standard (NODE_T *, MOID_T *, BYTE_T *, A68_REF);
-void initialise_internal_index (A68_TUPLE *, int);
+void genie_write_standard_format (NODE_T *, MOID_T *, BYTE_T *, A68G_REF, int *);
+void genie_write_standard (NODE_T *, MOID_T *, BYTE_T *, A68G_REF);
+void initialise_internal_index (A68G_TUPLE *, int);
 void io_close_tty_line (void);
 void io_write_string (FILE_T, const char *);
 void monitor_error (char *, char *);
 void mp_strtou (NODE_T *, MP_T *, char *, MOID_T *);
-void open_format_frame (NODE_T *, A68_REF, A68_FORMAT *, BOOL_T, BOOL_T);
-void print_internal_index (FILE_T, A68_TUPLE *, int);
+void open_format_frame (NODE_T *, A68G_REF, A68G_FORMAT *, BOOL_T, BOOL_T);
+void print_internal_index (FILE_T, A68G_TUPLE *, int);
 void print_item (NODE_T *, FILE_T, BYTE_T *, MOID_T *);
-void purge_format_read (NODE_T *, A68_REF);
-void purge_format_write (NODE_T *, A68_REF);
+void purge_format_read (NODE_T *, A68G_REF);
+void purge_format_write (NODE_T *, A68G_REF);
 void single_step (NODE_T *, unt);
-void skip_nl_ff (NODE_T *, int *, A68_REF);
+void skip_nl_ff (NODE_T *, int *, A68G_REF);
 void stack_dump (FILE_T, ADDR_T, int, int *);
-void value_sign_error (NODE_T *, MOID_T *, A68_REF);
+void value_sign_error (NODE_T *, MOID_T *, A68G_REF);
 void where_in_source (FILE_T, NODE_T *);
 
 // Standard prelude RTS
@@ -615,6 +617,7 @@ GPROC genie_to_lower;
 GPROC genie_to_upper;
 GPROC genie_unimplemented;
 GPROC genie_utctime;
+GPROC genie_walltime;
 GPROC genie_waitpid;
 GPROC genie_whole;
 GPROC genie_write;
